
# This file uses the following encoding : utf-8
# This file was generated automatically, don't edit it.
# Last generated on 2023-10-22 @ 22:59:34 
# All included emojis where extracted from https://www.webfx.com/tools/emoji-cheat-sheet

from collections import namedtuple

Emoji = namedtuple("Emoji", ["category", "emoji", "alias", "description", "unicode"])

EmojiStorage = [
	Emoji('smileys_and_people', '😀', 'grinning_face', 'grinning face', ['U+1F600']),
	Emoji('smileys_and_people', '😃', 'grinning_face_with_big_eyes', 'grinning face with big eyes', ['U+1F603']),
	Emoji('smileys_and_people', '😄', 'grinning_face_with_smiling_eyes', 'grinning face with smiling eyes', ['U+1F604']),
	Emoji('smileys_and_people', '😁', 'beaming_face_with_smiling_eyes', 'beaming face with smiling eyes', ['U+1F601']),
	Emoji('smileys_and_people', '😆', 'grinning_squinting_face', 'grinning squinting face', ['U+1F606']),
	Emoji('smileys_and_people', '😅', 'grinning_face_with_sweat', 'grinning face with sweat', ['U+1F605']),
	Emoji('smileys_and_people', '🤣', 'rolling_on_the_floor_laughing', 'rolling on the floor laughing', ['U+1F923']),
	Emoji('smileys_and_people', '😂', 'face_with_tears_of_joy', 'face with tears of joy', ['U+1F602']),
	Emoji('smileys_and_people', '🙂', 'slightly_smiling_face', 'slightly smiling face', ['U+1F642']),
	Emoji('smileys_and_people', '🙃', 'upside_down_face', 'upside-down face', ['U+1F643']),
	Emoji('smileys_and_people', '🫠', 'melting_face', 'melting face', ['U+1FAE0']),
	Emoji('smileys_and_people', '😉', 'winking_face', 'winking face', ['U+1F609']),
	Emoji('smileys_and_people', '😊', 'smiling_face_with_smiling_eyes', 'smiling face with smiling eyes', ['U+1F60A']),
	Emoji('smileys_and_people', '😇', 'smiling_face_with_halo', 'smiling face with halo', ['U+1F607']),
	Emoji('smileys_and_people', '🥰', 'smiling_face_with_hearts', 'smiling face with hearts', ['U+1F970']),
	Emoji('smileys_and_people', '😍', 'smiling_face_with_heart_eyes', 'smiling face with heart-eyes', ['U+1F60D']),
	Emoji('smileys_and_people', '🤩', 'star_struck', 'star-struck', ['U+1F929']),
	Emoji('smileys_and_people', '😘', 'face_blowing_a_kiss', 'face blowing a kiss', ['U+1F618']),
	Emoji('smileys_and_people', '😗', 'kissing_face', 'kissing face', ['U+1F617']),
	Emoji('smileys_and_people', '☺', 'smiling_face', 'smiling face', ['U+263A']),
	Emoji('smileys_and_people', '😚', 'kissing_face_with_closed_eyes', 'kissing face with closed eyes', ['U+1F61A']),
	Emoji('smileys_and_people', '😙', 'kissing_face_with_smiling_eyes', 'kissing face with smiling eyes', ['U+1F619']),
	Emoji('smileys_and_people', '🥲', 'smiling_face_with_tear', 'smiling face with tear', ['U+1F972']),
	Emoji('smileys_and_people', '😋', 'face_savoring_food', 'face savoring food', ['U+1F60B']),
	Emoji('smileys_and_people', '😛', 'face_with_tongue', 'face with tongue', ['U+1F61B']),
	Emoji('smileys_and_people', '😜', 'winking_face_with_tongue', 'winking face with tongue', ['U+1F61C']),
	Emoji('smileys_and_people', '🤪', 'zany_face', 'zany face', ['U+1F92A']),
	Emoji('smileys_and_people', '😝', 'squinting_face_with_tongue', 'squinting face with tongue', ['U+1F61D']),
	Emoji('smileys_and_people', '🤑', 'money_mouth_face', 'money-mouth face', ['U+1F911']),
	Emoji('smileys_and_people', '🤗', 'smiling_face_with_open_hands', 'smiling face with open hands', ['U+1F917']),
	Emoji('smileys_and_people', '🤭', 'face_with_hand_over_mouth', 'face with hand over mouth', ['U+1F92D']),
	Emoji('smileys_and_people', '🫢', 'face_with_open_eyes_and_hand_over_mouth', 'face with open eyes and hand over mouth', ['U+1FAE2']),
	Emoji('smileys_and_people', '🫣', 'face_with_peeking_eye', 'face with peeking eye', ['U+1FAE3']),
	Emoji('smileys_and_people', '🤫', 'shushing_face', 'shushing face', ['U+1F92B']),
	Emoji('smileys_and_people', '🤔', 'thinking_face', 'thinking face', ['U+1F914']),
	Emoji('smileys_and_people', '🫡', 'saluting_face', 'saluting face', ['U+1FAE1']),
	Emoji('smileys_and_people', '🤐', 'zipper_mouth_face', 'zipper-mouth face', ['U+1F910']),
	Emoji('smileys_and_people', '🤨', 'face_with_raised_eyebrow', 'face with raised eyebrow', ['U+1F928']),
	Emoji('smileys_and_people', '😐', 'neutral_face', 'neutral face', ['U+1F610']),
	Emoji('smileys_and_people', '😑', 'expressionless_face', 'expressionless face', ['U+1F611']),
	Emoji('smileys_and_people', '😶', 'face_without_mouth', 'face without mouth', ['U+1F636']),
	Emoji('smileys_and_people', '🫥', 'dotted_line_face', 'dotted line face', ['U+1FAE5']),
	Emoji('smileys_and_people', '😶‍🌫️', 'face_in_clouds', 'face in clouds', ['U+1F636', 'U+200D', 'U+1F32B', 'U+FE0F']),
	Emoji('smileys_and_people', '😏', 'smirking_face', 'smirking face', ['U+1F60F']),
	Emoji('smileys_and_people', '😒', 'unamused_face', 'unamused face', ['U+1F612']),
	Emoji('smileys_and_people', '🙄', 'face_with_rolling_eyes', 'face with rolling eyes', ['U+1F644']),
	Emoji('smileys_and_people', '😬', 'grimacing_face', 'grimacing face', ['U+1F62C']),
	Emoji('smileys_and_people', '😮‍💨', 'face_exhaling', 'face exhaling', ['U+1F62E', 'U+200D', 'U+1F4A8']),
	Emoji('smileys_and_people', '🤥', '⊛_shaking_face', '⊛ shaking face', ['U+1F925']),
	Emoji('smileys_and_people', '😌', 'relieved_face', 'relieved face', ['U+1F60C']),
	Emoji('smileys_and_people', '😔', 'pensive_face', 'pensive face', ['U+1F614']),
	Emoji('smileys_and_people', '😪', 'sleepy_face', 'sleepy face', ['U+1F62A']),
	Emoji('smileys_and_people', '🤤', 'drooling_face', 'drooling face', ['U+1F924']),
	Emoji('smileys_and_people', '😴', 'sleeping_face', 'sleeping face', ['U+1F634']),
	Emoji('smileys_and_people', '😷', 'face_with_medical_mask', 'face with medical mask', ['U+1F637']),
	Emoji('smileys_and_people', '🤒', 'face_with_thermometer', 'face with thermometer', ['U+1F912']),
	Emoji('smileys_and_people', '🤕', 'face_with_head_bandage', 'face with head-bandage', ['U+1F915']),
	Emoji('smileys_and_people', '🤢', 'nauseated_face', 'nauseated face', ['U+1F922']),
	Emoji('smileys_and_people', '🤮', 'face_vomiting', 'face vomiting', ['U+1F92E']),
	Emoji('smileys_and_people', '🤧', 'sneezing_face', 'sneezing face', ['U+1F927']),
	Emoji('smileys_and_people', '🥵', 'hot_face', 'hot face', ['U+1F975']),
	Emoji('smileys_and_people', '🥶', 'cold_face', 'cold face', ['U+1F976']),
	Emoji('smileys_and_people', '🥴', 'woozy_face', 'woozy face', ['U+1F974']),
	Emoji('smileys_and_people', '😵', 'face_with_crossed_out_eyes', 'face with crossed-out eyes', ['U+1F635']),
	Emoji('smileys_and_people', '😵‍💫', 'face_with_spiral_eyes', 'face with spiral eyes', ['U+1F635', 'U+200D', 'U+1F4AB']),
	Emoji('smileys_and_people', '🤯', 'exploding_head', 'exploding head', ['U+1F92F']),
	Emoji('smileys_and_people', '🤠', 'cowboy_hat_face', 'cowboy hat face', ['U+1F920']),
	Emoji('smileys_and_people', '🥳', 'partying_face', 'partying face', ['U+1F973']),
	Emoji('smileys_and_people', '🥸', 'disguised_face', 'disguised face', ['U+1F978']),
	Emoji('smileys_and_people', '😎', 'smiling_face_with_sunglasses', 'smiling face with sunglasses', ['U+1F60E']),
	Emoji('smileys_and_people', '🤓', 'nerd_face', 'nerd face', ['U+1F913']),
	Emoji('smileys_and_people', '🧐', 'face_with_monocle', 'face with monocle', ['U+1F9D0']),
	Emoji('smileys_and_people', '😕', 'confused_face', 'confused face', ['U+1F615']),
	Emoji('smileys_and_people', '🫤', 'face_with_diagonal_mouth', 'face with diagonal mouth', ['U+1FAE4']),
	Emoji('smileys_and_people', '😟', 'worried_face', 'worried face', ['U+1F61F']),
	Emoji('smileys_and_people', '🙁', 'slightly_frowning_face', 'slightly frowning face', ['U+1F641']),
	Emoji('smileys_and_people', '☹', 'frowning_face', 'frowning face', ['U+2639']),
	Emoji('smileys_and_people', '😮', 'face_with_open_mouth', 'face with open mouth', ['U+1F62E']),
	Emoji('smileys_and_people', '😯', 'hushed_face', 'hushed face', ['U+1F62F']),
	Emoji('smileys_and_people', '😲', 'astonished_face', 'astonished face', ['U+1F632']),
	Emoji('smileys_and_people', '😳', 'flushed_face', 'flushed face', ['U+1F633']),
	Emoji('smileys_and_people', '🥺', 'pleading_face', 'pleading face', ['U+1F97A']),
	Emoji('smileys_and_people', '🥹', 'face_holding_back_tears', 'face holding back tears', ['U+1F979']),
	Emoji('smileys_and_people', '😦', 'frowning_face_with_open_mouth', 'frowning face with open mouth', ['U+1F626']),
	Emoji('smileys_and_people', '😧', 'anguished_face', 'anguished face', ['U+1F627']),
	Emoji('smileys_and_people', '😨', 'fearful_face', 'fearful face', ['U+1F628']),
	Emoji('smileys_and_people', '😰', 'anxious_face_with_sweat', 'anxious face with sweat', ['U+1F630']),
	Emoji('smileys_and_people', '😥', 'sad_but_relieved_face', 'sad but relieved face', ['U+1F625']),
	Emoji('smileys_and_people', '😢', 'crying_face', 'crying face', ['U+1F622']),
	Emoji('smileys_and_people', '😭', 'loudly_crying_face', 'loudly crying face', ['U+1F62D']),
	Emoji('smileys_and_people', '😱', 'face_screaming_in_fear', 'face screaming in fear', ['U+1F631']),
	Emoji('smileys_and_people', '😖', 'confounded_face', 'confounded face', ['U+1F616']),
	Emoji('smileys_and_people', '😣', 'persevering_face', 'persevering face', ['U+1F623']),
	Emoji('smileys_and_people', '😞', 'disappointed_face', 'disappointed face', ['U+1F61E']),
	Emoji('smileys_and_people', '😓', 'downcast_face_with_sweat', 'downcast face with sweat', ['U+1F613']),
	Emoji('smileys_and_people', '😩', 'weary_face', 'weary face', ['U+1F629']),
	Emoji('smileys_and_people', '😫', 'tired_face', 'tired face', ['U+1F62B']),
	Emoji('smileys_and_people', '🥱', 'yawning_face', 'yawning face', ['U+1F971']),
	Emoji('smileys_and_people', '😤', 'face_with_steam_from_nose', 'face with steam from nose', ['U+1F624']),
	Emoji('smileys_and_people', '😡', 'enraged_face', 'enraged face', ['U+1F621']),
	Emoji('smileys_and_people', '😠', 'angry_face', 'angry face', ['U+1F620']),
	Emoji('smileys_and_people', '🤬', 'face_with_symbols_on_mouth', 'face with symbols on mouth', ['U+1F92C']),
	Emoji('smileys_and_people', '😈', 'smiling_face_with_horns', 'smiling face with horns', ['U+1F608']),
	Emoji('smileys_and_people', '👿', 'angry_face_with_horns', 'angry face with horns', ['U+1F47F']),
	Emoji('smileys_and_people', '💀', 'skull', 'skull', ['U+1F480']),
	Emoji('smileys_and_people', '☠', 'skull_and_crossbones', 'skull and crossbones', ['U+2620']),
	Emoji('smileys_and_people', '💩', 'pile_of_poo', 'pile of poo', ['U+1F4A9']),
	Emoji('smileys_and_people', '🤡', 'clown_face', 'clown face', ['U+1F921']),
	Emoji('smileys_and_people', '👹', 'ogre', 'ogre', ['U+1F479']),
	Emoji('smileys_and_people', '👺', 'goblin', 'goblin', ['U+1F47A']),
	Emoji('smileys_and_people', '👻', 'ghost', 'ghost', ['U+1F47B']),
	Emoji('smileys_and_people', '👽', 'alien', 'alien', ['U+1F47D']),
	Emoji('smileys_and_people', '👾', 'alien_monster', 'alien monster', ['U+1F47E']),
	Emoji('smileys_and_people', '🤖', 'robot', 'robot', ['U+1F916']),
	Emoji('smileys_and_people', '😺', 'grinning_cat', 'grinning cat', ['U+1F63A']),
	Emoji('smileys_and_people', '😸', 'grinning_cat_with_smiling_eyes', 'grinning cat with smiling eyes', ['U+1F638']),
	Emoji('smileys_and_people', '😹', 'cat_with_tears_of_joy', 'cat with tears of joy', ['U+1F639']),
	Emoji('smileys_and_people', '😻', 'smiling_cat_with_heart_eyes', 'smiling cat with heart-eyes', ['U+1F63B']),
	Emoji('smileys_and_people', '😼', 'cat_with_wry_smile', 'cat with wry smile', ['U+1F63C']),
	Emoji('smileys_and_people', '😽', 'kissing_cat', 'kissing cat', ['U+1F63D']),
	Emoji('smileys_and_people', '🙀', 'weary_cat', 'weary cat', ['U+1F640']),
	Emoji('smileys_and_people', '😿', 'crying_cat', 'crying cat', ['U+1F63F']),
	Emoji('smileys_and_people', '😾', 'pouting_cat', 'pouting cat', ['U+1F63E']),
	Emoji('smileys_and_people', '🙈', 'see_no_evil_monkey', 'see-no-evil monkey', ['U+1F648']),
	Emoji('smileys_and_people', '🙉', 'hear_no_evil_monkey', 'hear-no-evil monkey', ['U+1F649']),
	Emoji('smileys_and_people', '🙊', 'speak_no_evil_monkey', 'speak-no-evil monkey', ['U+1F64A']),
	Emoji('smileys_and_people', '💌', 'love_letter', 'love letter', ['U+1F48C']),
	Emoji('smileys_and_people', '💘', 'heart_with_arrow', 'heart with arrow', ['U+1F498']),
	Emoji('smileys_and_people', '💝', 'heart_with_ribbon', 'heart with ribbon', ['U+1F49D']),
	Emoji('smileys_and_people', '💖', 'sparkling_heart', 'sparkling heart', ['U+1F496']),
	Emoji('smileys_and_people', '💗', 'growing_heart', 'growing heart', ['U+1F497']),
	Emoji('smileys_and_people', '💓', 'beating_heart', 'beating heart', ['U+1F493']),
	Emoji('smileys_and_people', '💞', 'revolving_hearts', 'revolving hearts', ['U+1F49E']),
	Emoji('smileys_and_people', '💕', 'two_hearts', 'two hearts', ['U+1F495']),
	Emoji('smileys_and_people', '💟', 'heart_decoration', 'heart decoration', ['U+1F49F']),
	Emoji('smileys_and_people', '❣', 'heart_exclamation', 'heart exclamation', ['U+2763']),
	Emoji('smileys_and_people', '💔', 'broken_heart', 'broken heart', ['U+1F494']),
	Emoji('smileys_and_people', '❤️‍🔥', 'heart_on_fire', 'heart on fire', ['U+2764', 'U+FE0F', 'U+200D', 'U+1F525']),
	Emoji('smileys_and_people', '❤️‍🩹', 'mending_heart', 'mending heart', ['U+2764', 'U+FE0F', 'U+200D', 'U+1FA79']),
	Emoji('smileys_and_people', '❤', '⊛_pink_heart', '⊛ pink heart', ['U+2764']),
	Emoji('smileys_and_people', '🧡', 'orange_heart', 'orange heart', ['U+1F9E1']),
	Emoji('smileys_and_people', '💛', 'yellow_heart', 'yellow heart', ['U+1F49B']),
	Emoji('smileys_and_people', '💚', 'green_heart', 'green heart', ['U+1F49A']),
	Emoji('smileys_and_people', '💙', 'blue_heart', 'blue heart', ['U+1F499']),
	Emoji('smileys_and_people', '💜', 'purple_heart', 'purple heart', ['U+1F49C']),
	Emoji('smileys_and_people', '🤎', 'brown_heart', 'brown heart', ['U+1F90E']),
	Emoji('smileys_and_people', '🖤', '⊛_grey_heart', '⊛ grey heart', ['U+1F5A4']),
	Emoji('smileys_and_people', '🤍', 'white_heart', 'white heart', ['U+1F90D']),
	Emoji('smileys_and_people', '💋', 'kiss_mark', 'kiss mark', ['U+1F48B']),
	Emoji('smileys_and_people', '💯', 'hundred_points', 'hundred points', ['U+1F4AF']),
	Emoji('smileys_and_people', '💢', 'anger_symbol', 'anger symbol', ['U+1F4A2']),
	Emoji('smileys_and_people', '💥', 'collision', 'collision', ['U+1F4A5']),
	Emoji('smileys_and_people', '💫', 'dizzy', 'dizzy', ['U+1F4AB']),
	Emoji('smileys_and_people', '💦', 'sweat_droplets', 'sweat droplets', ['U+1F4A6']),
	Emoji('smileys_and_people', '💨', 'dashing_away', 'dashing away', ['U+1F4A8']),
	Emoji('smileys_and_people', '🕳', 'hole', 'hole', ['U+1F573']),
	Emoji('smileys_and_people', '💬', 'speech_balloon', 'speech balloon', ['U+1F4AC']),
	Emoji('smileys_and_people', '👁️‍🗨️', 'eye_in_speech_bubble', 'eye in speech bubble', ['U+1F441', 'U+FE0F', 'U+200D', 'U+1F5E8', 'U+FE0F']),
	Emoji('smileys_and_people', '🗨', 'left_speech_bubble', 'left speech bubble', ['U+1F5E8']),
	Emoji('smileys_and_people', '🗯', 'right_anger_bubble', 'right anger bubble', ['U+1F5EF']),
	Emoji('smileys_and_people', '💭', 'thought_balloon', 'thought balloon', ['U+1F4AD']),
	Emoji('smileys_and_people', '💤', 'ZZZ', 'ZZZ', ['U+1F4A4']),
	Emoji('smileys_and_people', '👋', 'waving_hand', 'waving hand', ['U+1F44B']),
	Emoji('smileys_and_people', '🤚', 'raised_back_of_hand', 'raised back of hand', ['U+1F91A']),
	Emoji('smileys_and_people', '🖐', 'hand_with_fingers_splayed', 'hand with fingers splayed', ['U+1F590']),
	Emoji('smileys_and_people', '✋', 'raised_hand', 'raised hand', ['U+270B']),
	Emoji('smileys_and_people', '🖖', 'vulcan_salute', 'vulcan salute', ['U+1F596']),
	Emoji('smileys_and_people', '🫱', 'rightwards_hand', 'rightwards hand', ['U+1FAF1']),
	Emoji('smileys_and_people', '🫲', 'leftwards_hand', 'leftwards hand', ['U+1FAF2']),
	Emoji('smileys_and_people', '🫳', 'palm_down_hand', 'palm down hand', ['U+1FAF3']),
	Emoji('smileys_and_people', '🫴', '⊛_rightwards_pushing_hand', '⊛ rightwards pushing hand', ['U+1FAF4']),
	Emoji('smileys_and_people', '👌', 'OK_hand', 'OK hand', ['U+1F44C']),
	Emoji('smileys_and_people', '🤌', 'pinched_fingers', 'pinched fingers', ['U+1F90C']),
	Emoji('smileys_and_people', '🤏', 'pinching_hand', 'pinching hand', ['U+1F90F']),
	Emoji('smileys_and_people', '✌', 'victory_hand', 'victory hand', ['U+270C']),
	Emoji('smileys_and_people', '🤞', 'crossed_fingers', 'crossed fingers', ['U+1F91E']),
	Emoji('smileys_and_people', '🫰', 'hand_with_index_finger_and_thumb_crossed', 'hand with index finger and thumb crossed', ['U+1FAF0']),
	Emoji('smileys_and_people', '🤟', 'love_you_gesture', 'love-you gesture', ['U+1F91F']),
	Emoji('smileys_and_people', '🤘', 'sign_of_the_horns', 'sign of the horns', ['U+1F918']),
	Emoji('smileys_and_people', '🤙', 'call_me_hand', 'call me hand', ['U+1F919']),
	Emoji('smileys_and_people', '👈', 'backhand_index_pointing_left', 'backhand index pointing left', ['U+1F448']),
	Emoji('smileys_and_people', '👉', 'backhand_index_pointing_right', 'backhand index pointing right', ['U+1F449']),
	Emoji('smileys_and_people', '👆', 'backhand_index_pointing_up', 'backhand index pointing up', ['U+1F446']),
	Emoji('smileys_and_people', '🖕', 'middle_finger', 'middle finger', ['U+1F595']),
	Emoji('smileys_and_people', '👇', 'backhand_index_pointing_down', 'backhand index pointing down', ['U+1F447']),
	Emoji('smileys_and_people', '☝', 'index_pointing_up', 'index pointing up', ['U+261D']),
	Emoji('smileys_and_people', '🫵', 'index_pointing_at_the_viewer', 'index pointing at the viewer', ['U+1FAF5']),
	Emoji('smileys_and_people', '👍', 'thumbs_up', 'thumbs up', ['U+1F44D']),
	Emoji('smileys_and_people', '👎', 'thumbs_down', 'thumbs down', ['U+1F44E']),
	Emoji('smileys_and_people', '✊', 'raised_fist', 'raised fist', ['U+270A']),
	Emoji('smileys_and_people', '👊', 'oncoming_fist', 'oncoming fist', ['U+1F44A']),
	Emoji('smileys_and_people', '🤛', 'left_facing_fist', 'left-facing fist', ['U+1F91B']),
	Emoji('smileys_and_people', '🤜', 'right_facing_fist', 'right-facing fist', ['U+1F91C']),
	Emoji('smileys_and_people', '👏', 'clapping_hands', 'clapping hands', ['U+1F44F']),
	Emoji('smileys_and_people', '🙌', 'raising_hands', 'raising hands', ['U+1F64C']),
	Emoji('smileys_and_people', '🫶', 'heart_hands', 'heart hands', ['U+1FAF6']),
	Emoji('smileys_and_people', '👐', 'open_hands', 'open hands', ['U+1F450']),
	Emoji('smileys_and_people', '🤲', 'palms_up_together', 'palms up together', ['U+1F932']),
	Emoji('smileys_and_people', '🤝', 'handshake', 'handshake', ['U+1F91D']),
	Emoji('smileys_and_people', '🙏', 'folded_hands', 'folded hands', ['U+1F64F']),
	Emoji('smileys_and_people', '✍', 'writing_hand', 'writing hand', ['U+270D']),
	Emoji('smileys_and_people', '💅', 'nail_polish', 'nail polish', ['U+1F485']),
	Emoji('smileys_and_people', '🤳', 'selfie', 'selfie', ['U+1F933']),
	Emoji('smileys_and_people', '💪', 'flexed_biceps', 'flexed biceps', ['U+1F4AA']),
	Emoji('smileys_and_people', '🦾', 'mechanical_arm', 'mechanical arm', ['U+1F9BE']),
	Emoji('smileys_and_people', '🦿', 'mechanical_leg', 'mechanical leg', ['U+1F9BF']),
	Emoji('smileys_and_people', '🦵', 'leg', 'leg', ['U+1F9B5']),
	Emoji('smileys_and_people', '🦶', 'foot', 'foot', ['U+1F9B6']),
	Emoji('smileys_and_people', '👂', 'ear', 'ear', ['U+1F442']),
	Emoji('smileys_and_people', '🦻', 'ear_with_hearing_aid', 'ear with hearing aid', ['U+1F9BB']),
	Emoji('smileys_and_people', '👃', 'nose', 'nose', ['U+1F443']),
	Emoji('smileys_and_people', '🧠', 'brain', 'brain', ['U+1F9E0']),
	Emoji('smileys_and_people', '🫀', 'anatomical_heart', 'anatomical heart', ['U+1FAC0']),
	Emoji('smileys_and_people', '🫁', 'lungs', 'lungs', ['U+1FAC1']),
	Emoji('smileys_and_people', '🦷', 'tooth', 'tooth', ['U+1F9B7']),
	Emoji('smileys_and_people', '🦴', 'bone', 'bone', ['U+1F9B4']),
	Emoji('smileys_and_people', '👀', 'eyes', 'eyes', ['U+1F440']),
	Emoji('smileys_and_people', '👁', 'eye', 'eye', ['U+1F441']),
	Emoji('smileys_and_people', '👅', 'tongue', 'tongue', ['U+1F445']),
	Emoji('smileys_and_people', '👄', 'mouth', 'mouth', ['U+1F444']),
	Emoji('smileys_and_people', '🫦', 'biting_lip', 'biting lip', ['U+1FAE6']),
	Emoji('smileys_and_people', '👶', 'baby', 'baby', ['U+1F476']),
	Emoji('smileys_and_people', '🧒', 'child', 'child', ['U+1F9D2']),
	Emoji('smileys_and_people', '👦', 'boy', 'boy', ['U+1F466']),
	Emoji('smileys_and_people', '👧', 'girl', 'girl', ['U+1F467']),
	Emoji('smileys_and_people', '🧑', 'person', 'person', ['U+1F9D1']),
	Emoji('smileys_and_people', '👱', 'person_blond_hair', 'person: blond hair', ['U+1F471']),
	Emoji('smileys_and_people', '👨', 'man', 'man', ['U+1F468']),
	Emoji('smileys_and_people', '🧔', 'person_beard', 'person: beard', ['U+1F9D4']),
	Emoji('smileys_and_people', '🧔‍♂️', 'man_beard', 'man: beard', ['U+1F9D4', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧔‍♀️', 'woman_beard', 'woman: beard', ['U+1F9D4', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '👨‍🦰', 'man_red_hair', 'man: red hair', ['U+1F468', 'U+200D', 'U+1F9B0']),
	Emoji('smileys_and_people', '👨‍🦱', 'man_curly_hair', 'man: curly hair', ['U+1F468', 'U+200D', 'U+1F9B1']),
	Emoji('smileys_and_people', '👨‍🦳', 'man_white_hair', 'man: white hair', ['U+1F468', 'U+200D', 'U+1F9B3']),
	Emoji('smileys_and_people', '👨‍🦲', 'man_bald', 'man: bald', ['U+1F468', 'U+200D', 'U+1F9B2']),
	Emoji('smileys_and_people', '👩', 'woman', 'woman', ['U+1F469']),
	Emoji('smileys_and_people', '👩‍🦰', 'woman_red_hair', 'woman: red hair', ['U+1F469', 'U+200D', 'U+1F9B0']),
	Emoji('smileys_and_people', '🧑‍🦰', 'person_red_hair', 'person: red hair', ['U+1F9D1', 'U+200D', 'U+1F9B0']),
	Emoji('smileys_and_people', '👩‍🦱', 'woman_curly_hair', 'woman: curly hair', ['U+1F469', 'U+200D', 'U+1F9B1']),
	Emoji('smileys_and_people', '🧑‍🦱', 'person_curly_hair', 'person: curly hair', ['U+1F9D1', 'U+200D', 'U+1F9B1']),
	Emoji('smileys_and_people', '👩‍🦳', 'woman_white_hair', 'woman: white hair', ['U+1F469', 'U+200D', 'U+1F9B3']),
	Emoji('smileys_and_people', '🧑‍🦳', 'person_white_hair', 'person: white hair', ['U+1F9D1', 'U+200D', 'U+1F9B3']),
	Emoji('smileys_and_people', '👩‍🦲', 'woman_bald', 'woman: bald', ['U+1F469', 'U+200D', 'U+1F9B2']),
	Emoji('smileys_and_people', '🧑‍🦲', 'person_bald', 'person: bald', ['U+1F9D1', 'U+200D', 'U+1F9B2']),
	Emoji('smileys_and_people', '👱‍♀️', 'woman_blond_hair', 'woman: blond hair', ['U+1F471', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '👱‍♂️', 'man_blond_hair', 'man: blond hair', ['U+1F471', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧓', 'older_person', 'older person', ['U+1F9D3']),
	Emoji('smileys_and_people', '👴', 'old_man', 'old man', ['U+1F474']),
	Emoji('smileys_and_people', '👵', 'old_woman', 'old woman', ['U+1F475']),
	Emoji('smileys_and_people', '🙍', 'person_frowning', 'person frowning', ['U+1F64D']),
	Emoji('smileys_and_people', '🙍‍♂️', 'man_frowning', 'man frowning', ['U+1F64D', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🙍‍♀️', 'woman_frowning', 'woman frowning', ['U+1F64D', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🙎', 'person_pouting', 'person pouting', ['U+1F64E']),
	Emoji('smileys_and_people', '🙎‍♂️', 'man_pouting', 'man pouting', ['U+1F64E', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🙎‍♀️', 'woman_pouting', 'woman pouting', ['U+1F64E', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🙅', 'person_gesturing_NO', 'person gesturing NO', ['U+1F645']),
	Emoji('smileys_and_people', '🙅‍♂️', 'man_gesturing_NO', 'man gesturing NO', ['U+1F645', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🙅‍♀️', 'woman_gesturing_NO', 'woman gesturing NO', ['U+1F645', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🙆', 'person_gesturing_OK', 'person gesturing OK', ['U+1F646']),
	Emoji('smileys_and_people', '🙆‍♂️', 'man_gesturing_OK', 'man gesturing OK', ['U+1F646', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🙆‍♀️', 'woman_gesturing_OK', 'woman gesturing OK', ['U+1F646', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '💁', 'person_tipping_hand', 'person tipping hand', ['U+1F481']),
	Emoji('smileys_and_people', '💁‍♂️', 'man_tipping_hand', 'man tipping hand', ['U+1F481', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '💁‍♀️', 'woman_tipping_hand', 'woman tipping hand', ['U+1F481', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🙋', 'person_raising_hand', 'person raising hand', ['U+1F64B']),
	Emoji('smileys_and_people', '🙋‍♂️', 'man_raising_hand', 'man raising hand', ['U+1F64B', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🙋‍♀️', 'woman_raising_hand', 'woman raising hand', ['U+1F64B', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧏', 'deaf_person', 'deaf person', ['U+1F9CF']),
	Emoji('smileys_and_people', '🧏‍♂️', 'deaf_man', 'deaf man', ['U+1F9CF', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧏‍♀️', 'deaf_woman', 'deaf woman', ['U+1F9CF', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🙇', 'person_bowing', 'person bowing', ['U+1F647']),
	Emoji('smileys_and_people', '🙇‍♂️', 'man_bowing', 'man bowing', ['U+1F647', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🙇‍♀️', 'woman_bowing', 'woman bowing', ['U+1F647', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤦', 'person_facepalming', 'person facepalming', ['U+1F926']),
	Emoji('smileys_and_people', '🤦‍♂️', 'man_facepalming', 'man facepalming', ['U+1F926', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤦‍♀️', 'woman_facepalming', 'woman facepalming', ['U+1F926', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤷', 'person_shrugging', 'person shrugging', ['U+1F937']),
	Emoji('smileys_and_people', '🤷‍♂️', 'man_shrugging', 'man shrugging', ['U+1F937', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤷‍♀️', 'woman_shrugging', 'woman shrugging', ['U+1F937', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧑‍⚕️', 'health_worker', 'health worker', ['U+1F9D1', 'U+200D', 'U+2695', 'U+FE0F']),
	Emoji('smileys_and_people', '👨‍⚕️', 'man_health_worker', 'man health worker', ['U+1F468', 'U+200D', 'U+2695', 'U+FE0F']),
	Emoji('smileys_and_people', '👩‍⚕️', 'woman_health_worker', 'woman health worker', ['U+1F469', 'U+200D', 'U+2695', 'U+FE0F']),
	Emoji('smileys_and_people', '🧑‍🎓', 'student', 'student', ['U+1F9D1', 'U+200D', 'U+1F393']),
	Emoji('smileys_and_people', '👨‍🎓', 'man_student', 'man student', ['U+1F468', 'U+200D', 'U+1F393']),
	Emoji('smileys_and_people', '👩‍🎓', 'woman_student', 'woman student', ['U+1F469', 'U+200D', 'U+1F393']),
	Emoji('smileys_and_people', '🧑‍🏫', 'teacher', 'teacher', ['U+1F9D1', 'U+200D', 'U+1F3EB']),
	Emoji('smileys_and_people', '👨‍🏫', 'man_teacher', 'man teacher', ['U+1F468', 'U+200D', 'U+1F3EB']),
	Emoji('smileys_and_people', '👩‍🏫', 'woman_teacher', 'woman teacher', ['U+1F469', 'U+200D', 'U+1F3EB']),
	Emoji('smileys_and_people', '🧑‍⚖️', 'judge', 'judge', ['U+1F9D1', 'U+200D', 'U+2696', 'U+FE0F']),
	Emoji('smileys_and_people', '👨‍⚖️', 'man_judge', 'man judge', ['U+1F468', 'U+200D', 'U+2696', 'U+FE0F']),
	Emoji('smileys_and_people', '👩‍⚖️', 'woman_judge', 'woman judge', ['U+1F469', 'U+200D', 'U+2696', 'U+FE0F']),
	Emoji('smileys_and_people', '🧑‍🌾', 'farmer', 'farmer', ['U+1F9D1', 'U+200D', 'U+1F33E']),
	Emoji('smileys_and_people', '👨‍🌾', 'man_farmer', 'man farmer', ['U+1F468', 'U+200D', 'U+1F33E']),
	Emoji('smileys_and_people', '👩‍🌾', 'woman_farmer', 'woman farmer', ['U+1F469', 'U+200D', 'U+1F33E']),
	Emoji('smileys_and_people', '🧑‍🍳', 'cook', 'cook', ['U+1F9D1', 'U+200D', 'U+1F373']),
	Emoji('smileys_and_people', '👨‍🍳', 'man_cook', 'man cook', ['U+1F468', 'U+200D', 'U+1F373']),
	Emoji('smileys_and_people', '👩‍🍳', 'woman_cook', 'woman cook', ['U+1F469', 'U+200D', 'U+1F373']),
	Emoji('smileys_and_people', '🧑‍🔧', 'mechanic', 'mechanic', ['U+1F9D1', 'U+200D', 'U+1F527']),
	Emoji('smileys_and_people', '👨‍🔧', 'man_mechanic', 'man mechanic', ['U+1F468', 'U+200D', 'U+1F527']),
	Emoji('smileys_and_people', '👩‍🔧', 'woman_mechanic', 'woman mechanic', ['U+1F469', 'U+200D', 'U+1F527']),
	Emoji('smileys_and_people', '🧑‍🏭', 'factory_worker', 'factory worker', ['U+1F9D1', 'U+200D', 'U+1F3ED']),
	Emoji('smileys_and_people', '👨‍🏭', 'man_factory_worker', 'man factory worker', ['U+1F468', 'U+200D', 'U+1F3ED']),
	Emoji('smileys_and_people', '👩‍🏭', 'woman_factory_worker', 'woman factory worker', ['U+1F469', 'U+200D', 'U+1F3ED']),
	Emoji('smileys_and_people', '🧑‍💼', 'office_worker', 'office worker', ['U+1F9D1', 'U+200D', 'U+1F4BC']),
	Emoji('smileys_and_people', '👨‍💼', 'man_office_worker', 'man office worker', ['U+1F468', 'U+200D', 'U+1F4BC']),
	Emoji('smileys_and_people', '👩‍💼', 'woman_office_worker', 'woman office worker', ['U+1F469', 'U+200D', 'U+1F4BC']),
	Emoji('smileys_and_people', '🧑‍🔬', 'scientist', 'scientist', ['U+1F9D1', 'U+200D', 'U+1F52C']),
	Emoji('smileys_and_people', '👨‍🔬', 'man_scientist', 'man scientist', ['U+1F468', 'U+200D', 'U+1F52C']),
	Emoji('smileys_and_people', '👩‍🔬', 'woman_scientist', 'woman scientist', ['U+1F469', 'U+200D', 'U+1F52C']),
	Emoji('smileys_and_people', '🧑‍💻', 'technologist', 'technologist', ['U+1F9D1', 'U+200D', 'U+1F4BB']),
	Emoji('smileys_and_people', '👨‍💻', 'man_technologist', 'man technologist', ['U+1F468', 'U+200D', 'U+1F4BB']),
	Emoji('smileys_and_people', '👩‍💻', 'woman_technologist', 'woman technologist', ['U+1F469', 'U+200D', 'U+1F4BB']),
	Emoji('smileys_and_people', '🧑‍🎤', 'singer', 'singer', ['U+1F9D1', 'U+200D', 'U+1F3A4']),
	Emoji('smileys_and_people', '👨‍🎤', 'man_singer', 'man singer', ['U+1F468', 'U+200D', 'U+1F3A4']),
	Emoji('smileys_and_people', '👩‍🎤', 'woman_singer', 'woman singer', ['U+1F469', 'U+200D', 'U+1F3A4']),
	Emoji('smileys_and_people', '🧑‍🎨', 'artist', 'artist', ['U+1F9D1', 'U+200D', 'U+1F3A8']),
	Emoji('smileys_and_people', '👨‍🎨', 'man_artist', 'man artist', ['U+1F468', 'U+200D', 'U+1F3A8']),
	Emoji('smileys_and_people', '👩‍🎨', 'woman_artist', 'woman artist', ['U+1F469', 'U+200D', 'U+1F3A8']),
	Emoji('smileys_and_people', '🧑‍✈️', 'pilot', 'pilot', ['U+1F9D1', 'U+200D', 'U+2708', 'U+FE0F']),
	Emoji('smileys_and_people', '👨‍✈️', 'man_pilot', 'man pilot', ['U+1F468', 'U+200D', 'U+2708', 'U+FE0F']),
	Emoji('smileys_and_people', '👩‍✈️', 'woman_pilot', 'woman pilot', ['U+1F469', 'U+200D', 'U+2708', 'U+FE0F']),
	Emoji('smileys_and_people', '🧑‍🚀', 'astronaut', 'astronaut', ['U+1F9D1', 'U+200D', 'U+1F680']),
	Emoji('smileys_and_people', '👨‍🚀', 'man_astronaut', 'man astronaut', ['U+1F468', 'U+200D', 'U+1F680']),
	Emoji('smileys_and_people', '👩‍🚀', 'woman_astronaut', 'woman astronaut', ['U+1F469', 'U+200D', 'U+1F680']),
	Emoji('smileys_and_people', '🧑‍🚒', 'firefighter', 'firefighter', ['U+1F9D1', 'U+200D', 'U+1F692']),
	Emoji('smileys_and_people', '👨‍🚒', 'man_firefighter', 'man firefighter', ['U+1F468', 'U+200D', 'U+1F692']),
	Emoji('smileys_and_people', '👩‍🚒', 'woman_firefighter', 'woman firefighter', ['U+1F469', 'U+200D', 'U+1F692']),
	Emoji('smileys_and_people', '👮', 'police_officer', 'police officer', ['U+1F46E']),
	Emoji('smileys_and_people', '👮‍♂️', 'man_police_officer', 'man police officer', ['U+1F46E', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '👮‍♀️', 'woman_police_officer', 'woman police officer', ['U+1F46E', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🕵', 'detective', 'detective', ['U+1F575']),
	Emoji('smileys_and_people', '🕵️‍♂️', 'man_detective', 'man detective', ['U+1F575', 'U+FE0F', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🕵️‍♀️', 'woman_detective', 'woman detective', ['U+1F575', 'U+FE0F', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '💂', 'guard', 'guard', ['U+1F482']),
	Emoji('smileys_and_people', '💂‍♂️', 'man_guard', 'man guard', ['U+1F482', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '💂‍♀️', 'woman_guard', 'woman guard', ['U+1F482', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🥷', 'ninja', 'ninja', ['U+1F977']),
	Emoji('smileys_and_people', '👷', 'construction_worker', 'construction worker', ['U+1F477']),
	Emoji('smileys_and_people', '👷‍♂️', 'man', 'man', ['U+1F477', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '👷‍♀️', 'woman_construction_worker', 'woman construction worker', ['U+1F477', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🫅', 'person_with_crown', 'person with crown', ['U+1FAC5']),
	Emoji('smileys_and_people', '🤴', 'prince', 'prince', ['U+1F934']),
	Emoji('smileys_and_people', '👸', 'princess', 'princess', ['U+1F478']),
	Emoji('smileys_and_people', '👳', 'person_wearing_turban', 'person wearing turban', ['U+1F473']),
	Emoji('smileys_and_people', '👳‍♂️', 'man_wearing_turban', 'man wearing turban', ['U+1F473', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '👳‍♀️', 'woman_wearing_turban', 'woman wearing turban', ['U+1F473', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '👲', 'person_with_skullcap', 'person with skullcap', ['U+1F472']),
	Emoji('smileys_and_people', '🧕', 'woman_with_headscarf', 'woman with headscarf', ['U+1F9D5']),
	Emoji('smileys_and_people', '🤵', 'person_in_tuxedo', 'person in tuxedo', ['U+1F935']),
	Emoji('smileys_and_people', '🤵‍♂️', 'man_in_tuxedo', 'man in tuxedo', ['U+1F935', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤵‍♀️', 'woman_in_tuxedo', 'woman in tuxedo', ['U+1F935', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '👰', 'person_with_veil', 'person with veil', ['U+1F470']),
	Emoji('smileys_and_people', '👰‍♂️', 'man_with_veil', 'man with veil', ['U+1F470', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '👰‍♀️', 'woman_with_veil', 'woman with veil', ['U+1F470', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤰', 'pregnant_woman', 'pregnant woman', ['U+1F930']),
	Emoji('smileys_and_people', '🫃', 'pregnant_man', 'pregnant man', ['U+1FAC3']),
	Emoji('smileys_and_people', '🫄', 'pregnant_person', 'pregnant person', ['U+1FAC4']),
	Emoji('smileys_and_people', '🤱', 'breast_feeding', 'breast-feeding', ['U+1F931']),
	Emoji('smileys_and_people', '👩‍🍼', 'woman_feeding_baby', 'woman feeding babay', ['U+1F469', 'U+200D', 'U+1F37C']),
	Emoji('smileys_and_people', '👨‍🍼', 'man_feeding_baby', 'man feeding baby', ['U+1F468', 'U+200D', 'U+1F37C']),
	Emoji('smileys_and_people', '🧑‍🍼', 'person_feeding_baby', 'person feeding baby', ['U+1F9D1', 'U+200D', 'U+1F37C']),
	Emoji('smileys_and_people', '👼', 'baby_angel', 'baby angel', ['U+1F47C']),
	Emoji('smileys_and_people', '🎅', 'Santa_Claus', 'Santa Claus', ['U+1F385']),
	Emoji('smileys_and_people', '🤶', 'Mrs._Claus', 'Mrs. Claus', ['U+1F936']),
	Emoji('smileys_and_people', '🧑‍🎄', 'mx_claus', 'mx claus', ['U+1F9D1', 'U+200D', 'U+1F384']),
	Emoji('smileys_and_people', '🦸', 'superhero', 'superhero', ['U+1F9B8']),
	Emoji('smileys_and_people', '🦸‍♂️', 'man_superhero', 'man superhero', ['U+1F9B8', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🦸‍♀️', 'woman_superhero', 'woman superhero', ['U+1F9B8', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🦹', 'supervillain', 'supervillain', ['U+1F9B9']),
	Emoji('smileys_and_people', '🦹‍♂️', 'man_supervillain', 'man supervillain', ['U+1F9B9', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🦹‍♀️', 'woman_supervillain', 'woman supervillain', ['U+1F9B9', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧙', 'mage', 'mage', ['U+1F9D9']),
	Emoji('smileys_and_people', '🧙‍♂️', 'man_mage', 'man mage', ['U+1F9D9', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧙‍♀️', 'woman_mage', 'woman mage', ['U+1F9D9', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧚', 'fairy', 'fairy', ['U+1F9DA']),
	Emoji('smileys_and_people', '🧚‍♂️', 'man_fairy', 'man fairy', ['U+1F9DA', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧚‍♀️', 'woman_fairy', 'woman fairy', ['U+1F9DA', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧛', 'vampire', 'vampire', ['U+1F9DB']),
	Emoji('smileys_and_people', '🧛‍♂️', 'man_vampire', 'man vampire', ['U+1F9DB', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧛‍♀️', 'woman_vampire', 'woman vampire', ['U+1F9DB', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧜', 'merperson', 'merperson', ['U+1F9DC']),
	Emoji('smileys_and_people', '🧜‍♂️', 'merman', 'merman', ['U+1F9DC', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧜‍♀️', 'mermaid', 'mermaid', ['U+1F9DC', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧝', 'elf', 'elf', ['U+1F9DD']),
	Emoji('smileys_and_people', '🧝‍♂️', 'man_elf', 'man elf', ['U+1F9DD', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧝‍♀️', 'woman_elf', 'woman elf', ['U+1F9DD', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧞', 'genie', 'genie', ['U+1F9DE']),
	Emoji('smileys_and_people', '🧞‍♂️', 'man_genie', 'man genie', ['U+1F9DE', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧞‍♀️', 'woman_genie', 'woman genie', ['U+1F9DE', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧟', 'zombie', 'zombie', ['U+1F9DF']),
	Emoji('smileys_and_people', '🧟‍♂️', 'man_zombie', 'man zombie', ['U+1F9DF', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧟‍♀️', 'woman_zombie', 'woman zombie', ['U+1F9DF', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧌', 'troll', 'troll', ['U+1F9CC']),
	Emoji('smileys_and_people', '💆', 'person_getting_massage', 'person getting massage', ['U+1F486']),
	Emoji('smileys_and_people', '💆‍♂️', 'man_getting_massage', 'man getting massage', ['U+1F486', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '💆‍♀️', 'woman_getting_massage', 'woman getting massage', ['U+1F486', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '💇', 'person_getting_haircut', 'person getting haircut', ['U+1F487']),
	Emoji('smileys_and_people', '💇‍♂️', 'man_getting_haircut', 'man getting haircut', ['U+1F487', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '💇‍♀️', 'woman_getting_haircut', 'woman getting haircut', ['U+1F487', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🚶', 'person_walking', 'person walking', ['U+1F6B6']),
	Emoji('smileys_and_people', '🚶‍♂️', 'man_walking', 'man walking', ['U+1F6B6', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🚶‍♀️', 'woman_walking', 'woman walking', ['U+1F6B6', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧍', 'person_standing', 'person standing', ['U+1F9CD']),
	Emoji('smileys_and_people', '🧍‍♂️', 'man_standing', 'man standing', ['U+1F9CD', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧍‍♀️', 'woman_standing', 'woman standing', ['U+1F9CD', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧎', 'person_kneeling', 'person kneeling', ['U+1F9CE']),
	Emoji('smileys_and_people', '🧎‍♂️', 'man_kneeling', 'man kneeling', ['U+1F9CE', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧎‍♀️', 'woman_kneeling', 'woman kneeling', ['U+1F9CE', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧑‍🦯', 'person_with_white_cane', 'person with white cane', ['U+1F9D1', 'U+200D', 'U+1F9AF']),
	Emoji('smileys_and_people', '👨‍🦯', 'man_with_white_cane', 'man with white cane', ['U+1F468', 'U+200D', 'U+1F9AF']),
	Emoji('smileys_and_people', '👩‍🦯', 'woman_with_white_cane', 'woman with white cane', ['U+1F469', 'U+200D', 'U+1F9AF']),
	Emoji('smileys_and_people', '🧑‍🦼', 'person_in_motorized_wheelchair', 'person in motorized wheelchair', ['U+1F9D1', 'U+200D', 'U+1F9BC']),
	Emoji('smileys_and_people', '👨‍🦼', 'man_in_motorized_wheelchair', 'man in motorized wheelchair', ['U+1F468', 'U+200D', 'U+1F9BC']),
	Emoji('smileys_and_people', '👩‍🦼', 'woman_in_motorized_wheelchair', 'woman in motorized wheelchair', ['U+1F469', 'U+200D', 'U+1F9BC']),
	Emoji('smileys_and_people', '🧑‍🦽', 'person_in_manual_wheelchair', 'person in manual wheelchair', ['U+1F9D1', 'U+200D', 'U+1F9BD']),
	Emoji('smileys_and_people', '👨‍🦽', 'man_in_manual_wheelchair', 'man in manual wheelchair', ['U+1F468', 'U+200D', 'U+1F9BD']),
	Emoji('smileys_and_people', '👩‍🦽', 'woman_in_manual_wheelchair', 'woman in manual wheelchair', ['U+1F469', 'U+200D', 'U+1F9BD']),
	Emoji('smileys_and_people', '🏃', 'person_running', 'person running', ['U+1F3C3']),
	Emoji('smileys_and_people', '🏃‍♂️', 'man_running', 'man running', ['U+1F3C3', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🏃‍♀️', 'woman_running', 'woman running', ['U+1F3C3', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '💃', 'woman_dancing', 'woman dancing', ['U+1F483']),
	Emoji('smileys_and_people', '🕺', 'man_dancing', 'man dancing', ['U+1F57A']),
	Emoji('smileys_and_people', '🕴', 'person_in_suit_levitating', 'person in suit levitating', ['U+1F574']),
	Emoji('smileys_and_people', '👯', 'people_with_bunny_ears', 'people with bunny ears', ['U+1F46F']),
	Emoji('smileys_and_people', '👯‍♂️', 'men_with_bunny_ears', 'men with bunny ears', ['U+1F46F', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '👯‍♀️', 'women_with_bunny_ears', 'women with bunny ears', ['U+1F46F', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧖', 'person_in_steamy_room', 'person in steamy room', ['U+1F9D6']),
	Emoji('smileys_and_people', '🧖‍♂️', 'man_in_steamy_room', 'man in steamy room', ['U+1F9D6', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧖‍♀️', 'woman_in_steamy_room', 'woman in steamy room', ['U+1F9D6', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧗', 'person_climbing', 'person climbing', ['U+1F9D7']),
	Emoji('smileys_and_people', '🧗‍♂️', 'man_climbing', 'man climbing', ['U+1F9D7', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧗‍♀️', 'woman_climbing', 'woman climbing', ['U+1F9D7', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤺', 'person_fencing', 'person fencing', ['U+1F93A']),
	Emoji('smileys_and_people', '🏇', 'horse_racing', 'horse racing', ['U+1F3C7']),
	Emoji('smileys_and_people', '⛷', 'skier', 'skier', ['U+26F7']),
	Emoji('smileys_and_people', '🏂', 'snowboarder', 'snowboarder', ['U+1F3C2']),
	Emoji('smileys_and_people', '🏌', 'person_golfing', 'person golfing', ['U+1F3CC']),
	Emoji('smileys_and_people', '🏌️‍♂️', 'man_golfing', 'man golfing', ['U+1F3CC', 'U+FE0F', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🏌️‍♀️', 'woman_golfing', 'woman golfing', ['U+1F3CC', 'U+FE0F', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🏄', 'person_surfing', 'person surfing', ['U+1F3C4']),
	Emoji('smileys_and_people', '🏄‍♂️', 'man_surfing', 'man surfing', ['U+1F3C4', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🏄‍♀️', 'woman_surfing', 'woman surfing', ['U+1F3C4', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🚣', 'person_rowing_boat', 'person rowing boat', ['U+1F6A3']),
	Emoji('smileys_and_people', '🚣‍♂️', 'man_rowing_boat', 'man rowing boat', ['U+1F6A3', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🚣‍♀️', 'woman_rowing_boat', 'woman rowing boat', ['U+1F6A3', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🏊', 'person_swimming', 'person swimming', ['U+1F3CA']),
	Emoji('smileys_and_people', '🏊‍♂️', 'man_swimming', 'man swimming', ['U+1F3CA', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🏊‍♀️', 'woman_swimming', 'woman swimming', ['U+1F3CA', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '⛹', 'person_bouncing_ball', 'person bouncing ball', ['U+26F9']),
	Emoji('smileys_and_people', '⛹️‍♂️', 'man_bouncing_ball', 'man bouncing ball', ['U+26F9', 'U+FE0F', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '⛹️‍♀️', 'woman_bouncing_ball', 'woman bouncing ball', ['U+26F9', 'U+FE0F', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🏋', 'person_lifting_weights', 'person lifting weights', ['U+1F3CB']),
	Emoji('smileys_and_people', '🏋️‍♂️', 'man_lifting_weights', 'man lifting weights', ['U+1F3CB', 'U+FE0F', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🏋️‍♀️', 'woman_lifting_weights', 'woman lifting weights', ['U+1F3CB', 'U+FE0F', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🚴', 'person_biking', 'None', ['U+1F6B4']),
	Emoji('smileys_and_people', '🚴‍♂️', 'man_biking', 'None', ['U+1F6B4', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🚴‍♀️', 'woman_biking', 'woman biking', ['U+1F6B4', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🚵', 'person_mountain_biking', 'person mountain biking', ['U+1F6B5']),
	Emoji('smileys_and_people', '🚵‍♂️', 'man_mountain_biking', 'man mountain biking', ['U+1F6B5', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🚵‍♀️', 'woman_mountain_biking', 'woman mountain biking', ['U+1F6B5', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤸', 'person_cartwheeling', 'person cartwheeling', ['U+1F938']),
	Emoji('smileys_and_people', '🤸‍♂️', 'man_cartwheeling', 'man cartwheeling', ['U+1F938', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤸‍♀️', 'woman_cartwheeling', 'woman cartwheeling', ['U+1F938', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤼', 'people_wrestling', 'people wrestling', ['U+1F93C']),
	Emoji('smileys_and_people', '🤼‍♂️', 'men_wrestling', 'men wrestling', ['U+1F93C', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤼‍♀️', 'women_wrestling', 'women wrestling', ['U+1F93C', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤽', 'person_playing_water_polo', 'person playing water polo', ['U+1F93D']),
	Emoji('smileys_and_people', '🤽‍♂️', 'man_playing_water_polo', 'man playing water polo', ['U+1F93D', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤽‍♀️', 'woman_playing_water_polo', 'woman playing water polo', ['U+1F93D', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤾', 'person_playing_handball', 'person playing handball', ['U+1F93E']),
	Emoji('smileys_and_people', '🤾‍♂️', 'man_playing_handball', 'man playing handball', ['U+1F93E', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤾‍♀️', 'woman', 'woman ', ['U+1F93E', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🤹', 'person_juggling', 'person juggling', ['U+1F939']),
	Emoji('smileys_and_people', '🤹‍♂️', 'man_juggling', 'man juggling', ['U+1F939', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🤹‍♀️', 'woman_juggling', 'woman juggling', ['U+1F939', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🧘', 'person_in_lotus_position', 'person in lotus position', ['U+1F9D8']),
	Emoji('smileys_and_people', '🧘‍♂️', 'man_in_lotus_position', 'man in lotus position', ['U+1F9D8', 'U+200D', 'U+2642', 'U+FE0F']),
	Emoji('smileys_and_people', '🧘‍♀️', 'woman_in_lotus_position', 'woman in lotus position', ['U+1F9D8', 'U+200D', 'U+2640', 'U+FE0F']),
	Emoji('smileys_and_people', '🛀', 'person_taking_bath', 'person taking bath', ['U+1F6C0']),
	Emoji('smileys_and_people', '🛌', 'person_in_bed', 'person in bed', ['U+1F6CC']),
	Emoji('smileys_and_people', '🧑‍🤝‍🧑', 'people_holding_hands', 'people holding hands', ['U+1F9D1', 'U+200D', 'U+1F91D', 'U+200D', 'U+1F9D1']),
	Emoji('smileys_and_people', '👭', 'women_holding_hands', 'women holding hands', ['U+1F46D']),
	Emoji('smileys_and_people', '👫', 'woman_and_man_holding_hands', 'woman and man holding hands', ['U+1F46B']),
	Emoji('smileys_and_people', '👬', 'men_holding_hands', 'men holding hands', ['U+1F46C']),
	Emoji('smileys_and_people', '💏', 'kiss', 'kiss', ['U+1F48F']),
	Emoji('smileys_and_people', '👩‍❤️‍💋‍👨', 'kiss_woman_man', 'kiss: woman, man', ['U+1F469', 'U+200D', 'U+2764', 'U+FE0F', 'U+200D', 'U+1F48B', 'U+200D', 'U+1F468']),
	Emoji('smileys_and_people', '👨‍❤️‍💋‍👨', 'kiss_man_man', 'kiss: man, man', ['U+1F468', 'U+200D', 'U+2764', 'U+FE0F', 'U+200D', 'U+1F48B', 'U+200D', 'U+1F468']),
	Emoji('smileys_and_people', '👩‍❤️‍💋‍👩', 'kiss_woman_woman', 'kiss: woman, woman', ['U+1F469', 'U+200D', 'U+2764', 'U+FE0F', 'U+200D', 'U+1F48B', 'U+200D', 'U+1F469']),
	Emoji('smileys_and_people', '💑', 'couple_with_heart', 'couple with heart', ['U+1F491']),
	Emoji('smileys_and_people', '👩‍❤️‍👨', 'couple_with_heart_woman_man', 'couple with heart: woman, man', ['U+1F469', 'U+200D', 'U+2764', 'U+FE0F', 'U+200D', 'U+1F468']),
	Emoji('smileys_and_people', '👨‍❤️‍👨', 'couple_with_heart_man_man', 'couple with heart: man, man', ['U+1F468', 'U+200D', 'U+2764', 'U+FE0F', 'U+200D', 'U+1F468']),
	Emoji('smileys_and_people', '👩‍❤️‍👩', 'couple_with_heart_woman_woman', 'couple with heart: woman, woman', ['U+1F469', 'U+200D', 'U+2764', 'U+FE0F', 'U+200D', 'U+1F469']),
	Emoji('smileys_and_people', '👪', 'family', 'family', ['U+1F46A']),
	Emoji('smileys_and_people', '👨‍👩‍👦', 'family_man_woman_boy', 'family: man, woman, boy', ['U+1F468', 'U+200D', 'U+1F469', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👩‍👧', 'family_man_woman_girl', 'family: man, woman, girl', ['U+1F468', 'U+200D', 'U+1F469', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👨‍👩‍👧‍👦', 'family_man_woman_girl_boy', 'family: man, woman, girl, boy', ['U+1F468', 'U+200D', 'U+1F469', 'U+200D', 'U+1F467', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👩‍👦‍👦', 'family_man_woman_boy_boy', 'family: man, woman, boy, boy', ['U+1F468', 'U+200D', 'U+1F469', 'U+200D', 'U+1F466', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👩‍👧‍👧', 'family_man_woman_girl_girl', 'family: man, woman, girl, girl', ['U+1F468', 'U+200D', 'U+1F469', 'U+200D', 'U+1F467', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👨‍👨‍👦', 'family_man_man_boy', 'family: man, man, boy', ['U+1F468', 'U+200D', 'U+1F468', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👨‍👧', 'family_man', 'family: man, ', ['U+1F468', 'U+200D', 'U+1F468', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👨‍👨‍👧‍👦', 'family_man_man_girl_boy', 'family: man, man, girl, boy', ['U+1F468', 'U+200D', 'U+1F468', 'U+200D', 'U+1F467', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👨‍👦‍👦', 'family_man_man_boy_boy', 'family: man, man, boy, boy', ['U+1F468', 'U+200D', 'U+1F468', 'U+200D', 'U+1F466', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👨‍👧‍👧', 'family_man_man_girl_girl', 'family: man, man, girl, girl', ['U+1F468', 'U+200D', 'U+1F468', 'U+200D', 'U+1F467', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👩‍👩‍👦', 'family_woman_woman_boy', 'family: woman, woman, boy', ['U+1F469', 'U+200D', 'U+1F469', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👩‍👩‍👧', 'family_woman_woman_girl', 'family: woman, woman, girl', ['U+1F469', 'U+200D', 'U+1F469', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👩‍👩‍👧‍👦', 'family_woman_woman_girl_boy', 'family: woman, woman, girl, boy', ['U+1F469', 'U+200D', 'U+1F469', 'U+200D', 'U+1F467', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👩‍👩‍👦‍👦', 'family_woman_woman_boy_boy', 'family: woman, woman, boy, boy', ['U+1F469', 'U+200D', 'U+1F469', 'U+200D', 'U+1F466', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👩‍👩‍👧‍👧', 'family_woman_woman_girl_girl', 'family: woman, woman, girl, girl', ['U+1F469', 'U+200D', 'U+1F469', 'U+200D', 'U+1F467', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👨‍👦', 'family_man_boy', 'family: man, boy', ['U+1F468', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👦‍👦', 'family_man_boy_boy', 'family: man, boy, boy', ['U+1F468', 'U+200D', 'U+1F466', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👧', 'family_man_girl', 'family: man, girl', ['U+1F468', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👨‍👧‍👦', 'family_man_girl_boy', 'family: man, girl, boy', ['U+1F468', 'U+200D', 'U+1F467', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👨‍👧‍👧', 'family_man_girl_girl', 'family: man, girl, girl', ['U+1F468', 'U+200D', 'U+1F467', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👩‍👦', 'family_woman_boy', 'family: woman, boy', ['U+1F469', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👩‍👦‍👦', 'family_woman_boy_boy', 'family: woman, boy, boy', ['U+1F469', 'U+200D', 'U+1F466', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👩‍👧', 'family_woman_girl', 'family: woman, girl', ['U+1F469', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '👩‍👧‍👦', 'family_woman_girl_boy', 'family: woman, girl, boy', ['U+1F469', 'U+200D', 'U+1F467', 'U+200D', 'U+1F466']),
	Emoji('smileys_and_people', '👩‍👧‍👧', 'family_woman_girl_girl', 'family: woman, girl, girl', ['U+1F469', 'U+200D', 'U+1F467', 'U+200D', 'U+1F467']),
	Emoji('smileys_and_people', '🗣', 'speaking_head', 'speaking head', ['U+1F5E3']),
	Emoji('smileys_and_people', '👤', 'bust_in_silhouette', 'bust in silhouette', ['U+1F464']),
	Emoji('smileys_and_people', '👥', 'busts_in_silhouette', 'busts in silhouette', ['U+1F465']),
	Emoji('smileys_and_people', '🫂', 'people_hugging', 'people hugging', ['U+1FAC2']),
	Emoji('smileys_and_people', '👣', 'footprints', 'footprints', ['U+1F463']),
	Emoji('smileys_and_people', '🦰', 'red_hair', 'red hair', ['U+1F9B0']),
	Emoji('smileys_and_people', '🦱', 'curly_hair', 'curly hair', ['U+1F9B1']),
	Emoji('smileys_and_people', '🦳', 'white_hair', 'white hair', ['U+1F9B3']),
	Emoji('smileys_and_people', '🦲', 'bald', 'bald', ['U+1F9B2']),

	## » 527 Emojis found in smileys_and_people category « ##

	Emoji('animals_and_nature', '🐵', 'monkey_face', 'monkey face', ['U+1F435']),
	Emoji('animals_and_nature', '🐒', 'monkey', 'monkey', ['U+1F412']),
	Emoji('animals_and_nature', '🦍', 'gorilla', 'gorilla', ['U+1F98D']),
	Emoji('animals_and_nature', '🦧', 'orangutan', 'orangutan', ['U+1F9A7']),
	Emoji('animals_and_nature', '🐶', 'dog_face', 'dog face', ['U+1F436']),
	Emoji('animals_and_nature', '🐕', 'dog', 'dog', ['U+1F415']),
	Emoji('animals_and_nature', '🦮', 'guide_dog', 'guide dog', ['U+1F9AE']),
	Emoji('animals_and_nature', '🐕‍🦺', 'service_dog', 'service dog', ['U+1F415', 'U+200D', 'U+1F9BA']),
	Emoji('animals_and_nature', '🐩', 'poodle', 'poodle', ['U+1F429']),
	Emoji('animals_and_nature', '🐺', 'wolf', 'wolf', ['U+1F43A']),
	Emoji('animals_and_nature', '🦊', 'fox', 'fox', ['U+1F98A']),
	Emoji('animals_and_nature', '🦝', 'raccoon', 'raccoon', ['U+1F99D']),
	Emoji('animals_and_nature', '🐱', 'cat_face', 'cat face', ['U+1F431']),
	Emoji('animals_and_nature', '🐈', 'cat', 'cat', ['U+1F408']),
	Emoji('animals_and_nature', '🐈‍⬛', 'black_cat', 'black cat', ['U+1F408', 'U+200D', 'U+2B1B']),
	Emoji('animals_and_nature', '🦁', 'lion', 'lion', ['U+1F981']),
	Emoji('animals_and_nature', '🐯', 'tiger_face', 'tiger face', ['U+1F42F']),
	Emoji('animals_and_nature', '🐅', 'tiger', 'tiger', ['U+1F405']),
	Emoji('animals_and_nature', '🐆', 'leopard', 'leopard', ['U+1F406']),
	Emoji('animals_and_nature', '🐴', 'horse_face', 'horse face', ['U+1F434']),
	Emoji('animals_and_nature', '🐎', 'horse', 'horse', ['U+1F40E']),
	Emoji('animals_and_nature', '🦄', 'unicorn', 'unicorn', ['U+1F984']),
	Emoji('animals_and_nature', '🦓', 'zebra', 'zebra', ['U+1F993']),
	Emoji('animals_and_nature', '🦌', 'deer', 'deer', ['U+1F98C']),
	Emoji('animals_and_nature', '🦬', 'bison', 'bison', ['U+1F9AC']),
	Emoji('animals_and_nature', '🐮', 'cow_face', 'cow face', ['U+1F42E']),
	Emoji('animals_and_nature', '🐂', 'ox', 'ox', ['U+1F402']),
	Emoji('animals_and_nature', '🐃', 'water_buffalo', 'water buffalo', ['U+1F403']),
	Emoji('animals_and_nature', '🐄', 'cow', 'cow', ['U+1F404']),
	Emoji('animals_and_nature', '🐷', 'pig_face', 'pig face', ['U+1F437']),
	Emoji('animals_and_nature', '🐖', 'pig', 'pig', ['U+1F416']),
	Emoji('animals_and_nature', '🐗', 'boar', 'boar', ['U+1F417']),
	Emoji('animals_and_nature', '🐽', 'pig_nose', 'pig nose', ['U+1F43D']),
	Emoji('animals_and_nature', '🐏', 'ram', 'ram', ['U+1F40F']),
	Emoji('animals_and_nature', '🐑', 'ewe', 'ewe', ['U+1F411']),
	Emoji('animals_and_nature', '🐐', 'goat', 'goat', ['U+1F410']),
	Emoji('animals_and_nature', '🐪', 'camel', 'camel', ['U+1F42A']),
	Emoji('animals_and_nature', '🐫', 'two_hump_camel', 'two-hump camel', ['U+1F42B']),
	Emoji('animals_and_nature', '🦙', 'llama', 'llama', ['U+1F999']),
	Emoji('animals_and_nature', '🦒', 'giraffe', 'giraffe', ['U+1F992']),
	Emoji('animals_and_nature', '🐘', 'elephant', 'elephant', ['U+1F418']),
	Emoji('animals_and_nature', '🦣', 'mammoth', 'mammoth', ['U+1F9A3']),
	Emoji('animals_and_nature', '🦏', 'rhinoceros', 'rhinoceros', ['U+1F98F']),
	Emoji('animals_and_nature', '🦛', 'hippopotamus', 'hippopotamus', ['U+1F99B']),
	Emoji('animals_and_nature', '🐭', 'mouse_face', 'mouse face', ['U+1F42D']),
	Emoji('animals_and_nature', '🐁', 'mouse', 'mouse', ['U+1F401']),
	Emoji('animals_and_nature', '🐀', 'rat', 'rat', ['U+1F400']),
	Emoji('animals_and_nature', '🐹', 'hamster', 'hamster', ['U+1F439']),
	Emoji('animals_and_nature', '🐰', 'rabbit_face', 'rabbit face', ['U+1F430']),
	Emoji('animals_and_nature', '🐇', 'rabbit', 'rabbit', ['U+1F407']),
	Emoji('animals_and_nature', '🐿', 'chipmunk', 'chipmunk', ['U+1F43F']),
	Emoji('animals_and_nature', '🦫', 'beaver', 'beaver', ['U+1F9AB']),
	Emoji('animals_and_nature', '🦔', 'hedgehog', 'hedgehog', ['U+1F994']),
	Emoji('animals_and_nature', '🦇', 'bat', 'bat', ['U+1F987']),
	Emoji('animals_and_nature', '🐻', 'bear', 'bear', ['U+1F43B']),
	Emoji('animals_and_nature', '🐻‍❄️', 'polar_bear', 'polar bear', ['U+1F43B', 'U+200D', 'U+2744', 'U+FE0F']),
	Emoji('animals_and_nature', '🐨', 'koala', 'koala', ['U+1F428']),
	Emoji('animals_and_nature', '🐼', 'panda', 'panda', ['U+1F43C']),
	Emoji('animals_and_nature', '🦥', 'sloth', 'sloth', ['U+1F9A5']),
	Emoji('animals_and_nature', '🦦', 'otter', 'otter', ['U+1F9A6']),
	Emoji('animals_and_nature', '🦨', 'skunk', 'skunk', ['U+1F9A8']),
	Emoji('animals_and_nature', '🦘', 'kangaroo', 'kangaroo', ['U+1F998']),
	Emoji('animals_and_nature', '🦡', 'badger', 'badger', ['U+1F9A1']),
	Emoji('animals_and_nature', '🐾', 'paw_prints', 'paw prints', ['U+1F43E']),
	Emoji('animals_and_nature', '🦃', 'turkey', 'turkey', ['U+1F983']),
	Emoji('animals_and_nature', '🐔', 'chicken', 'chicken', ['U+1F414']),
	Emoji('animals_and_nature', '🐓', 'rooster', 'rooster', ['U+1F413']),
	Emoji('animals_and_nature', '🐣', 'hatching_chick', 'hatching chick', ['U+1F423']),
	Emoji('animals_and_nature', '🐤', 'baby_chick', 'baby chick', ['U+1F424']),
	Emoji('animals_and_nature', '🐥', 'front_facing_baby_chick', 'front-facing baby chick', ['U+1F425']),
	Emoji('animals_and_nature', '🐦', 'bird', 'bird', ['U+1F426']),
	Emoji('animals_and_nature', '🐧', 'penguin', 'penguin', ['U+1F427']),
	Emoji('animals_and_nature', '🕊', 'dove', 'dove', ['U+1F54A']),
	Emoji('animals_and_nature', '🦅', 'eagle', 'eagle', ['U+1F985']),
	Emoji('animals_and_nature', '🦆', 'duck', 'duck', ['U+1F986']),
	Emoji('animals_and_nature', '🦢', 'swan', 'swan', ['U+1F9A2']),
	Emoji('animals_and_nature', '🦉', 'owl', 'owl', ['U+1F989']),
	Emoji('animals_and_nature', '🦤', 'dodo', 'dodo', ['U+1F9A4']),
	Emoji('animals_and_nature', '🪶', 'feather', 'feather', ['U+1FAB6']),
	Emoji('animals_and_nature', '🦩', 'flamingo', 'flamingo', ['U+1F9A9']),
	Emoji('animals_and_nature', '🦚', 'peacock', 'peacock', ['U+1F99A']),
	Emoji('animals_and_nature', '🦜', 'parrot', 'parrot', ['U+1F99C']),
	Emoji('animals_and_nature', '🐸', 'frog', 'frog', ['U+1F438']),
	Emoji('animals_and_nature', '🐊', 'crocodile', 'crocodile', ['U+1F40A']),
	Emoji('animals_and_nature', '🐢', 'turtle', 'turtle', ['U+1F422']),
	Emoji('animals_and_nature', '🦎', 'lizard', 'lizard', ['U+1F98E']),
	Emoji('animals_and_nature', '🐍', 'snake', 'snake', ['U+1F40D']),
	Emoji('animals_and_nature', '🐲', 'dragon_face', 'dragon face', ['U+1F432']),
	Emoji('animals_and_nature', '🐉', 'dragon', 'dragon', ['U+1F409']),
	Emoji('animals_and_nature', '🦕', 'sauropod', 'sauropod', ['U+1F995']),
	Emoji('animals_and_nature', '🦖', 't_rex', 't-rex', ['U+1F996']),
	Emoji('animals_and_nature', '🐳', 'spouting_whale', 'spouting whale', ['U+1F433']),
	Emoji('animals_and_nature', '🐋', 'whale', 'whale', ['U+1F40B']),
	Emoji('animals_and_nature', '🐬', 'dolphin', 'dolphin', ['U+1F42C']),
	Emoji('animals_and_nature', '🦭', 'seal', 'seal', ['U+1F9AD']),
	Emoji('animals_and_nature', '🐟', 'fish', 'fish', ['U+1F41F']),
	Emoji('animals_and_nature', '🐠', 'tropical_fish', 'tropical fish', ['U+1F420']),
	Emoji('animals_and_nature', '🐡', 'blowfish', 'blowfish', ['U+1F421']),
	Emoji('animals_and_nature', '🦈', 'shark', 'shark', ['U+1F988']),
	Emoji('animals_and_nature', '🐙', 'octopus', 'octopus', ['U+1F419']),
	Emoji('animals_and_nature', '🐚', 'spiral_shell', 'spiral shell', ['U+1F41A']),
	Emoji('animals_and_nature', '🐌', 'snail', 'None', ['U+1F40C']),
	Emoji('animals_and_nature', '🦋', 'butterfly', 'butterfly', ['U+1F98B']),
	Emoji('animals_and_nature', '🐛', 'bug', 'bug', ['U+1F41B']),
	Emoji('animals_and_nature', '🐜', 'ant', 'ant', ['U+1F41C']),
	Emoji('animals_and_nature', '🐝', 'honeybee', 'honeybee', ['U+1F41D']),
	Emoji('animals_and_nature', '🪲', 'beetle', 'beetle', ['U+1FAB2']),
	Emoji('animals_and_nature', '🐞', 'lady_beetle', 'lady beetle', ['U+1F41E']),
	Emoji('animals_and_nature', '🦗', 'cricket', 'cricket', ['U+1F997']),
	Emoji('animals_and_nature', '🪳', 'cockroach', 'cockroach', ['U+1FAB3']),
	Emoji('animals_and_nature', '🕷', 'spider', 'spider', ['U+1F577']),
	Emoji('animals_and_nature', '🕸', 'spider_web', 'spider web', ['U+1F578']),
	Emoji('animals_and_nature', '🦂', 'scorpion', 'scorpion', ['U+1F982']),
	Emoji('animals_and_nature', '🦟', 'mosquito', 'mosquito', ['U+1F99F']),
	Emoji('animals_and_nature', '🪰', 'fly', 'fly', ['U+1FAB0']),
	Emoji('animals_and_nature', '🪱', 'worm', 'worm', ['U+1FAB1']),
	Emoji('animals_and_nature', '🦠', 'microbe', 'microbe', ['U+1F9A0']),
	Emoji('animals_and_nature', '💐', 'bouquet', 'bouquet', ['U+1F490']),
	Emoji('animals_and_nature', '🌸', 'cherry_blossom', 'cherry blossom', ['U+1F338']),
	Emoji('animals_and_nature', '💮', 'white_flower', 'white flower', ['U+1F4AE']),
	Emoji('animals_and_nature', '🪷', 'lotus', 'lotus', ['U+1FAB7']),
	Emoji('animals_and_nature', '🏵', 'rosette', 'rosette', ['U+1F3F5']),
	Emoji('animals_and_nature', '🌹', 'rose', 'rose', ['U+1F339']),
	Emoji('animals_and_nature', '🥀', 'wilted_flower', 'wilted flower', ['U+1F940']),
	Emoji('animals_and_nature', '🌺', 'hibiscus', 'hibiscus', ['U+1F33A']),
	Emoji('animals_and_nature', '🌻', 'sunflower', 'sunflower', ['U+1F33B']),
	Emoji('animals_and_nature', '🌼', 'blossom', 'blossom', ['U+1F33C']),
	Emoji('animals_and_nature', '🌷', 'tulip', 'tulip', ['U+1F337']),
	Emoji('animals_and_nature', '🌱', 'seedling', 'seedling', ['U+1F331']),
	Emoji('animals_and_nature', '🪴', 'potted_plant', 'potted plant', ['U+1FAB4']),
	Emoji('animals_and_nature', '🌲', 'evergreen_tree', 'evergreen tree', ['U+1F332']),
	Emoji('animals_and_nature', '🌳', 'deciduous_tree', 'deciduous tree', ['U+1F333']),
	Emoji('animals_and_nature', '🌴', 'palm_tree', 'palm tree', ['U+1F334']),
	Emoji('animals_and_nature', '🌵', 'cactus', 'cactus', ['U+1F335']),
	Emoji('animals_and_nature', '🌾', 'sheaf_of_rice', 'sheaf of rice', ['U+1F33E']),
	Emoji('animals_and_nature', '🌿', 'herb', 'herb', ['U+1F33F']),
	Emoji('animals_and_nature', '☘', 'shamrock', 'shamrock', ['U+2618']),
	Emoji('animals_and_nature', '🍀', 'four_leaf_clover', 'four leaf clover', ['U+1F340']),
	Emoji('animals_and_nature', '🍁', 'maple_leaf', 'maple leaf', ['U+1F341']),
	Emoji('animals_and_nature', '🍂', 'fallen_leaf', 'fallen leaf', ['U+1F342']),
	Emoji('animals_and_nature', '🍃', 'leaf_fluttering_in_wind', 'leaf fluttering in wind', ['U+1F343']),
	Emoji('animals_and_nature', '🪹', 'empty_nest', 'empty nest', ['U+1FAB9']),
	Emoji('animals_and_nature', '🪺', 'nest_with_eggs', 'nest with eggs', ['U+1FABA']),
	Emoji('animals_and_nature', '🍄', 'mushroom', 'mushroom', ['U+1F344']),

	## » 144 Emojis found in animals_and_nature category « ##

	Emoji('food_and_drink', '🍇', 'grapes', 'grapes', ['U+1F347']),
	Emoji('food_and_drink', '🍈', 'melon', 'melon', ['U+1F348']),
	Emoji('food_and_drink', '🍉', 'watermelon', 'watermelon', ['U+1F349']),
	Emoji('food_and_drink', '🍊', 'tangerine', 'tangerine', ['U+1F34A']),
	Emoji('food_and_drink', '🍋', 'lemon', 'lemon', ['U+1F34B']),
	Emoji('food_and_drink', '🍌', 'banana', 'banana', ['U+1F34C']),
	Emoji('food_and_drink', '🍍', 'pineapple', 'pineapple', ['U+1F34D']),
	Emoji('food_and_drink', '🥭', 'mango', 'mango', ['U+1F96D']),
	Emoji('food_and_drink', '🍎', 'red_apple', 'red apple', ['U+1F34E']),
	Emoji('food_and_drink', '🍏', 'green_apple', 'green apple', ['U+1F34F']),
	Emoji('food_and_drink', '🍐', 'pear', 'pear', ['U+1F350']),
	Emoji('food_and_drink', '🍑', 'peach', 'peach', ['U+1F351']),
	Emoji('food_and_drink', '🍒', 'cherries', 'cherries', ['U+1F352']),
	Emoji('food_and_drink', '🍓', 'strawberry', 'strawberry', ['U+1F353']),
	Emoji('food_and_drink', '🫐', 'blueberries', 'blueberries', ['U+1FAD0']),
	Emoji('food_and_drink', '🥝', 'kiwi_fruit', 'kiwi fruit', ['U+1F95D']),
	Emoji('food_and_drink', '🍅', 'tomato', 'tomato', ['U+1F345']),
	Emoji('food_and_drink', '🫒', 'olive', 'olive', ['U+1FAD2']),
	Emoji('food_and_drink', '🥥', 'coconut', 'coconut', ['U+1F965']),
	Emoji('food_and_drink', '🥑', 'avocado', 'avocado', ['U+1F951']),
	Emoji('food_and_drink', '🍆', 'eggplant', 'eggplant', ['U+1F346']),
	Emoji('food_and_drink', '🥔', 'potato', 'potato', ['U+1F954']),
	Emoji('food_and_drink', '🥕', 'carrot', 'carrot', ['U+1F955']),
	Emoji('food_and_drink', '🌽', 'ear_of_corn', 'ear of corn', ['U+1F33D']),
	Emoji('food_and_drink', '🌶', 'hot_pepper', 'hot pepper', ['U+1F336']),
	Emoji('food_and_drink', '🫑', 'bell_pepper', 'bell pepper', ['U+1FAD1']),
	Emoji('food_and_drink', '🥒', 'cucumber', 'cucumber', ['U+1F952']),
	Emoji('food_and_drink', '🥬', 'leafy_green', 'leafy green', ['U+1F96C']),
	Emoji('food_and_drink', '🥦', 'broccoli', 'broccoli', ['U+1F966']),
	Emoji('food_and_drink', '🧄', 'garlic', 'garlic', ['U+1F9C4']),
	Emoji('food_and_drink', '🧅', 'onion', 'onion', ['U+1F9C5']),
	Emoji('food_and_drink', '🥜', 'peanuts', 'peanuts', ['U+1F95C']),
	Emoji('food_and_drink', '🫘', 'beans', 'beans', ['U+1FAD8']),
	Emoji('food_and_drink', '🌰', 'chestnut', 'chestnut', ['U+1F330']),
	Emoji('food_and_drink', '🍞', 'bread', 'bread', ['U+1F35E']),
	Emoji('food_and_drink', '🥐', 'croissant', 'croissant', ['U+1F950']),
	Emoji('food_and_drink', '🥖', 'baguette_bread', 'baguette bread', ['U+1F956']),
	Emoji('food_and_drink', '🫓', 'flatbread', 'flatbread', ['U+1FAD3']),
	Emoji('food_and_drink', '🥨', 'pretzel', 'pretzel', ['U+1F968']),
	Emoji('food_and_drink', '🥯', 'bagel', 'bagel', ['U+1F96F']),
	Emoji('food_and_drink', '🥞', 'pancakes', 'pancakes', ['U+1F95E']),
	Emoji('food_and_drink', '🧇', 'waffle', 'waffle', ['U+1F9C7']),
	Emoji('food_and_drink', '🧀', 'cheese_wedge', 'cheese wedge', ['U+1F9C0']),
	Emoji('food_and_drink', '🍖', 'meat_on_bone', 'meat on bone', ['U+1F356']),
	Emoji('food_and_drink', '🍗', 'poultry_leg', 'poultry leg', ['U+1F357']),
	Emoji('food_and_drink', '🥩', 'cut_of_meat', 'cut of meat', ['U+1F969']),
	Emoji('food_and_drink', '🥓', 'bacon', 'bacon', ['U+1F953']),
	Emoji('food_and_drink', '🍔', 'hamburger', 'hamburger', ['U+1F354']),
	Emoji('food_and_drink', '🍟', 'french_fries', 'french fries', ['U+1F35F']),
	Emoji('food_and_drink', '🍕', 'pizza', 'pizza', ['U+1F355']),
	Emoji('food_and_drink', '🌭', 'hot_dog', 'hot dog', ['U+1F32D']),
	Emoji('food_and_drink', '🥪', 'sandwich', 'sandwich', ['U+1F96A']),
	Emoji('food_and_drink', '🌮', 'taco', 'taco', ['U+1F32E']),
	Emoji('food_and_drink', '🌯', 'burrito', 'burrito', ['U+1F32F']),
	Emoji('food_and_drink', '🫔', 'tamale', 'tamale', ['U+1FAD4']),
	Emoji('food_and_drink', '🥙', 'stuffed_flatbread', 'stuffed flatbread', ['U+1F959']),
	Emoji('food_and_drink', '🧆', 'falafel', 'falafel', ['U+1F9C6']),
	Emoji('food_and_drink', '🥚', 'egg', 'egg', ['U+1F95A']),
	Emoji('food_and_drink', '🍳', 'cooking', 'cooking', ['U+1F373']),
	Emoji('food_and_drink', '🥘', 'shallow_pan_of_food', 'shallow pan of food', ['U+1F958']),
	Emoji('food_and_drink', '🍲', 'pot_of_food', 'pot of food', ['U+1F372']),
	Emoji('food_and_drink', '🫕', 'fondue', 'fondue', ['U+1FAD5']),
	Emoji('food_and_drink', '🥣', 'bowl_with_spoon', 'bowl with spoon', ['U+1F963']),
	Emoji('food_and_drink', '🥗', 'green_salad', 'green salad', ['U+1F957']),
	Emoji('food_and_drink', '🍿', 'popcorn', 'popcorn', ['U+1F37F']),
	Emoji('food_and_drink', '🧈', 'butter', 'butter', ['U+1F9C8']),
	Emoji('food_and_drink', '🧂', 'salt', 'salt', ['U+1F9C2']),
	Emoji('food_and_drink', '🥫', 'canned_food', 'canned food', ['U+1F96B']),
	Emoji('food_and_drink', '🍱', 'bento_box', 'bento box', ['U+1F371']),
	Emoji('food_and_drink', '🍘', 'rice_cracker', 'rice cracker', ['U+1F358']),
	Emoji('food_and_drink', '🍙', 'rice_ball', 'rice ball', ['U+1F359']),
	Emoji('food_and_drink', '🍚', 'cooked_rice', 'cooked rice', ['U+1F35A']),
	Emoji('food_and_drink', '🍛', 'curry_rice', 'curry rice', ['U+1F35B']),
	Emoji('food_and_drink', '🍜', 'steaming_bowl', 'steaming bowl', ['U+1F35C']),
	Emoji('food_and_drink', '🍝', 'spaghetti', 'spaghetti', ['U+1F35D']),
	Emoji('food_and_drink', '🍠', 'roasted_sweet_potato', 'roasted sweet potato', ['U+1F360']),
	Emoji('food_and_drink', '🍢', 'oden', 'oden', ['U+1F362']),
	Emoji('food_and_drink', '🍣', 'sushi', 'sushi', ['U+1F363']),
	Emoji('food_and_drink', '🍤', 'fried_shrimp', 'fried shrimp', ['U+1F364']),
	Emoji('food_and_drink', '🍥', 'fish_cake_with_swirl', 'fish cake with swirl', ['U+1F365']),
	Emoji('food_and_drink', '🥮', 'moon_cake', 'moon cake', ['U+1F96E']),
	Emoji('food_and_drink', '🍡', 'dango', 'dango', ['U+1F361']),
	Emoji('food_and_drink', '🥟', 'dumpling', 'dumpling', ['U+1F95F']),
	Emoji('food_and_drink', '🥠', 'fortune_cookie', 'fortune cookie', ['U+1F960']),
	Emoji('food_and_drink', '🥡', 'takeout_box', 'takeout box', ['U+1F961']),
	Emoji('food_and_drink', '🦀', 'crab', 'crab', ['U+1F980']),
	Emoji('food_and_drink', '🦞', 'lobster', 'lobster', ['U+1F99E']),
	Emoji('food_and_drink', '🦐', 'shrimp', 'shrimp', ['U+1F990']),
	Emoji('food_and_drink', '🦑', 'squid', 'squid', ['U+1F991']),
	Emoji('food_and_drink', '🦪', 'oyster', 'oyster', ['U+1F9AA']),
	Emoji('food_and_drink', '🍦', 'soft_ice_cream', 'soft ice cream', ['U+1F366']),
	Emoji('food_and_drink', '🍧', 'shaved_ice', 'shaved ice', ['U+1F367']),
	Emoji('food_and_drink', '🍨', 'ice_cream', 'ice cream', ['U+1F368']),
	Emoji('food_and_drink', '🍩', 'doughnut', 'doughnut', ['U+1F369']),
	Emoji('food_and_drink', '🍪', 'cookie', 'cookie', ['U+1F36A']),
	Emoji('food_and_drink', '🎂', 'birthday_cake', 'birthday cake', ['U+1F382']),
	Emoji('food_and_drink', '🍰', 'shortcake', 'shortcake', ['U+1F370']),
	Emoji('food_and_drink', '🧁', 'cupcake', 'cupcake', ['U+1F9C1']),
	Emoji('food_and_drink', '🥧', 'pie', 'pie', ['U+1F967']),
	Emoji('food_and_drink', '🍫', 'chocolate_bar', 'chocolate bar', ['U+1F36B']),
	Emoji('food_and_drink', '🍬', 'candy', 'candy', ['U+1F36C']),
	Emoji('food_and_drink', '🍭', 'lollipop', 'lollipop', ['U+1F36D']),
	Emoji('food_and_drink', '🍮', 'custard', 'custard', ['U+1F36E']),
	Emoji('food_and_drink', '🍯', 'honey_pot', 'honey pot', ['U+1F36F']),
	Emoji('food_and_drink', '🍼', 'baby_bottle', 'baby bottle', ['U+1F37C']),
	Emoji('food_and_drink', '🥛', 'glass_of_milk', 'glass of milk', ['U+1F95B']),
	Emoji('food_and_drink', '☕', 'hot_beverage', 'hot beverage', ['U+2615']),
	Emoji('food_and_drink', '🫖', 'teapot', 'teapot', ['U+1FAD6']),
	Emoji('food_and_drink', '🍵', 'teacup_without_handle', 'teacup without handle', ['U+1F375']),
	Emoji('food_and_drink', '🍶', 'sake', 'sake', ['U+1F376']),
	Emoji('food_and_drink', '🍾', 'bottle_with_popping_cork', 'bottle with popping cork', ['U+1F37E']),
	Emoji('food_and_drink', '🍷', 'wine_glass', 'wine glass', ['U+1F377']),
	Emoji('food_and_drink', '🍸', 'cocktail_glass', 'cocktail glass', ['U+1F378']),
	Emoji('food_and_drink', '🍹', 'tropical_drink', 'tropical drink', ['U+1F379']),
	Emoji('food_and_drink', '🍺', 'beer_mug', 'beer mug', ['U+1F37A']),
	Emoji('food_and_drink', '🍻', 'clinking_beer_mugs', 'clinking beer mugs', ['U+1F37B']),
	Emoji('food_and_drink', '🥂', 'clinking_glasses', 'clinking glasses', ['U+1F942']),
	Emoji('food_and_drink', '🥃', 'tumbler_glass', 'tumbler glass', ['U+1F943']),
	Emoji('food_and_drink', '🫗', 'pouring_liquid', 'pouring liquid', ['U+1FAD7']),
	Emoji('food_and_drink', '🥤', 'cup_with_straw', 'cup with straw', ['U+1F964']),
	Emoji('food_and_drink', '🧋', 'bubble_tea', 'bubble tea', ['U+1F9CB']),
	Emoji('food_and_drink', '🧃', 'beverage_box', 'beverage box', ['U+1F9C3']),
	Emoji('food_and_drink', '🧉', 'mate', 'mate', ['U+1F9C9']),
	Emoji('food_and_drink', '🧊', 'ice', 'ice', ['U+1F9CA']),
	Emoji('food_and_drink', '🥢', 'chopsticks', 'chopsticks', ['U+1F962']),
	Emoji('food_and_drink', '🍽', 'fork_and_knife_with_plate', 'fork and knife with plate', ['U+1F37D']),
	Emoji('food_and_drink', '🍴', 'fork_and_knife', 'fork and knife', ['U+1F374']),
	Emoji('food_and_drink', '🥄', 'spoon', 'spoon', ['U+1F944']),
	Emoji('food_and_drink', '🔪', 'kitchen_knife', 'kitchen knife', ['U+1F52A']),
	Emoji('food_and_drink', '🫙', 'jar', 'jar', ['U+1FAD9']),
	Emoji('food_and_drink', '🏺', 'amphora', 'amphora', ['U+1F3FA']),

	## » 131 Emojis found in food_and_drink category « ##

	Emoji('travel_and_places', '🌍', 'globe_showing_europe_africa', 'globe showing Europe-Africa', ['U+1F30D']),
	Emoji('travel_and_places', '🌎', 'globe_showing_americas', 'globe showing Americas', ['U+1F30E']),
	Emoji('travel_and_places', '🌏', 'globe_showing_asia_australia', 'globe showing Asia-Australia', ['U+1F30F']),
	Emoji('travel_and_places', '🌐', 'globe_with_meridians', 'globe with meridians', ['U+1F310']),
	Emoji('travel_and_places', '🗺', 'world_map', 'world map', ['U+1F5FA']),
	Emoji('travel_and_places', '🗾', 'map_of_japan', 'map of Japan', ['U+1F5FE']),
	Emoji('travel_and_places', '🧭', 'compass', 'compass', ['U+1F9ED']),
	Emoji('travel_and_places', '🏔', 'snow_capped_mountain', 'snow-capped mountain', ['U+1F3D4']),
	Emoji('travel_and_places', '⛰', 'mountain', 'mountain', ['U+26F0']),
	Emoji('travel_and_places', '🌋', 'volcano', 'volcano', ['U+1F30B']),
	Emoji('travel_and_places', '🗻', 'mount_fuji', 'mount fuji', ['U+1F5FB']),
	Emoji('travel_and_places', '🏕', 'camping', 'camping', ['U+1F3D5']),
	Emoji('travel_and_places', '🏖', 'beach_with_umbrella', 'beach with umbrella', ['U+1F3D6']),
	Emoji('travel_and_places', '🏜', 'desert', 'desert', ['U+1F3DC']),
	Emoji('travel_and_places', '🏝', 'desert_island', 'desert island', ['U+1F3DD']),
	Emoji('travel_and_places', '🏞', 'national_park', 'national park', ['U+1F3DE']),
	Emoji('travel_and_places', '🏟', 'stadium', 'stadium', ['U+1F3DF']),
	Emoji('travel_and_places', '🏛', 'classical_building', 'classical building', ['U+1F3DB']),
	Emoji('travel_and_places', '🏗', 'building_construction', 'building construction', ['U+1F3D7']),
	Emoji('travel_and_places', '🧱', 'brick', 'brick', ['U+1F9F1']),
	Emoji('travel_and_places', '🪨', 'rock', 'rock', ['U+1FAA8']),
	Emoji('travel_and_places', '🪵', 'wood', 'wood', ['U+1FAB5']),
	Emoji('travel_and_places', '🛖', 'hut', 'hut', ['U+1F6D6']),
	Emoji('travel_and_places', '🏘', 'houses', 'houses', ['U+1F3D8']),
	Emoji('travel_and_places', '🏚', 'derelict_house', 'derelict house', ['U+1F3DA']),
	Emoji('travel_and_places', '🏠', 'house', 'house', ['U+1F3E0']),
	Emoji('travel_and_places', '🏡', 'house_with_garden', 'house with garden', ['U+1F3E1']),
	Emoji('travel_and_places', '🏢', 'office_building', 'office building', ['U+1F3E2']),
	Emoji('travel_and_places', '🏣', 'japanese_post_office', 'Japanese post office', ['U+1F3E3']),
	Emoji('travel_and_places', '🏤', 'post_office', 'post office', ['U+1F3E4']),
	Emoji('travel_and_places', '🏥', 'hospital', 'hospital', ['U+1F3E5']),
	Emoji('travel_and_places', '🏦', 'bank', 'bank', ['U+1F3E6']),
	Emoji('travel_and_places', '🏨', 'hotel', 'hotel', ['U+1F3E8']),
	Emoji('travel_and_places', '🏩', 'love_hotel', 'love hotel', ['U+1F3E9']),
	Emoji('travel_and_places', '🏪', 'convenience_store', 'convenience store', ['U+1F3EA']),
	Emoji('travel_and_places', '🏫', 'school', 'school', ['U+1F3EB']),
	Emoji('travel_and_places', '🏬', 'department_store', 'department store', ['U+1F3EC']),
	Emoji('travel_and_places', '🏭', 'factory', 'factory', ['U+1F3ED']),
	Emoji('travel_and_places', '🏯', 'japanese_castle', 'Japanese castle', ['U+1F3EF']),
	Emoji('travel_and_places', '🏰', 'castle', 'castle', ['U+1F3F0']),
	Emoji('travel_and_places', '💒', 'wedding', 'wedding', ['U+1F492']),
	Emoji('travel_and_places', '🗼', 'tokyo_tower', 'Tokyo tower', ['U+1F5FC']),
	Emoji('travel_and_places', '🗽', 'statue_of_liberty', 'Statue of Liberty', ['U+1F5FD']),
	Emoji('travel_and_places', '⛪', 'church', 'church', ['U+26EA']),
	Emoji('travel_and_places', '🕌', 'mosque', 'mosque', ['U+1F54C']),
	Emoji('travel_and_places', '🛕', 'hindu_temple', 'hindu temple', ['U+1F6D5']),
	Emoji('travel_and_places', '🕍', 'synagogue', 'synagogue', ['U+1F54D']),
	Emoji('travel_and_places', '⛩', 'shinto_shrine', 'shinto shrine', ['U+26E9']),
	Emoji('travel_and_places', '🕋', 'kaaba', 'kaaba', ['U+1F54B']),
	Emoji('travel_and_places', '⛲', 'fountain', 'fountain', ['U+26F2']),
	Emoji('travel_and_places', '⛺', 'tent', 'tent', ['U+26FA']),
	Emoji('travel_and_places', '🌁', 'foggy', 'foggy', ['U+1F301']),
	Emoji('travel_and_places', '🌃', 'night_with_stars', 'night with stars', ['U+1F303']),
	Emoji('travel_and_places', '🏙', 'cityscape', 'cityscape', ['U+1F3D9']),
	Emoji('travel_and_places', '🌄', 'sunrise_over_mountains', 'sunrise over mountains', ['U+1F304']),
	Emoji('travel_and_places', '🌅', 'sunrise', 'sunrise', ['U+1F305']),
	Emoji('travel_and_places', '🌆', 'cityscape_at_dusk', 'cityscape at dusk', ['U+1F306']),
	Emoji('travel_and_places', '🌇', 'sunset', 'sunset', ['U+1F307']),
	Emoji('travel_and_places', '🌉', 'bridge_at_night', 'bridge at night', ['U+1F309']),
	Emoji('travel_and_places', '♨', 'hot_springs', 'hot springs', ['U+2668']),
	Emoji('travel_and_places', '🎠', 'carousel_horse', 'carousel horse', ['U+1F3A0']),
	Emoji('travel_and_places', '🛝', 'playground_slide', 'playground slide', ['U+1F6DD']),
	Emoji('travel_and_places', '🎡', 'ferris_wheel', 'ferris wheel', ['U+1F3A1']),
	Emoji('travel_and_places', '🎢', 'roller_coaster', 'roller coaster', ['U+1F3A2']),
	Emoji('travel_and_places', '💈', 'barber_pole', 'barber pole', ['U+1F488']),
	Emoji('travel_and_places', '🎪', 'circus_tent', 'circus tent', ['U+1F3AA']),
	Emoji('travel_and_places', '🚂', 'locomotive', 'locomotive', ['U+1F682']),
	Emoji('travel_and_places', '🚃', 'railway_car', 'railway car', ['U+1F683']),
	Emoji('travel_and_places', '🚄', 'high_speed_train', 'high-speed train', ['U+1F684']),
	Emoji('travel_and_places', '🚅', 'bullet_train', 'bullet train', ['U+1F685']),
	Emoji('travel_and_places', '🚆', 'train', 'train', ['U+1F686']),
	Emoji('travel_and_places', '🚇', 'metro', 'metro', ['U+1F687']),
	Emoji('travel_and_places', '🚈', 'light_rail', 'light rail', ['U+1F688']),
	Emoji('travel_and_places', '🚉', 'station', 'station', ['U+1F689']),
	Emoji('travel_and_places', '🚊', 'tram', 'tram', ['U+1F68A']),
	Emoji('travel_and_places', '🚝', 'monorail', 'monorail', ['U+1F69D']),
	Emoji('travel_and_places', '🚞', 'mountain_railway', 'mountain railway', ['U+1F69E']),
	Emoji('travel_and_places', '🚋', 'tram_car', 'tram car', ['U+1F68B']),
	Emoji('travel_and_places', '🚌', 'bus', 'bus', ['U+1F68C']),
	Emoji('travel_and_places', '🚍', 'oncoming_bus', 'oncoming bus', ['U+1F68D']),
	Emoji('travel_and_places', '🚎', 'trolleybus', 'trolleybus', ['U+1F68E']),
	Emoji('travel_and_places', '🚐', 'minibus', 'minibus', ['U+1F690']),
	Emoji('travel_and_places', '🚑', 'ambulance', 'ambulance', ['U+1F691']),
	Emoji('travel_and_places', '🚒', 'fire_engine', 'fire engine', ['U+1F692']),
	Emoji('travel_and_places', '🚓', 'police_car', 'police car', ['U+1F693']),
	Emoji('travel_and_places', '🚔', 'oncoming_police_car', 'oncoming police car', ['U+1F694']),
	Emoji('travel_and_places', '🚕', 'taxi', 'taxi', ['U+1F695']),
	Emoji('travel_and_places', '🚖', 'oncoming_taxi', 'oncoming taxi', ['U+1F696']),
	Emoji('travel_and_places', '🚗', 'automobile', 'automobile', ['U+1F697']),
	Emoji('travel_and_places', '🚘', 'oncoming_automobile', 'oncoming automobile', ['U+1F698']),
	Emoji('travel_and_places', '🚙', 'sport_utility_vehicle', 'sport utility vehicle', ['U+1F699']),
	Emoji('travel_and_places', '🛻', 'pickup_truck', 'pickup truck', ['U+1F6FB']),
	Emoji('travel_and_places', '🚚', 'delivery_truck', 'delivery truck', ['U+1F69A']),
	Emoji('travel_and_places', '🚛', 'articulated_lorry', 'articulated lorry', ['U+1F69B']),
	Emoji('travel_and_places', '🚜', 'tractor', 'tractor', ['U+1F69C']),
	Emoji('travel_and_places', '🏎', 'racing_car', 'racing car', ['U+1F3CE']),
	Emoji('travel_and_places', '🏍', 'motorcycle', 'motorcycle', ['U+1F3CD']),
	Emoji('travel_and_places', '🛵', 'motor_scooter', 'motor scooter', ['U+1F6F5']),
	Emoji('travel_and_places', '🦽', 'manual_wheelchair', 'manual wheelchair', ['U+1F9BD']),
	Emoji('travel_and_places', '🦼', 'motorized_wheelchair', 'motorized wheelchair', ['U+1F9BC']),
	Emoji('travel_and_places', '🛺', 'auto_rickshaw', 'auto rickshaw', ['U+1F6FA']),
	Emoji('travel_and_places', '🚲', 'bicycle', 'bicycle', ['U+1F6B2']),
	Emoji('travel_and_places', '🛴', 'kick_scooter', 'kick scooter', ['U+1F6F4']),
	Emoji('travel_and_places', '🛹', 'skateboard', 'skateboard', ['U+1F6F9']),
	Emoji('travel_and_places', '🛼', 'roller_skate', 'roller skate', ['U+1F6FC']),
	Emoji('travel_and_places', '🚏', 'bus_stop', 'bus stop', ['U+1F68F']),
	Emoji('travel_and_places', '🛣', 'motorway', 'motorway', ['U+1F6E3']),
	Emoji('travel_and_places', '🛤', 'railway_track', 'railway track', ['U+1F6E4']),
	Emoji('travel_and_places', '🛢', 'oil_drum', 'oil drum', ['U+1F6E2']),
	Emoji('travel_and_places', '⛽', 'fuel_pump', 'fuel pump', ['U+26FD']),
	Emoji('travel_and_places', '🛞', 'wheel', 'wheel', ['U+1F6DE']),
	Emoji('travel_and_places', '🚨', 'police_car_light', 'police car light', ['U+1F6A8']),
	Emoji('travel_and_places', '🚥', 'horizontal_traffic_light', 'horizontal traffic light', ['U+1F6A5']),
	Emoji('travel_and_places', '🚦', 'vertical_traffic_light', 'vertical traffic light', ['U+1F6A6']),
	Emoji('travel_and_places', '🛑', 'stop_sign', 'stop sign', ['U+1F6D1']),
	Emoji('travel_and_places', '🚧', 'construction', 'construction', ['U+1F6A7']),
	Emoji('travel_and_places', '⚓', 'anchor', 'anchor', ['U+2693']),
	Emoji('travel_and_places', '🛟', 'ring_buoy', 'ring buoy', ['U+1F6DF']),
	Emoji('travel_and_places', '⛵', 'sailboat', 'sailboat', ['U+26F5']),
	Emoji('travel_and_places', '🛶', 'canoe', 'canoe', ['U+1F6F6']),
	Emoji('travel_and_places', '🚤', 'speedboat', 'speedboat', ['U+1F6A4']),
	Emoji('travel_and_places', '🛳', 'passenger_ship', 'passenger ship', ['U+1F6F3']),
	Emoji('travel_and_places', '⛴', 'ferry', 'ferry', ['U+26F4']),
	Emoji('travel_and_places', '🛥', 'motor_boat', 'motor boat', ['U+1F6E5']),
	Emoji('travel_and_places', '🚢', 'ship', 'ship', ['U+1F6A2']),
	Emoji('travel_and_places', '✈', 'airplane', 'airplane', ['U+2708']),
	Emoji('travel_and_places', '🛩', 'small_airplane', 'small airplane', ['U+1F6E9']),
	Emoji('travel_and_places', '🛫', 'airplane_departure', 'airplane departure', ['U+1F6EB']),
	Emoji('travel_and_places', '🛬', 'airplane_arrival', 'airplane arrival', ['U+1F6EC']),
	Emoji('travel_and_places', '🪂', 'parachute', 'parachute', ['U+1FA82']),
	Emoji('travel_and_places', '💺', 'seat', 'seat', ['U+1F4BA']),
	Emoji('travel_and_places', '🚁', 'helicopter', 'helicopter', ['U+1F681']),
	Emoji('travel_and_places', '🚟', 'suspension_railway', 'suspension railway', ['U+1F69F']),
	Emoji('travel_and_places', '🚠', 'mountain_cableway', 'mountain cableway', ['U+1F6A0']),
	Emoji('travel_and_places', '🚡', 'aerial_tramway', 'aerial tramway', ['U+1F6A1']),
	Emoji('travel_and_places', '🛰', 'satellite', 'satellite', ['U+1F6F0']),
	Emoji('travel_and_places', '🚀', 'rocket', 'rocket', ['U+1F680']),
	Emoji('travel_and_places', '🛸', 'flying_saucer', 'flying saucer', ['U+1F6F8']),
	Emoji('travel_and_places', '🧳', 'luggage', 'luggage', ['U+1F9F3']),
	Emoji('travel_and_places', '⌛', 'hourglass_done', 'hourglass done', ['U+231B']),
	Emoji('travel_and_places', '⏳', 'hourglass_not_done', 'hourglass not done', ['U+23F3']),
	Emoji('travel_and_places', '⌚', 'watch', 'watch', ['U+231A']),
	Emoji('travel_and_places', '⏰', 'alarm_clock', 'alarm clock', ['U+23F0']),
	Emoji('travel_and_places', '⏱', 'stopwatch', 'stopwatch', ['U+23F1']),
	Emoji('travel_and_places', '⏲', 'timer_clock', 'timer clock', ['U+23F2']),
	Emoji('travel_and_places', '🕰', 'mantelpiece_clock', 'mantelpiece clock', ['U+1F570']),
	Emoji('travel_and_places', '🕛', 'twelve_oclock', 'twelve o’clock', ['U+1F55B']),
	Emoji('travel_and_places', '🕧', 'twelve_thirty', 'twelve-thirty', ['U+1F567']),
	Emoji('travel_and_places', '🕐', 'one_oclock', 'one o’clock', ['U+1F550']),
	Emoji('travel_and_places', '🕜', 'one_thirty', 'one-thirty', ['U+1F55C']),
	Emoji('travel_and_places', '🕑', 'two_oclock', 'two o’clock', ['U+1F551']),
	Emoji('travel_and_places', '🕝', 'two_thirty', 'two-thirty', ['U+1F55D']),
	Emoji('travel_and_places', '🕒', 'three_oclock', 'three o’clock', ['U+1F552']),
	Emoji('travel_and_places', '🕞', 'three_thirty', 'three-thirty', ['U+1F55E']),
	Emoji('travel_and_places', '🕓', 'four_oclock', 'four o’clock', ['U+1F553']),
	Emoji('travel_and_places', '🕟', 'four_thirty', 'four-thirty', ['U+1F55F']),
	Emoji('travel_and_places', '🕔', 'five_oclock', 'five o’clock', ['U+1F554']),
	Emoji('travel_and_places', '🕠', 'five_thirty', 'five-thirty', ['U+1F560']),
	Emoji('travel_and_places', '🕕', 'six_oclock', 'six o’clock', ['U+1F555']),
	Emoji('travel_and_places', '🕡', 'six_thirty', 'six-thirty', ['U+1F561']),
	Emoji('travel_and_places', '🕖', 'seven_oclock', 'seven o’clock', ['U+1F556']),
	Emoji('travel_and_places', '🕢', 'seven_thirty', 'seven-thirty', ['U+1F562']),
	Emoji('travel_and_places', '🕗', 'eight_oclock', 'eight o’clock', ['U+1F557']),
	Emoji('travel_and_places', '🕣', 'eight_thirty', 'eight-thirty', ['U+1F563']),
	Emoji('travel_and_places', '🕘', 'nine_oclock', 'nine o’clock', ['U+1F558']),
	Emoji('travel_and_places', '🕤', 'nine_thirty', 'nine-thirty', ['U+1F564']),
	Emoji('travel_and_places', '🕙', 'ten_oclock', 'ten o’clock', ['U+1F559']),
	Emoji('travel_and_places', '🕥', 'ten_thirty', 'ten-thirty', ['U+1F565']),
	Emoji('travel_and_places', '🕚', 'eleven_oclock', 'eleven o’clock', ['U+1F55A']),
	Emoji('travel_and_places', '🕦', 'eleven_thirty', 'eleven-thirty', ['U+1F566']),
	Emoji('travel_and_places', '🌑', 'new_moon', 'new moon', ['U+1F311']),
	Emoji('travel_and_places', '🌒', 'waxing_crescent_moon', 'waxing crescent moon', ['U+1F312']),
	Emoji('travel_and_places', '🌓', 'first_quarter_moon', 'first quarter moon', ['U+1F313']),
	Emoji('travel_and_places', '🌔', 'waxing_gibbous_moon', 'waxing gibbous moon', ['U+1F314']),
	Emoji('travel_and_places', '🌕', 'full_moon', 'full moon', ['U+1F315']),
	Emoji('travel_and_places', '🌖', 'waning_gibbous_moon', 'waning gibbous moon', ['U+1F316']),
	Emoji('travel_and_places', '🌗', 'last_quarter_moon', 'last quarter moon', ['U+1F317']),
	Emoji('travel_and_places', '🌘', 'waning_crescent_moon', 'waning crescent moon', ['U+1F318']),
	Emoji('travel_and_places', '🌙', 'crescent_moon', 'crescent moon', ['U+1F319']),
	Emoji('travel_and_places', '🌚', 'new_moon_face', 'new moon face', ['U+1F31A']),
	Emoji('travel_and_places', '🌛', 'first_quarter_moon_face', 'first quarter moon face', ['U+1F31B']),
	Emoji('travel_and_places', '🌜', 'last_quarter_moon_face', 'last quarter moon face', ['U+1F31C']),
	Emoji('travel_and_places', '🌡', 'thermometer', 'thermometer', ['U+1F321']),
	Emoji('travel_and_places', '☀', 'sun', 'sun', ['U+2600']),
	Emoji('travel_and_places', '🌝', 'full_moon_face', 'full moon face', ['U+1F31D']),
	Emoji('travel_and_places', '🌞', 'sun_with_face', 'sun with face', ['U+1F31E']),
	Emoji('travel_and_places', '🪐', 'ringed_planet', 'ringed planet', ['U+1FA90']),
	Emoji('travel_and_places', '⭐', 'star', 'star', ['U+2B50']),
	Emoji('travel_and_places', '🌟', 'glowing_star', 'glowing star', ['U+1F31F']),
	Emoji('travel_and_places', '🌠', 'shooting_star', 'shooting star', ['U+1F320']),
	Emoji('travel_and_places', '🌌', 'milky_way', 'milky way', ['U+1F30C']),
	Emoji('travel_and_places', '☁', 'cloud', 'cloud', ['U+2601']),
	Emoji('travel_and_places', '⛅', 'sun_behind_cloud', 'sun behind cloud', ['U+26C5']),
	Emoji('travel_and_places', '⛈', 'cloud_with_lightning_and_rain', 'cloud with lightning and rain', ['U+26C8']),
	Emoji('travel_and_places', '🌤', 'sun_behind_small_cloud', 'sun behind small cloud', ['U+1F324']),
	Emoji('travel_and_places', '🌥', 'sun_behind_large_cloud', 'sun behind large cloud', ['U+1F325']),
	Emoji('travel_and_places', '🌦', 'sun_behind_rain_cloud', 'sun behind rain cloud', ['U+1F326']),
	Emoji('travel_and_places', '🌧', 'cloud_with_rain', 'cloud with rain', ['U+1F327']),
	Emoji('travel_and_places', '🌨', 'cloud_with_snow', 'cloud with snow', ['U+1F328']),
	Emoji('travel_and_places', '🌩', 'cloud_with_lightning', 'cloud with lightning', ['U+1F329']),
	Emoji('travel_and_places', '🌪', 'tornado', 'tornado', ['U+1F32A']),
	Emoji('travel_and_places', '🌫', 'fog', 'fog', ['U+1F32B']),
	Emoji('travel_and_places', '🌬', 'wind_face', 'wind face', ['U+1F32C']),
	Emoji('travel_and_places', '🌀', 'cyclone', 'cyclone', ['U+1F300']),
	Emoji('travel_and_places', '🌈', 'rainbow', 'rainbow', ['U+1F308']),
	Emoji('travel_and_places', '🌂', 'closed_umbrella', 'closed umbrella', ['U+1F302']),
	Emoji('travel_and_places', '☂', 'umbrella', 'umbrella', ['U+2602']),
	Emoji('travel_and_places', '☔', 'umbrella_with_rain_drops', 'umbrella with rain drops', ['U+2614']),
	Emoji('travel_and_places', '⛱', 'umbrella_on_ground', 'umbrella on ground', ['U+26F1']),
	Emoji('travel_and_places', '⚡', 'high_voltage', 'high voltage', ['U+26A1']),
	Emoji('travel_and_places', '❄', 'snowflake', 'snowflake', ['U+2744']),
	Emoji('travel_and_places', '☃', 'snowman', 'snowman', ['U+2603']),
	Emoji('travel_and_places', '⛄', 'snowman_without_snow', 'snowman without snow', ['U+26C4']),
	Emoji('travel_and_places', '☄', 'comet', 'comet', ['U+2604']),
	Emoji('travel_and_places', '🔥', 'fire', 'fire', ['U+1F525']),
	Emoji('travel_and_places', '💧', 'droplet', 'droplet', ['U+1F4A7']),
	Emoji('travel_and_places', '🌊', 'water_wave', 'water wave', ['U+1F30A']),

	## » 217 Emojis found in travel_and_places category « ##

	Emoji('activities', '🎃', 'jack_o_lantern', 'jack-o-lantern', ['U+1F383']),
	Emoji('activities', '🎄', 'christmas_tree', 'Christmas tree', ['U+1F384']),
	Emoji('activities', '🎆', 'fireworks', 'fireworks', ['U+1F386']),
	Emoji('activities', '🎇', 'sparkler', 'sparkler', ['U+1F387']),
	Emoji('activities', '🧨', 'firecracker', 'firecracker', ['U+1F9E8']),
	Emoji('activities', '✨', 'sparkles', 'sparkles', ['U+2728']),
	Emoji('activities', '🎈', 'balloon', 'balloon', ['U+1F388']),
	Emoji('activities', '🎉', 'party_popper', 'party popper', ['U+1F389']),
	Emoji('activities', '🎊', 'confetti_ball', 'confetti ball', ['U+1F38A']),
	Emoji('activities', '🎋', 'tanabata_tree', 'tanabata tree', ['U+1F38B']),
	Emoji('activities', '🎍', 'pine_decoration', 'pine decoration', ['U+1F38D']),
	Emoji('activities', '🎎', 'japanese_dolls', 'Japanese dolls', ['U+1F38E']),
	Emoji('activities', '🎏', 'carp_streamer', 'carp streamer', ['U+1F38F']),
	Emoji('activities', '🎐', 'wind_chime', 'wind chime', ['U+1F390']),
	Emoji('activities', '🎑', 'moon_viewing_ceremony', 'moon viewing ceremony', ['U+1F391']),
	Emoji('activities', '🧧', 'red_envelope', 'red envelope', ['U+1F9E7']),
	Emoji('activities', '🎀', 'ribbon', 'ribbon', ['U+1F380']),
	Emoji('activities', '🎁', 'wrapped_gift', 'wrapped gift', ['U+1F381']),
	Emoji('activities', '🎗', 'reminder_ribbon', 'reminder ribbon', ['U+1F397']),
	Emoji('activities', '🎟', 'admission_tickets', 'admission tickets', ['U+1F39F']),
	Emoji('activities', '🎫', 'ticket', 'ticket', ['U+1F3AB']),
	Emoji('activities', '🎖', 'military_medal', 'military medal', ['U+1F396']),
	Emoji('activities', '🏆', 'trophy', 'trophy', ['U+1F3C6']),
	Emoji('activities', '🏅', 'sports_medal', 'sports medal', ['U+1F3C5']),
	Emoji('activities', '🥇', '1st_place_medal', '1st place medal', ['U+1F947']),
	Emoji('activities', '🥈', '2nd_place_medal', '2nd place medal', ['U+1F948']),
	Emoji('activities', '🥉', '3rd_place_medal', '3rd place medal', ['U+1F949']),
	Emoji('activities', '⚽', 'soccer_ball', 'soccer ball', ['U+26BD']),
	Emoji('activities', '⚾', 'baseball', 'baseball', ['U+26BE']),
	Emoji('activities', '🥎', 'softball', 'softball', ['U+1F94E']),
	Emoji('activities', '🏀', 'basketball', 'basketball', ['U+1F3C0']),
	Emoji('activities', '🏐', 'volleyball', 'volleyball', ['U+1F3D0']),
	Emoji('activities', '🏈', 'american_football', 'american football', ['U+1F3C8']),
	Emoji('activities', '🏉', 'rugby_football', 'rugby football', ['U+1F3C9']),
	Emoji('activities', '🎾', 'tennis', 'tennis', ['U+1F3BE']),
	Emoji('activities', '🥏', 'flying_disc', 'flying disc', ['U+1F94F']),
	Emoji('activities', '🎳', 'bowling', 'bowling', ['U+1F3B3']),
	Emoji('activities', '🏏', 'cricket_game', 'cricket game', ['U+1F3CF']),
	Emoji('activities', '🏑', 'field_hockey', 'field hockey', ['U+1F3D1']),
	Emoji('activities', '🏒', 'ice_hockey', 'ice hockey', ['U+1F3D2']),
	Emoji('activities', '🥍', 'lacrosse', 'lacrosse', ['U+1F94D']),
	Emoji('activities', '🏓', 'ping_pong', 'ping pong', ['U+1F3D3']),
	Emoji('activities', '🏸', 'badminton', 'badminton', ['U+1F3F8']),
	Emoji('activities', '🥊', 'boxing_glove', 'boxing glove', ['U+1F94A']),
	Emoji('activities', '🥋', 'martial_arts_uniform', 'martial arts uniform', ['U+1F94B']),
	Emoji('activities', '🥅', 'goal_net', 'goal net', ['U+1F945']),
	Emoji('activities', '⛳', 'flag_in_hole', 'flag in hole', ['U+26F3']),
	Emoji('activities', '⛸', 'ice_skate', 'ice skate', ['U+26F8']),
	Emoji('activities', '🎣', 'fishing_pole', 'fishing pole', ['U+1F3A3']),
	Emoji('activities', '🤿', 'diving_mask', 'diving mask', ['U+1F93F']),
	Emoji('activities', '🎽', 'running_shirt', 'running shirt', ['U+1F3BD']),
	Emoji('activities', '🎿', 'skis', 'skis', ['U+1F3BF']),
	Emoji('activities', '🛷', 'sled', 'sled', ['U+1F6F7']),
	Emoji('activities', '🥌', 'curling_stone', 'curling stone', ['U+1F94C']),
	Emoji('activities', '🎯', 'bullseye', 'bullseye', ['U+1F3AF']),
	Emoji('activities', '🪀', 'yo_yo', 'yo-yo', ['U+1FA80']),
	Emoji('activities', '🪁', 'kite', 'kite', ['U+1FA81']),
	Emoji('activities', '🔫', 'water_pistol', 'water pistol', ['U+1F52B']),
	Emoji('activities', '🎱', 'pool_8_ball', 'pool 8 ball', ['U+1F3B1']),
	Emoji('activities', '🔮', 'crystal_ball', 'crystal ball', ['U+1F52E']),
	Emoji('activities', '🪄', 'magic_wand', 'magic wand', ['U+1FA84']),
	Emoji('activities', '🎮', 'video_game', 'video game', ['U+1F3AE']),
	Emoji('activities', '🕹', 'joystick', 'joystick', ['U+1F579']),
	Emoji('activities', '🎰', 'slot_machine', 'slot machine', ['U+1F3B0']),
	Emoji('activities', '🎲', 'game_die', 'game die', ['U+1F3B2']),
	Emoji('activities', '🧩', 'puzzle_piece', 'puzzle piece', ['U+1F9E9']),
	Emoji('activities', '🧸', 'teddy_bear', 'teddy bear', ['U+1F9F8']),
	Emoji('activities', '🪅', 'piñata', 'piñata', ['U+1FA85']),
	Emoji('activities', '🪩', 'mirror_ball', 'mirror ball', ['U+1FAA9']),
	Emoji('activities', '🪆', 'nesting_dolls', 'nesting dolls', ['U+1FA86']),
	Emoji('activities', '♠', 'spade_suit', 'spade suit', ['U+2660']),
	Emoji('activities', '♥', 'heart_suit', 'heart suit', ['U+2665']),
	Emoji('activities', '♦', 'diamond_suit', 'diamond suit', ['U+2666']),
	Emoji('activities', '♣', 'club_suit', 'club suit', ['U+2663']),
	Emoji('activities', '♟', 'chess_pawn', 'chess pawn', ['U+265F']),
	Emoji('activities', '🃏', 'joker', 'joker', ['U+1F0CF']),
	Emoji('activities', '🀄', 'mahjong_red_dragon', 'mahjong red dragon', ['U+1F004']),
	Emoji('activities', '🎴', 'flower_playing_cards', 'flower playing cards', ['U+1F3B4']),
	Emoji('activities', '🎭', 'performing_arts', 'performing arts', ['U+1F3AD']),
	Emoji('activities', '🖼', 'framed_picture', 'framed picture', ['U+1F5BC']),
	Emoji('activities', '🎨', 'artist_palette', 'artist palette', ['U+1F3A8']),
	Emoji('activities', '🧵', 'thread', 'thread', ['U+1F9F5']),
	Emoji('activities', '🪡', 'sewing_needle', 'sewing needle', ['U+1FAA1']),
	Emoji('activities', '🧶', 'yarn', 'yarn', ['U+1F9F6']),
	Emoji('activities', '🪢', 'knot', 'knot', ['U+1FAA2']),

	## » 85 Emojis found in activities category « ##

	Emoji('objects', '👓', 'glasses', 'glasses', ['U+1F453']),
	Emoji('objects', '🕶', 'sunglasses', 'sunglasses', ['U+1F576']),
	Emoji('objects', '🥽', 'goggles', 'goggles', ['U+1F97D']),
	Emoji('objects', '🥼', 'lab_coat', 'lab coat', ['U+1F97C']),
	Emoji('objects', '🦺', 'safety_vest', 'safety vest', ['U+1F9BA']),
	Emoji('objects', '👔', 'necktie', 'necktie', ['U+1F454']),
	Emoji('objects', '👕', 't_shirt', 't-shirt', ['U+1F455']),
	Emoji('objects', '👖', 'jeans', 'jeans', ['U+1F456']),
	Emoji('objects', '🧣', 'scarf', 'scarf', ['U+1F9E3']),
	Emoji('objects', '🧤', 'gloves', 'gloves', ['U+1F9E4']),
	Emoji('objects', '🧥', 'coat', 'coat', ['U+1F9E5']),
	Emoji('objects', '🧦', 'socks', 'socks', ['U+1F9E6']),
	Emoji('objects', '👗', 'dress', 'dress', ['U+1F457']),
	Emoji('objects', '👘', 'kimono', 'kimono', ['U+1F458']),
	Emoji('objects', '🥻', 'sari', 'sari', ['U+1F97B']),
	Emoji('objects', '🩱', 'one_piece_swimsuit', 'one-piece swimsuit', ['U+1FA71']),
	Emoji('objects', '🩲', 'briefs', 'briefs', ['U+1FA72']),
	Emoji('objects', '🩳', 'shorts', 'shorts', ['U+1FA73']),
	Emoji('objects', '👙', 'bikini', 'bikini', ['U+1F459']),
	Emoji('objects', '👚', 'womans_clothes', 'woman’s clothes', ['U+1F45A']),
	Emoji('objects', '👛', 'purse', 'purse', ['U+1F45B']),
	Emoji('objects', '👜', 'handbag', 'handbag', ['U+1F45C']),
	Emoji('objects', '👝', 'clutch_bag', 'clutch bag', ['U+1F45D']),
	Emoji('objects', '🛍', 'shopping_bags', 'shopping bags', ['U+1F6CD']),
	Emoji('objects', '🎒', 'backpack', 'backpack', ['U+1F392']),
	Emoji('objects', '🩴', 'thong_sandal', 'thong sandal', ['U+1FA74']),
	Emoji('objects', '👞', 'mans_shoe', 'man’s shoe', ['U+1F45E']),
	Emoji('objects', '👟', 'running_shoe', 'running shoe', ['U+1F45F']),
	Emoji('objects', '🥾', 'hiking_boot', 'hiking boot', ['U+1F97E']),
	Emoji('objects', '🥿', 'flat_shoe', 'flat shoe', ['U+1F97F']),
	Emoji('objects', '👠', 'high_heeled_shoe', 'high-heeled shoe', ['U+1F460']),
	Emoji('objects', '👡', 'womans_sandal', 'woman’s sandal', ['U+1F461']),
	Emoji('objects', '🩰', 'ballet_shoes', 'ballet shoes', ['U+1FA70']),
	Emoji('objects', '👢', 'womans_boot', 'woman’s boot', ['U+1F462']),
	Emoji('objects', '👑', 'crown', 'crown', ['U+1F451']),
	Emoji('objects', '👒', 'womans_hat', 'woman’s hat', ['U+1F452']),
	Emoji('objects', '🎩', 'top_hat', 'top hat', ['U+1F3A9']),
	Emoji('objects', '🎓', 'graduation_cap', 'graduation cap', ['U+1F393']),
	Emoji('objects', '🧢', 'billed_cap', 'billed cap', ['U+1F9E2']),
	Emoji('objects', '🪖', 'military_helmet', 'military helmet', ['U+1FA96']),
	Emoji('objects', '⛑', 'rescue_workers_helmet', 'rescue worker’s helmet', ['U+26D1']),
	Emoji('objects', '📿', 'prayer_beads', 'prayer beads', ['U+1F4FF']),
	Emoji('objects', '💄', 'lipstick', 'lipstick', ['U+1F484']),
	Emoji('objects', '💍', 'ring', 'ring', ['U+1F48D']),
	Emoji('objects', '💎', 'gem_stone', 'gem stone', ['U+1F48E']),
	Emoji('objects', '🔇', 'muted_speaker', 'muted speaker', ['U+1F507']),
	Emoji('objects', '🔈', 'speaker_low_volume', 'speaker low volume', ['U+1F508']),
	Emoji('objects', '🔉', 'speaker_medium_volume', 'speaker medium volume', ['U+1F509']),
	Emoji('objects', '🔊', 'speaker_high_volume', 'speaker high volume', ['U+1F50A']),
	Emoji('objects', '📢', 'loudspeaker', 'loudspeaker', ['U+1F4E2']),
	Emoji('objects', '📣', 'megaphone', 'megaphone', ['U+1F4E3']),
	Emoji('objects', '📯', 'postal_horn', 'postal horn', ['U+1F4EF']),
	Emoji('objects', '🔔', 'bell', 'bell', ['U+1F514']),
	Emoji('objects', '🔕', 'bell_with_slash', 'bell with slash', ['U+1F515']),
	Emoji('objects', '🎼', 'musical_score', 'musical score', ['U+1F3BC']),
	Emoji('objects', '🎵', 'musical_note', 'musical note', ['U+1F3B5']),
	Emoji('objects', '🎶', 'musical_notes', 'musical notes', ['U+1F3B6']),
	Emoji('objects', '🎙', 'studio_microphone', 'studio microphone', ['U+1F399']),
	Emoji('objects', '🎚', 'level_slider', 'level slider', ['U+1F39A']),
	Emoji('objects', '🎛', 'control_knobs', 'control knobs', ['U+1F39B']),
	Emoji('objects', '🎤', 'microphone', 'microphone', ['U+1F3A4']),
	Emoji('objects', '🎧', 'headphone', 'headphone', ['U+1F3A7']),
	Emoji('objects', '📻', 'radio', 'radio', ['U+1F4FB']),
	Emoji('objects', '🎷', 'saxophone', 'saxophone', ['U+1F3B7']),
	Emoji('objects', '🪗', 'accordion', 'accordion', ['U+1FA97']),
	Emoji('objects', '🎸', 'guitar', 'guitar', ['U+1F3B8']),
	Emoji('objects', '🎹', 'musical_keyboard', 'musical keyboard', ['U+1F3B9']),
	Emoji('objects', '🎺', 'trumpet', 'trumpet', ['U+1F3BA']),
	Emoji('objects', '🎻', 'violin', 'violin', ['U+1F3BB']),
	Emoji('objects', '🪕', 'banjo', 'banjo', ['U+1FA95']),
	Emoji('objects', '🥁', 'drum', 'drum', ['U+1F941']),
	Emoji('objects', '🪘', 'long_drum', 'long drum', ['U+1FA98']),
	Emoji('objects', '📱', 'mobile_phone', 'mobile phone', ['U+1F4F1']),
	Emoji('objects', '📲', 'mobile_phone_with_arrow', 'mobile phone with arrow', ['U+1F4F2']),
	Emoji('objects', '☎', 'telephone', 'telephone', ['U+260E']),
	Emoji('objects', '📞', 'telephone_receiver', 'telephone receiver', ['U+1F4DE']),
	Emoji('objects', '📟', 'pager', 'pager', ['U+1F4DF']),
	Emoji('objects', '📠', 'fax_machine', 'fax machine', ['U+1F4E0']),
	Emoji('objects', '🔋', 'battery', 'battery', ['U+1F50B']),
	Emoji('objects', '🪫', 'low_battery', 'low battery', ['U+1FAAB']),
	Emoji('objects', '🔌', 'electric_plug', 'electric plug', ['U+1F50C']),
	Emoji('objects', '💻', 'laptop', 'laptop', ['U+1F4BB']),
	Emoji('objects', '🖥', 'desktop_computer', 'desktop computer', ['U+1F5A5']),
	Emoji('objects', '🖨', 'printer', 'printer', ['U+1F5A8']),
	Emoji('objects', '⌨', 'keyboard', 'keyboard', ['U+2328']),
	Emoji('objects', '🖱', 'computer_mouse', 'computer mouse', ['U+1F5B1']),
	Emoji('objects', '🖲', 'trackball', 'trackball', ['U+1F5B2']),
	Emoji('objects', '💽', 'computer_disk', 'computer disk', ['U+1F4BD']),
	Emoji('objects', '💾', 'floppy_disk', 'floppy disk', ['U+1F4BE']),
	Emoji('objects', '💿', 'optical_disk', 'optical disk', ['U+1F4BF']),
	Emoji('objects', '📀', 'dvd', 'dvd', ['U+1F4C0']),
	Emoji('objects', '🧮', 'abacus', 'abacus', ['U+1F9EE']),
	Emoji('objects', '🎥', 'movie_camera', 'movie camera', ['U+1F3A5']),
	Emoji('objects', '🎞', 'film_frames', 'film frames', ['U+1F39E']),
	Emoji('objects', '📽', 'film_projector', 'film projector', ['U+1F4FD']),
	Emoji('objects', '🎬', 'clapper_board', 'clapper board', ['U+1F3AC']),
	Emoji('objects', '📺', 'television', 'television', ['U+1F4FA']),
	Emoji('objects', '📷', 'camera', 'camera', ['U+1F4F7']),
	Emoji('objects', '📸', 'camera_with_flash', 'camera with flash', ['U+1F4F8']),
	Emoji('objects', '📹', 'video_camera', 'video camera', ['U+1F4F9']),
	Emoji('objects', '📼', 'videocassette', 'videocassette', ['U+1F4FC']),
	Emoji('objects', '🔍', 'magnifying_glass_tilted_left', 'magnifying glass tilted left', ['U+1F50D']),
	Emoji('objects', '🔎', 'magnifying_glass_tilted_right', 'magnifying glass tilted right', ['U+1F50E']),
	Emoji('objects', '🕯', 'candle', 'candle', ['U+1F56F']),
	Emoji('objects', '💡', 'light_bulb', 'light bulb', ['U+1F4A1']),
	Emoji('objects', '🔦', 'flashlight', 'flashlight', ['U+1F526']),
	Emoji('objects', '🏮', 'red_paper_lantern', 'red paper lantern', ['U+1F3EE']),
	Emoji('objects', '🪔', 'diya_lamp', 'diya lamp', ['U+1FA94']),
	Emoji('objects', '📔', 'notebook_with_decorative_cover', 'notebook with decorative cover', ['U+1F4D4']),
	Emoji('objects', '📕', 'closed_book', 'closed book', ['U+1F4D5']),
	Emoji('objects', '📖', 'open_book', 'open book', ['U+1F4D6']),
	Emoji('objects', '📗', 'green_book', 'green book', ['U+1F4D7']),
	Emoji('objects', '📘', 'blue_book', 'blue book', ['U+1F4D8']),
	Emoji('objects', '📙', 'orange_book', 'orange book', ['U+1F4D9']),
	Emoji('objects', '📚', 'books', 'books', ['U+1F4DA']),
	Emoji('objects', '📓', 'notebook', 'notebook', ['U+1F4D3']),
	Emoji('objects', '📒', 'ledger', 'ledger', ['U+1F4D2']),
	Emoji('objects', '📃', 'page_with_curl', 'page with curl', ['U+1F4C3']),
	Emoji('objects', '📜', 'scroll', 'scroll', ['U+1F4DC']),
	Emoji('objects', '📄', 'page_facing_up', 'page facing up', ['U+1F4C4']),
	Emoji('objects', '📰', 'newspaper', 'newspaper', ['U+1F4F0']),
	Emoji('objects', '🗞', 'rolled_up_newspaper', 'rolled-up newspaper', ['U+1F5DE']),
	Emoji('objects', '📑', 'bookmark_tabs', 'bookmark tabs', ['U+1F4D1']),
	Emoji('objects', '🔖', 'bookmark', 'bookmark', ['U+1F516']),
	Emoji('objects', '🏷', 'label', 'label', ['U+1F3F7']),
	Emoji('objects', '💰', 'money_bag', 'money bag', ['U+1F4B0']),
	Emoji('objects', '🪙', 'coin', 'coin', ['U+1FA99']),
	Emoji('objects', '💴', 'yen_banknote', 'yen banknote', ['U+1F4B4']),
	Emoji('objects', '💵', 'dollar_banknote', 'dollar banknote', ['U+1F4B5']),
	Emoji('objects', '💶', 'euro_banknote', 'euro banknote', ['U+1F4B6']),
	Emoji('objects', '💷', 'pound_banknote', 'pound banknote', ['U+1F4B7']),
	Emoji('objects', '💸', 'money_with_wings', 'money with wings', ['U+1F4B8']),
	Emoji('objects', '💳', 'credit_card', 'credit card', ['U+1F4B3']),
	Emoji('objects', '🧾', 'receipt', 'receipt', ['U+1F9FE']),
	Emoji('objects', '💹', 'chart_increasing_with_yen', 'chart increasing with yen', ['U+1F4B9']),
	Emoji('objects', '✉', 'envelope', 'envelope', ['U+2709']),
	Emoji('objects', '📧', 'e_mail', 'e-mail', ['U+1F4E7']),
	Emoji('objects', '📨', 'incoming_envelope', 'incoming envelope', ['U+1F4E8']),
	Emoji('objects', '📩', 'envelope_with_arrow', 'envelope with arrow', ['U+1F4E9']),
	Emoji('objects', '📤', 'outbox_tray', 'outbox tray', ['U+1F4E4']),
	Emoji('objects', '📥', 'inbox_tray', 'inbox tray', ['U+1F4E5']),
	Emoji('objects', '📦', 'package', 'package', ['U+1F4E6']),
	Emoji('objects', '📫', 'closed_mailbox_with_raised_flag', 'closed mailbox with raised flag', ['U+1F4EB']),
	Emoji('objects', '📪', 'closed_mailbox_with_lowered_flag', 'closed mailbox with lowered flag', ['U+1F4EA']),
	Emoji('objects', '📬', 'open_mailbox_with_raised_flag', 'open mailbox with raised flag', ['U+1F4EC']),
	Emoji('objects', '📭', 'open_mailbox_with_lowered_flag', 'open mailbox with lowered flag', ['U+1F4ED']),
	Emoji('objects', '📮', 'postbox', 'postbox', ['U+1F4EE']),
	Emoji('objects', '🗳', 'ballot_box_with_ballot', 'ballot box with ballot', ['U+1F5F3']),
	Emoji('objects', '✏', 'pencil', 'pencil', ['U+270F']),
	Emoji('objects', '✒', 'black_nib', 'black nib', ['U+2712']),
	Emoji('objects', '🖋', 'fountain_pen', 'fountain pen', ['U+1F58B']),
	Emoji('objects', '🖊', 'pen', 'pen', ['U+1F58A']),
	Emoji('objects', '🖌', 'paintbrush', 'paintbrush', ['U+1F58C']),
	Emoji('objects', '🖍', 'crayon', 'crayon', ['U+1F58D']),
	Emoji('objects', '📝', 'memo', 'memo', ['U+1F4DD']),
	Emoji('objects', '💼', 'briefcase', 'briefcase', ['U+1F4BC']),
	Emoji('objects', '📁', 'file_folder', 'file folder', ['U+1F4C1']),
	Emoji('objects', '📂', 'open_file_folder', 'open file folder', ['U+1F4C2']),
	Emoji('objects', '🗂', 'card_index_dividers', 'card index dividers', ['U+1F5C2']),
	Emoji('objects', '📅', 'calendar', 'calendar', ['U+1F4C5']),
	Emoji('objects', '📆', 'tear_off_calendar', 'tear-off calendar', ['U+1F4C6']),
	Emoji('objects', '🗒', 'spiral_notepad', 'spiral notepad', ['U+1F5D2']),
	Emoji('objects', '🗓', 'spiral_calendar', 'spiral calendar', ['U+1F5D3']),
	Emoji('objects', '📇', 'card_index', 'card index', ['U+1F4C7']),
	Emoji('objects', '📈', 'chart_increasing', 'chart increasing', ['U+1F4C8']),
	Emoji('objects', '📉', 'chart_decreasing', 'chart decreasing', ['U+1F4C9']),
	Emoji('objects', '📊', 'bar_chart', 'bar chart', ['U+1F4CA']),
	Emoji('objects', '📋', 'clipboard', 'clipboard', ['U+1F4CB']),
	Emoji('objects', '📌', 'pushpin', 'pushpin', ['U+1F4CC']),
	Emoji('objects', '📍', 'round_pushpin', 'round pushpin', ['U+1F4CD']),
	Emoji('objects', '📎', 'paperclip', 'paperclip', ['U+1F4CE']),
	Emoji('objects', '🖇', 'linked_paperclips', 'linked paperclips', ['U+1F587']),
	Emoji('objects', '📏', 'straight_ruler', 'straight ruler', ['U+1F4CF']),
	Emoji('objects', '📐', 'triangular_ruler', 'triangular ruler', ['U+1F4D0']),
	Emoji('objects', '✂', 'scissors', 'scissors', ['U+2702']),
	Emoji('objects', '🗃', 'card_file_box', 'card file box', ['U+1F5C3']),
	Emoji('objects', '🗄', 'file_cabinet', 'file cabinet', ['U+1F5C4']),
	Emoji('objects', '🗑', 'wastebasket', 'wastebasket', ['U+1F5D1']),
	Emoji('objects', '🔒', 'locked', 'locked', ['U+1F512']),
	Emoji('objects', '🔓', 'unlocked', 'unlocked', ['U+1F513']),
	Emoji('objects', '🔏', 'locked_with_pen', 'locked with pen', ['U+1F50F']),
	Emoji('objects', '🔐', 'locked_with_key', 'locked with key', ['U+1F510']),
	Emoji('objects', '🔑', 'key', 'key', ['U+1F511']),
	Emoji('objects', '🗝', 'old_key', 'old key', ['U+1F5DD']),
	Emoji('objects', '🔨', 'hammer', 'hammer', ['U+1F528']),
	Emoji('objects', '🪓', 'axe', 'axe', ['U+1FA93']),
	Emoji('objects', '⛏', 'pick', 'pick', ['U+26CF']),
	Emoji('objects', '⚒', 'hammer_and_pick', 'hammer and pick', ['U+2692']),
	Emoji('objects', '🛠', 'hammer_and_wrench', 'hammer and wrench', ['U+1F6E0']),
	Emoji('objects', '🗡', 'dagger', 'dagger', ['U+1F5E1']),
	Emoji('objects', '⚔', 'crossed_swords', 'crossed swords', ['U+2694']),
	Emoji('objects', '💣', 'bomb', 'bomb', ['U+1F4A3']),
	Emoji('objects', '🪃', 'boomerang', 'boomerang', ['U+1FA83']),
	Emoji('objects', '🏹', 'bow_and_arrow', 'bow and arrow', ['U+1F3F9']),
	Emoji('objects', '🛡', 'shield', 'shield', ['U+1F6E1']),
	Emoji('objects', '🪚', 'carpentry_saw', 'carpentry saw', ['U+1FA9A']),
	Emoji('objects', '🔧', 'wrench', 'wrench', ['U+1F527']),
	Emoji('objects', '🪛', 'screwdriver', 'screwdriver', ['U+1FA9B']),
	Emoji('objects', '🔩', 'nut_and_bolt', 'nut and bolt', ['U+1F529']),
	Emoji('objects', '⚙', 'gear', 'gear', ['U+2699']),
	Emoji('objects', '🗜', 'clamp', 'clamp', ['U+1F5DC']),
	Emoji('objects', '⚖', 'balance_scale', 'balance scale', ['U+2696']),
	Emoji('objects', '🦯', 'white_cane', 'white cane', ['U+1F9AF']),
	Emoji('objects', '🔗', 'link', 'link', ['U+1F517']),
	Emoji('objects', '⛓', 'chains', 'chains', ['U+26D3']),
	Emoji('objects', '🪝', 'hook', 'hook', ['U+1FA9D']),
	Emoji('objects', '🧰', 'toolbox', 'toolbox', ['U+1F9F0']),
	Emoji('objects', '🧲', 'magnet', 'magnet', ['U+1F9F2']),
	Emoji('objects', '🪜', 'ladder', 'ladder', ['U+1FA9C']),
	Emoji('objects', '⚗', 'alembic', 'alembic', ['U+2697']),
	Emoji('objects', '🧪', 'test_tube', 'test tube', ['U+1F9EA']),
	Emoji('objects', '🧫', 'petri_dish', 'petri dish', ['U+1F9EB']),
	Emoji('objects', '🧬', 'dna', 'dna', ['U+1F9EC']),
	Emoji('objects', '🔬', 'microscope', 'microscope', ['U+1F52C']),
	Emoji('objects', '🔭', 'telescope', 'telescope', ['U+1F52D']),
	Emoji('objects', '📡', 'satellite_antenna', 'satellite antenna', ['U+1F4E1']),
	Emoji('objects', '💉', 'syringe', 'syringe', ['U+1F489']),
	Emoji('objects', '🩸', 'drop_of_blood', 'drop of blood', ['U+1FA78']),
	Emoji('objects', '💊', 'pill', 'pill', ['U+1F48A']),
	Emoji('objects', '🩹', 'adhesive_bandage', 'adhesive bandage', ['U+1FA79']),
	Emoji('objects', '🩼', 'crutch', 'crutch', ['U+1FA7C']),
	Emoji('objects', '🩺', 'stethoscope', 'stethoscope', ['U+1FA7A']),
	Emoji('objects', '🩻', 'x_ray', 'x-ray', ['U+1FA7B']),
	Emoji('objects', '🚪', 'door', 'door', ['U+1F6AA']),
	Emoji('objects', '🛗', 'elevator', 'elevator', ['U+1F6D7']),
	Emoji('objects', '🪞', 'mirror', 'mirror', ['U+1FA9E']),
	Emoji('objects', '🪟', 'window', 'window', ['U+1FA9F']),
	Emoji('objects', '🛏', 'bed', 'bed', ['U+1F6CF']),
	Emoji('objects', '🛋', 'couch_and_lamp', 'couch and lamp', ['U+1F6CB']),
	Emoji('objects', '🪑', 'chair', 'chair', ['U+1FA91']),
	Emoji('objects', '🚽', 'toilet', 'toilet', ['U+1F6BD']),
	Emoji('objects', '🪠', 'plunger', 'plunger', ['U+1FAA0']),
	Emoji('objects', '🚿', 'shower', 'shower', ['U+1F6BF']),
	Emoji('objects', '🛁', 'bathtub', 'bathtub', ['U+1F6C1']),
	Emoji('objects', '🪤', 'mouse_trap', 'mouse trap', ['U+1FAA4']),
	Emoji('objects', '🪒', 'razor', 'razor', ['U+1FA92']),
	Emoji('objects', '🧴', 'lotion_bottle', 'lotion bottle', ['U+1F9F4']),
	Emoji('objects', '🧷', 'safety_pin', 'safety pin', ['U+1F9F7']),
	Emoji('objects', '🧹', 'broom', 'broom', ['U+1F9F9']),
	Emoji('objects', '🧺', 'basket', 'basket', ['U+1F9FA']),
	Emoji('objects', '🧻', 'roll_of_paper', 'roll of paper', ['U+1F9FB']),
	Emoji('objects', '🪣', 'bucket', 'bucket', ['U+1FAA3']),
	Emoji('objects', '🧼', 'soap', 'soap', ['U+1F9FC']),
	Emoji('objects', '🫧', 'bubbles', 'bubbles', ['U+1FAE7']),
	Emoji('objects', '🪥', 'toothbrush', 'toothbrush', ['U+1FAA5']),
	Emoji('objects', '🧽', 'sponge', 'sponge', ['U+1F9FD']),
	Emoji('objects', '🧯', 'fire_extinguisher', 'fire extinguisher', ['U+1F9EF']),
	Emoji('objects', '🛒', 'shopping_cart', 'shopping cart', ['U+1F6D2']),
	Emoji('objects', '🚬', 'cigarette', 'cigarette', ['U+1F6AC']),
	Emoji('objects', '⚰', 'coffin', 'coffin', ['U+26B0']),
	Emoji('objects', '🪦', 'headstone', 'headstone', ['U+1FAA6']),
	Emoji('objects', '⚱', 'funeral_urn', 'funeral urn', ['U+26B1']),
	Emoji('objects', '🧿', 'nazar_amulet', 'nazar amulet', ['U+1F9FF']),
	Emoji('objects', '🪬', 'hamsa', 'hamsa', ['U+1FAAC']),
	Emoji('objects', '🗿', 'moai', 'moai', ['U+1F5FF']),
	Emoji('objects', '🪧', 'placard', 'placard', ['U+1FAA7']),
	Emoji('objects', '🪧', 'identification_card', 'identification card', ['U+1FAAA']),

	## » 257 Emojis found in objects category « ##

	Emoji('symbols', '🏧', 'atm_sign', 'ATM sign', ['U+1F3E7']),
	Emoji('symbols', '🚮', 'litter_in_bin_sign', 'litter in bin sign', ['U+1F6AE']),
	Emoji('symbols', '🚰', 'potable_water', 'potable water', ['U+1F6B0']),
	Emoji('symbols', '♿', 'wheelchair_symbol', 'wheelchair symbol', ['U+267F']),
	Emoji('symbols', '🚹', 'mens_room', 'men’s room', ['U+1F6B9']),
	Emoji('symbols', '🚺', 'womens_room', 'women’s room', ['U+1F6BA']),
	Emoji('symbols', '🚻', 'restroom', 'restroom', ['U+1F6BB']),
	Emoji('symbols', '🚼', 'baby_symbol', 'baby symbol', ['U+1F6BC']),
	Emoji('symbols', '🚾', 'water_closet', 'water closet', ['U+1F6BE']),
	Emoji('symbols', '🛂', 'passport_control', 'passport control', ['U+1F6C2']),
	Emoji('symbols', '🛃', 'customs', 'customs', ['U+1F6C3']),
	Emoji('symbols', '🛄', 'baggage_claim', 'baggage claim', ['U+1F6C4']),
	Emoji('symbols', '🛅', 'left_luggage', 'left luggage', ['U+1F6C5']),
	Emoji('symbols', '⚠', 'warning', 'warning', ['U+26A0']),
	Emoji('symbols', '🚸', 'children_crossing', 'children crossing', ['U+1F6B8']),
	Emoji('symbols', '⛔', 'no_entry', 'no entry', ['U+26D4']),
	Emoji('symbols', '🚫', 'prohibited', 'prohibited', ['U+1F6AB']),
	Emoji('symbols', '🚳', 'no_bicycles', 'no bicycles', ['U+1F6B3']),
	Emoji('symbols', '🚭', 'no_smoking', 'no smoking', ['U+1F6AD']),
	Emoji('symbols', '🚯', 'no_littering', 'no littering', ['U+1F6AF']),
	Emoji('symbols', '🚱', 'non_potable_water', 'non-potable water', ['U+1F6B1']),
	Emoji('symbols', '🚷', 'no_pedestrians', 'no pedestrians', ['U+1F6B7']),
	Emoji('symbols', '📵', 'no_mobile_phones', 'no mobile phones', ['U+1F4F5']),
	Emoji('symbols', '🔞', 'no_one_under_eighteen', 'no one under eighteen', ['U+1F51E']),
	Emoji('symbols', '☢', 'radioactive', 'radioactive', ['U+2622']),
	Emoji('symbols', '☣', 'biohazard', 'biohazard', ['U+2623']),
	Emoji('symbols', '⬆', 'up_arrow', 'up arrow', ['U+2B06']),
	Emoji('symbols', '↗', 'up_right_arrow', 'up-right arrow', ['U+2197']),
	Emoji('symbols', '➡', 'right_arrow', 'right arrow', ['U+27A1']),
	Emoji('symbols', '↘', 'down_right_arrow', 'down-right arrow', ['U+2198']),
	Emoji('symbols', '⬇', 'down_arrow', 'down arrow', ['U+2B07']),
	Emoji('symbols', '↙', 'down_left_arrow', 'down-left arrow', ['U+2199']),
	Emoji('symbols', '⬅', 'left_arrow', 'left arrow', ['U+2B05']),
	Emoji('symbols', '↖', 'up_left_arrow', 'up-left arrow', ['U+2196']),
	Emoji('symbols', '↕', 'up_down_arrow', 'up-down arrow', ['U+2195']),
	Emoji('symbols', '↔', 'left_right_arrow', 'left-right arrow', ['U+2194']),
	Emoji('symbols', '↩', 'right_arrow_curving_left', 'right arrow curving left', ['U+21A9']),
	Emoji('symbols', '↪', 'left_arrow_curving_right', 'left arrow curving right', ['U+21AA']),
	Emoji('symbols', '⤴', 'right_arrow_curving_up', 'right arrow curving up', ['U+2934']),
	Emoji('symbols', '⤵', 'right_arrow_curving_down', 'right arrow curving down', ['U+2935']),
	Emoji('symbols', '🔃', 'clockwise_vertical_arrows', 'clockwise vertical arrows', ['U+1F503']),
	Emoji('symbols', '🔄', 'counterclockwise_arrows_button', 'counterclockwise arrows button', ['U+1F504']),
	Emoji('symbols', '🔙', 'back_arrow', 'BACK arrow', ['U+1F519']),
	Emoji('symbols', '🔚', 'end_arrow', 'END arrow', ['U+1F51A']),
	Emoji('symbols', '🔛', 'on_arrow', 'ON! arrow', ['U+1F51B']),
	Emoji('symbols', '🔜', 'soon_arrow', 'SOON arrow', ['U+1F51C']),
	Emoji('symbols', '🔝', 'top_arrow', 'TOP arrow', ['U+1F51D']),
	Emoji('symbols', '🛐', 'place_of_worship', 'place of worship', ['U+1F6D0']),
	Emoji('symbols', '⚛', 'atom_symbol', 'atom symbol', ['U+269B']),
	Emoji('symbols', '🕉', 'om', 'om', ['U+1F549']),
	Emoji('symbols', '✡', 'star_of_david', 'star of David', ['U+2721']),
	Emoji('symbols', '☸', 'wheel_of_dharma', 'wheel of dharma', ['U+2638']),
	Emoji('symbols', '☯', 'yin_yang', 'yin yang', ['U+262F']),
	Emoji('symbols', '✝', 'latin_cross', 'latin cross', ['U+271D']),
	Emoji('symbols', '☦', 'orthodox_cross', 'orthodox cross', ['U+2626']),
	Emoji('symbols', '☪', 'star_and_crescent', 'star and crescent', ['U+262A']),
	Emoji('symbols', '☮', 'peace_symbol', 'peace symbol', ['U+262E']),
	Emoji('symbols', '🕎', 'menorah', 'menorah', ['U+1F54E']),
	Emoji('symbols', '🪯', 'dotted_six_pointed_star', 'dotted six-pointed star', ['U+1F52F']),
	Emoji('symbols', '♈', 'aries', 'Aries', ['U+2648']),
	Emoji('symbols', '♉', 'taurus', 'Taurus', ['U+2649']),
	Emoji('symbols', '♊', 'gemini', 'Gemini', ['U+264A']),
	Emoji('symbols', '♋', 'cancer', 'Cancer', ['U+264B']),
	Emoji('symbols', '♌', 'leo', 'Leo', ['U+264C']),
	Emoji('symbols', '♍', 'virgo', 'Virgo', ['U+264D']),
	Emoji('symbols', '♎', 'libra', 'Libra', ['U+264E']),
	Emoji('symbols', '♏', 'scorpio', 'Scorpio', ['U+264F']),
	Emoji('symbols', '♐', 'sagittarius', 'Sagittarius', ['U+2650']),
	Emoji('symbols', '♑', 'capricorn', 'Capricorn', ['U+2651']),
	Emoji('symbols', '♒', 'aquarius', 'Aquarius', ['U+2652']),
	Emoji('symbols', '♓', 'pisces', 'Pisces', ['U+2653']),
	Emoji('symbols', '⛎', 'ophiuchus', 'Ophiuchus', ['U+26CE']),
	Emoji('symbols', '🔀', 'shuffle_tracks_button', 'shuffle tracks button', ['U+1F500']),
	Emoji('symbols', '🔁', 'repeat_button', 'repeat button', ['U+1F501']),
	Emoji('symbols', '🔂', 'repeat_single_button', 'repeat single button', ['U+1F502']),
	Emoji('symbols', '▶', 'play_button', 'play button', ['U+25B6']),
	Emoji('symbols', '⏩', 'fast_forward_button', 'fast-forward button', ['U+23E9']),
	Emoji('symbols', '⏭', 'next_track_button', 'next track button', ['U+23ED']),
	Emoji('symbols', '⏯', 'play_or_pause_button', 'play or pause button', ['U+23EF']),
	Emoji('symbols', '◀', 'reverse_button', 'reverse button', ['U+25C0']),
	Emoji('symbols', '⏪', 'fast_reverse_button', 'fast reverse button', ['U+23EA']),
	Emoji('symbols', '⏮', 'last_track_button', 'last track button', ['U+23EE']),
	Emoji('symbols', '🔼', 'upwards_button', 'upwards button', ['U+1F53C']),
	Emoji('symbols', '⏫', 'fast_up_button', 'fast up button', ['U+23EB']),
	Emoji('symbols', '🔽', 'downwards_button', 'downwards button', ['U+1F53D']),
	Emoji('symbols', '⏬', 'fast_down_button', 'fast down button', ['U+23EC']),
	Emoji('symbols', '⏸', 'pause_button', 'pause button', ['U+23F8']),
	Emoji('symbols', '⏹', 'stop_button', 'stop button', ['U+23F9']),
	Emoji('symbols', '⏺', 'record_button', 'record button', ['U+23FA']),
	Emoji('symbols', '⏏', 'eject_button', 'eject button', ['U+23CF']),
	Emoji('symbols', '🎦', 'cinema', 'cinema', ['U+1F3A6']),
	Emoji('symbols', '🔅', 'dim_button', 'dim button', ['U+1F505']),
	Emoji('symbols', '🔆', 'bright_button', 'bright button', ['U+1F506']),
	Emoji('symbols', '📶', 'antenna_bars', 'antenna bars', ['U+1F4F6']),
	Emoji('symbols', '📳', 'vibration_mode', 'vibration mode', ['U+1F4F3']),
	Emoji('symbols', '📴', 'mobile_phone_off', 'mobile phone off', ['U+1F4F4']),
	Emoji('symbols', '♀', 'female_sign', 'female sign', ['U+2640']),
	Emoji('symbols', '♂', 'male_sign', 'male sign', ['U+2642']),
	Emoji('symbols', '⚧', 'transgender_symbol', 'transgender symbol', ['U+26A7']),
	Emoji('symbols', '✖', 'multiply', 'multiply', ['U+2716']),
	Emoji('symbols', '➕', 'plus', 'plus', ['U+2795']),
	Emoji('symbols', '➖', 'minus', 'minus', ['U+2796']),
	Emoji('symbols', '➗', 'divide', 'divide', ['U+2797']),
	Emoji('symbols', '🟰', 'heavy_equals_sign', 'heavy equals sign', ['U+1F7F0']),
	Emoji('symbols', '♾', 'infinity', 'infinity', ['U+267E']),
	Emoji('symbols', '‼', 'double_exclamation_mark', 'double exclamation mark', ['U+203C']),
	Emoji('symbols', '⁉', 'exclamation_question_mark', 'exclamation question mark', ['U+2049']),
	Emoji('symbols', '❓', 'red_question_mark', 'red question mark', ['U+2753']),
	Emoji('symbols', '❔', 'white_question_mark', 'white question mark', ['U+2754']),
	Emoji('symbols', '❕', 'white_exclamation_mark', 'white exclamation mark', ['U+2755']),
	Emoji('symbols', '❗', 'red_exclamation_mark', 'red exclamation mark', ['U+2757']),
	Emoji('symbols', '〰', 'wavy_dash', 'wavy dash', ['U+3030']),
	Emoji('symbols', '💱', 'currency_exchange', 'currency exchange', ['U+1F4B1']),
	Emoji('symbols', '💲', 'heavy_dollar_sign', 'heavy dollar sign', ['U+1F4B2']),
	Emoji('symbols', '⚕', 'medical_symbol', 'medical symbol', ['U+2695']),
	Emoji('symbols', '♻', 'recycling_symbol', 'recycling symbol', ['U+267B']),
	Emoji('symbols', '⚜', 'fleur_de_lis', 'fleur-de-lis', ['U+269C']),
	Emoji('symbols', '🔱', 'trident_emblem', 'trident emblem', ['U+1F531']),
	Emoji('symbols', '📛', 'name_badge', 'name badge', ['U+1F4DB']),
	Emoji('symbols', '🔰', 'japanese_symbol_for_beginner', 'Japanese symbol for beginner', ['U+1F530']),
	Emoji('symbols', '⭕', 'hollow_red_circle', 'hollow red circle', ['U+2B55']),
	Emoji('symbols', '✅', 'check_mark_button', 'check mark button', ['U+2705']),
	Emoji('symbols', '☑', 'check_box_with_check', 'check box with check', ['U+2611']),
	Emoji('symbols', '✔', 'check_mark', 'check mark', ['U+2714']),
	Emoji('symbols', '❌', 'cross_mark', 'cross mark', ['U+274C']),
	Emoji('symbols', '❎', 'cross_mark_button', 'cross mark button', ['U+274E']),
	Emoji('symbols', '➰', 'curly_loop', 'curly loop', ['U+27B0']),
	Emoji('symbols', '➿', 'double_curly_loop', 'double curly loop', ['U+27BF']),
	Emoji('symbols', '〽', 'part_alternation_mark', 'part alternation mark', ['U+303D']),
	Emoji('symbols', '✳', 'eight_spoked_asterisk', 'eight-spoked asterisk', ['U+2733']),
	Emoji('symbols', '✴', 'eight_pointed_star', 'eight-pointed star', ['U+2734']),
	Emoji('symbols', '❇', 'sparkle', 'sparkle', ['U+2747']),
	Emoji('symbols', '©', 'copyright', 'copyright', ['U+00A9']),
	Emoji('symbols', '®', 'registered', 'registered', ['U+00AE']),
	Emoji('symbols', '™', 'trade_mark', 'trade mark', ['U+2122']),
	Emoji('symbols', '#️⃣', ':hash:', 'keycap: #', ['U+0023', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '*️⃣', ':asterisk:', 'keycap: *', ['U+002A', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '0️⃣', ':zero:', 'keycap: 0', ['U+0030', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '1️⃣', ':one:', 'keycap: 1', ['U+0031', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '2️⃣', ':two:', 'keycap: 2', ['U+0032', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '3️⃣', ':three:', 'keycap: 3', ['U+0033', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '4️⃣', ':four:', 'keycap: 4', ['U+0034', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '5️⃣', ':five:', 'keycap: 5', ['U+0035', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '6️⃣', ':six:', 'keycap: 6', ['U+0036', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '7️⃣', ':seven:', 'keycap: 7', ['U+0037', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '8️⃣', ':eight:', 'keycap: 8', ['U+0038', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '9️⃣', ':nine:', 'keycap: 9', ['U+0039', 'U+FE0F', 'U+20E3']),
	Emoji('symbols', '🔟', ':ten:', 'keycap: 10', ['U+1F51F']),
	Emoji('symbols', '🔠', 'input_latin_uppercase', 'input latin uppercase', ['U+1F520']),
	Emoji('symbols', '🔡', 'input_latin_lowercase', 'input latin lowercase', ['U+1F521']),
	Emoji('symbols', '🔢', 'input_numbers', 'input numbers', ['U+1F522']),
	Emoji('symbols', '🔣', 'input_symbols', 'input symbols', ['U+1F523']),
	Emoji('symbols', '🔤', 'input_latin_letters', 'input latin letters', ['U+1F524']),
	Emoji('symbols', '🅰', 'a_button_blood_type', 'A button (blood type)', ['U+1F170']),
	Emoji('symbols', '🆎', 'ab_button_blood_type', 'AB button (blood type)', ['U+1F18E']),
	Emoji('symbols', '🅱', 'b_button_blood_type', 'B button (blood type)', ['U+1F171']),
	Emoji('symbols', '🆑', 'cl_button', 'CL button', ['U+1F191']),
	Emoji('symbols', '🆒', 'cool_button', 'COOL button', ['U+1F192']),
	Emoji('symbols', '🆓', 'free_button', 'FREE button', ['U+1F193']),
	Emoji('symbols', 'ℹ', 'information', 'information', ['U+2139']),
	Emoji('symbols', '🆔', 'id_button', 'ID button', ['U+1F194']),
	Emoji('symbols', 'Ⓜ', 'circled_m', 'circled M', ['U+24C2']),
	Emoji('symbols', '🆕', 'new_button', 'NEW button', ['U+1F195']),
	Emoji('symbols', '🆖', 'ng_button', 'NG button', ['U+1F196']),
	Emoji('symbols', '🅾', 'o_button_blood_type', 'O button (blood type)', ['U+1F17E']),
	Emoji('symbols', '🆗', 'ok_button', 'OK button', ['U+1F197']),
	Emoji('symbols', '🅿', 'p_button', 'P button', ['U+1F17F']),
	Emoji('symbols', '🆘', 'sos_button', 'SOS button', ['U+1F198']),
	Emoji('symbols', '🆙', 'up_button', 'UP! button', ['U+1F199']),
	Emoji('symbols', '🆚', 'vs_button', 'VS button', ['U+1F19A']),
	Emoji('symbols', '🈁', 'japanese_here_button', 'Japanese “here” button', ['U+1F201']),
	Emoji('symbols', '🈂', 'japanese_service_charge_button', 'Japanese “service charge” button', ['U+1F202']),
	Emoji('symbols', '🈷', 'japanese_monthly_amount_button', 'Japanese “monthly amount” button', ['U+1F237']),
	Emoji('symbols', '🈶', 'japanese_not_free_of_charge_button', 'Japanese “not free of charge” button', ['U+1F236']),
	Emoji('symbols', '🈯', 'japanese_reserved_button', 'Japanese “reserved” button', ['U+1F22F']),
	Emoji('symbols', '🉐', 'japanese_bargain_button', 'Japanese “bargain” button', ['U+1F250']),
	Emoji('symbols', '🈹', 'japanese_discount_button', 'Japanese “discount” button', ['U+1F239']),
	Emoji('symbols', '🈚', 'japanese_free_of_charge_button', 'Japanese “free of charge” button', ['U+1F21A']),
	Emoji('symbols', '🈲', 'japanese_prohibited_button', 'Japanese “prohibited” button', ['U+1F232']),
	Emoji('symbols', '🉑', 'japanese_acceptable_button', 'Japanese “acceptable” button', ['U+1F251']),
	Emoji('symbols', '🈸', 'japanese_application_button', 'Japanese “application” button', ['U+1F238']),
	Emoji('symbols', '🈴', 'japanese_passing_grade_button', 'Japanese “passing grade” button', ['U+1F234']),
	Emoji('symbols', '🈳', 'japanese_vacancy_button', 'Japanese “vacancy” button', ['U+1F233']),
	Emoji('symbols', '㊗', 'japanese_congratulations_button', 'Japanese “congratulations” button', ['U+3297']),
	Emoji('symbols', '㊙', 'japanese_secret_button', 'Japanese “secret” button', ['U+3299']),
	Emoji('symbols', '🈺', 'japanese_open_for_business_button', 'Japanese “open for business” button', ['U+1F23A']),
	Emoji('symbols', '🈵', 'japanese_no_vacancy_button', 'Japanese “no vacancy” button', ['U+1F235']),
	Emoji('symbols', '🔴', 'red_circle', 'red circle', ['U+1F534']),
	Emoji('symbols', '🟠', 'orange_circle', 'orange circle', ['U+1F7E0']),
	Emoji('symbols', '🟡', 'yellow_circle', 'yellow circle', ['U+1F7E1']),
	Emoji('symbols', '🟢', 'green_circle', 'green circle', ['U+1F7E2']),
	Emoji('symbols', '🔵', 'blue_circle', 'blue circle', ['U+1F535']),
	Emoji('symbols', '🟣', 'purple_circle', 'purple circle', ['U+1F7E3']),
	Emoji('symbols', '🟤', 'brown_circle', 'brown circle', ['U+1F7E4']),
	Emoji('symbols', '⚫', 'black_circle', 'black circle', ['U+26AB']),
	Emoji('symbols', '⚪', 'white_circle', 'white circle', ['U+26AA']),
	Emoji('symbols', '🟥', 'red_square', 'red square', ['U+1F7E5']),
	Emoji('symbols', '🟧', 'orange_square', 'orange square', ['U+1F7E7']),
	Emoji('symbols', '🟨', 'yellow_square', 'yellow square', ['U+1F7E8']),
	Emoji('symbols', '🟩', 'green_square', 'green square', ['U+1F7E9']),
	Emoji('symbols', '🟦', 'blue_square', 'blue square', ['U+1F7E6']),
	Emoji('symbols', '🟪', 'purple_square', 'purple square', ['U+1F7EA']),
	Emoji('symbols', '🟫', 'brown_square', 'brown square', ['U+1F7EB']),
	Emoji('symbols', '⬛', 'black_large_square', 'black large square', ['U+2B1B']),
	Emoji('symbols', '⬜', 'white_large_square', 'white large square', ['U+2B1C']),
	Emoji('symbols', '◼', 'black_medium_square', 'black medium square', ['U+25FC']),
	Emoji('symbols', '◻', 'white_medium_square', 'white medium square', ['U+25FB']),
	Emoji('symbols', '◾', 'black_medium_small_square', 'black medium-small square', ['U+25FE']),
	Emoji('symbols', '◽', 'white_medium_small_square', 'white medium-small square', ['U+25FD']),
	Emoji('symbols', '▪', 'black_small_square', 'black small square', ['U+25AA']),
	Emoji('symbols', '▫', 'white_small_square', 'white small square', ['U+25AB']),
	Emoji('symbols', '🔶', 'large_orange_diamond', 'large orange diamond', ['U+1F536']),
	Emoji('symbols', '🔷', 'large_blue_diamond', 'large blue diamond', ['U+1F537']),
	Emoji('symbols', '🔸', 'small_orange_diamond', 'small orange diamond', ['U+1F538']),
	Emoji('symbols', '🔹', 'small_blue_diamond', 'small blue diamond', ['U+1F539']),
	Emoji('symbols', '🔺', 'red_triangle_pointed_up', 'red triangle pointed up', ['U+1F53A']),
	Emoji('symbols', '🔻', 'red_triangle_pointed_down', 'red triangle pointed down', ['U+1F53B']),
	Emoji('symbols', '💠', 'diamond_with_a_dot', 'diamond with a dot', ['U+1F4A0']),
	Emoji('symbols', '🔘', 'radio_button', 'radio button', ['U+1F518']),
	Emoji('symbols', '🔳', 'white_square_button', 'white square button', ['U+1F533']),
	Emoji('symbols', '🔲', 'black_square_button', 'black square button', ['U+1F532']),

	## » 221 Emojis found in symbols category « ##

	Emoji('flags', '🏁', 'chequered_flag', 'chequered flag', ['U+1F3C1']),
	Emoji('flags', '🚩', 'triangular_flag', 'triangular flag', ['U+1F6A9']),
	Emoji('flags', '🎌', 'crossed_flags', 'crossed flags', ['U+1F38C']),
	Emoji('flags', '🏴', 'black_flag', 'black flag', ['U+1F3F4']),
	Emoji('flags', '🏳', 'white_flag', 'white flag', ['U+1F3F3']),
	Emoji('flags', '🏳️‍🌈', 'rainbow_flag', 'rainbow flag', ['U+1F3F3', 'U+FE0F', 'U+200D', 'U+1F308']),
	Emoji('flags', '🏳️‍⚧️', 'transgender_flag', 'transgender flag', ['U+1F3F3', 'U+FE0F', 'U+200D', 'U+26A7', 'U+FE0F']),
	Emoji('flags', '🏴‍☠️', 'pirate_flag', 'pirate flag', ['U+1F3F4', 'U+200D', 'U+2620', 'U+FE0F']),
	Emoji('flags', '🇦🇨', 'flag_ascension_island', 'flag: ascension island', ['U+1F1E6', 'U+1F1E8']),
	Emoji('flags', '🇦🇩', 'flag_andorra', 'flag: andorra', ['U+1F1E6', 'U+1F1E9']),
	Emoji('flags', '🇦🇪', 'flag_united_arab_emirates', 'flag: united arab emirates', ['U+1F1E6', 'U+1F1EA']),
	Emoji('flags', '🇦🇫', 'flag_afghanistan', 'flag: afghanistan', ['U+1F1E6', 'U+1F1EB']),
	Emoji('flags', '🇦🇬', 'flag_antigua_barbuda', 'flag: antigua & barbuda', ['U+1F1E6', 'U+1F1EC']),
	Emoji('flags', '🇦🇮', 'flag_anguilla', 'flag: anguilla', ['U+1F1E6', 'U+1F1EE']),
	Emoji('flags', '🇦🇱', 'flag_albania', 'flag: albania', ['U+1F1E6', 'U+1F1F1']),
	Emoji('flags', '🇦🇲', 'flag_armenia', 'flag: armenia', ['U+1F1E6', 'U+1F1F2']),
	Emoji('flags', '🇦🇴', 'flag_angola', 'flag: angola', ['U+1F1E6', 'U+1F1F4']),
	Emoji('flags', '🇦🇶', 'flag_antarctica', 'flag: antarctica', ['U+1F1E6', 'U+1F1F6']),
	Emoji('flags', '🇦🇷', 'flag_argentina', 'flag: argentina', ['U+1F1E6', 'U+1F1F7']),
	Emoji('flags', '🇦🇸', 'flag_american_samoa', 'flag: american samoa', ['U+1F1E6', 'U+1F1F8']),
	Emoji('flags', '🇦🇹', 'flag_austria', 'flag: austria', ['U+1F1E6', 'U+1F1F9']),
	Emoji('flags', '🇦🇺', 'flag_australia', 'flag: australia', ['U+1F1E6', 'U+1F1FA']),
	Emoji('flags', '🇦🇼', 'flag_aruba', 'flag: aruba', ['U+1F1E6', 'U+1F1FC']),
	Emoji('flags', '🇦🇽', 'flag_åland_islands', 'flag: åland islands', ['U+1F1E6', 'U+1F1FD']),
	Emoji('flags', '🇦🇿', 'flag_azerbaijan', 'flag: azerbaijan', ['U+1F1E6', 'U+1F1FF']),
	Emoji('flags', '🇧🇦', 'flag_bosnia_herzegovina', 'flag: bosnia & herzegovina', ['U+1F1E7', 'U+1F1E6']),
	Emoji('flags', '🇧🇧', 'flag_barbados', 'flag: barbados', ['U+1F1E7', 'U+1F1E7']),
	Emoji('flags', '🇧🇩', 'flag_bangladesh', 'flag: bangladesh', ['U+1F1E7', 'U+1F1E9']),
	Emoji('flags', '🇧🇪', 'flag_belgium', 'flag: belgium', ['U+1F1E7', 'U+1F1EA']),
	Emoji('flags', '🇧🇫', 'flag_burkina_faso', 'flag: burkina faso', ['U+1F1E7', 'U+1F1EB']),
	Emoji('flags', '🇧🇬', 'flag_bulgaria', 'flag: bulgaria', ['U+1F1E7', 'U+1F1EC']),
	Emoji('flags', '🇧🇭', 'flag_bahrain', 'flag: bahrain', ['U+1F1E7', 'U+1F1ED']),
	Emoji('flags', '🇧🇮', 'flag_burundi', 'flag: burundi', ['U+1F1E7', 'U+1F1EE']),
	Emoji('flags', '🇧🇯', 'flag_benin', 'flag: benin', ['U+1F1E7', 'U+1F1EF']),
	Emoji('flags', '🇧🇱', 'flag_st._barthélemy', 'flag: st. barthélemy', ['U+1F1E7', 'U+1F1F1']),
	Emoji('flags', '🇧🇲', 'flag_bermuda', 'flag: bermuda', ['U+1F1E7', 'U+1F1F2']),
	Emoji('flags', '🇧🇳', 'flag_brunei', 'flag: brunei', ['U+1F1E7', 'U+1F1F3']),
	Emoji('flags', '🇧🇴', 'flag_bolivia', 'flag: bolivia', ['U+1F1E7', 'U+1F1F4']),
	Emoji('flags', '🇧🇶', 'flag_caribbean_netherlands', 'flag: caribbean netherlands', ['U+1F1E7', 'U+1F1F6']),
	Emoji('flags', '🇧🇷', 'flag_brazil', 'flag: brazil', ['U+1F1E7', 'U+1F1F7']),
	Emoji('flags', '🇧🇸', 'flag_bahamas', 'flag: bahamas', ['U+1F1E7', 'U+1F1F8']),
	Emoji('flags', '🇧🇹', 'flag_bhutan', 'flag: bhutan', ['U+1F1E7', 'U+1F1F9']),
	Emoji('flags', '🇧🇻', 'flag_bouvet_island', 'flag: bouvet island', ['U+1F1E7', 'U+1F1FB']),
	Emoji('flags', '🇧🇼', 'flag_botswana', 'flag: botswana', ['U+1F1E7', 'U+1F1FC']),
	Emoji('flags', '🇧🇾', 'flag_belarus', 'flag: belarus', ['U+1F1E7', 'U+1F1FE']),
	Emoji('flags', '🇧🇿', 'flag_belize', 'flag: belize', ['U+1F1E7', 'U+1F1FF']),
	Emoji('flags', '🇨🇦', 'flag_canada', 'flag: canada', ['U+1F1E8', 'U+1F1E6']),
	Emoji('flags', '🇨🇨', 'flag_cocos_keeling_islands', 'flag: cocos (keeling) islands', ['U+1F1E8', 'U+1F1E8']),
	Emoji('flags', '🇨🇩', 'flag_congo_kinshasa', 'flag: congo - kinshasa', ['U+1F1E8', 'U+1F1E9']),
	Emoji('flags', '🇨🇫', 'flag_central_african_republic', 'flag: central african republic', ['U+1F1E8', 'U+1F1EB']),
	Emoji('flags', '🇨🇬', 'flag_congo_brazzaville', 'flag: congo - brazzaville', ['U+1F1E8', 'U+1F1EC']),
	Emoji('flags', '🇨🇭', 'flag_switzerland', 'flag: switzerland', ['U+1F1E8', 'U+1F1ED']),
	Emoji('flags', '🇨🇮', 'flag_côte_divoire', 'flag: côte d’ivoire', ['U+1F1E8', 'U+1F1EE']),
	Emoji('flags', '🇨🇰', 'flag_cook_islands', 'flag: cook islands', ['U+1F1E8', 'U+1F1F0']),
	Emoji('flags', '🇨🇱', 'flag_chile', 'flag: chile', ['U+1F1E8', 'U+1F1F1']),
	Emoji('flags', '🇨🇲', 'flag_cameroon', 'flag: cameroon', ['U+1F1E8', 'U+1F1F2']),
	Emoji('flags', '🇨🇳', 'flag_china', 'flag: china', ['U+1F1E8', 'U+1F1F3']),
	Emoji('flags', '🇨🇴', 'flag_colombia', 'flag: colombia', ['U+1F1E8', 'U+1F1F4']),
	Emoji('flags', '🇨🇵', 'flag_clipperton_island', 'flag: clipperton island', ['U+1F1E8', 'U+1F1F5']),
	Emoji('flags', '🇨🇷', 'flag_costa_rica', 'flag: costa rica', ['U+1F1E8', 'U+1F1F7']),
	Emoji('flags', '🇨🇺', 'flag_cuba', 'flag: cuba', ['U+1F1E8', 'U+1F1FA']),
	Emoji('flags', '🇨🇻', 'flag_cape_verde', 'flag: cape verde', ['U+1F1E8', 'U+1F1FB']),
	Emoji('flags', '🇨🇼', 'flag_curaçao', 'flag: curaçao', ['U+1F1E8', 'U+1F1FC']),
	Emoji('flags', '🇨🇽', 'flag_christmas_island', 'flag: christmas island', ['U+1F1E8', 'U+1F1FD']),
	Emoji('flags', '🇨🇾', 'flag_cyprus', 'flag: cyprus', ['U+1F1E8', 'U+1F1FE']),
	Emoji('flags', '🇨🇿', 'flag_czechia', 'flag: czechia', ['U+1F1E8', 'U+1F1FF']),
	Emoji('flags', '🇩🇪', 'flag_germany', 'flag: germany', ['U+1F1E9', 'U+1F1EA']),
	Emoji('flags', '🇩🇬', 'flag_diego_garcia', 'flag: diego garcia', ['U+1F1E9', 'U+1F1EC']),
	Emoji('flags', '🇩🇯', 'flag_djibouti', 'flag: djibouti', ['U+1F1E9', 'U+1F1EF']),
	Emoji('flags', '🇩🇰', 'flag_denmark', 'flag: denmark', ['U+1F1E9', 'U+1F1F0']),
	Emoji('flags', '🇩🇲', 'flag_dominica', 'flag: dominica', ['U+1F1E9', 'U+1F1F2']),
	Emoji('flags', '🇩🇴', 'flag_dominican_republic', 'flag: dominican republic', ['U+1F1E9', 'U+1F1F4']),
	Emoji('flags', '🇩🇿', 'flag_algeria', 'flag: algeria', ['U+1F1E9', 'U+1F1FF']),
	Emoji('flags', '🇪🇦', 'flag_ceuta_melilla', 'flag: ceuta & melilla', ['U+1F1EA', 'U+1F1E6']),
	Emoji('flags', '🇪🇨', 'flag_ecuador', 'flag: ecuador', ['U+1F1EA', 'U+1F1E8']),
	Emoji('flags', '🇪🇪', 'flag_estonia', 'flag: estonia', ['U+1F1EA', 'U+1F1EA']),
	Emoji('flags', '🇪🇬', 'flag_egypt', 'flag: egypt', ['U+1F1EA', 'U+1F1EC']),
	Emoji('flags', '🇪🇭', 'flag_western_sahara', 'flag: western sahara', ['U+1F1EA', 'U+1F1ED']),
	Emoji('flags', '🇪🇷', 'flag_eritrea', 'flag: eritrea', ['U+1F1EA', 'U+1F1F7']),
	Emoji('flags', '🇪🇸', 'flag_spain', 'flag: spain', ['U+1F1EA', 'U+1F1F8']),
	Emoji('flags', '🇪🇹', 'flag_ethiopia', 'flag: ethiopia', ['U+1F1EA', 'U+1F1F9']),
	Emoji('flags', '🇪🇺', 'flag_european_union', 'flag: european union', ['U+1F1EA', 'U+1F1FA']),
	Emoji('flags', '🇫🇮', 'flag_finland', 'flag: finland', ['U+1F1EB', 'U+1F1EE']),
	Emoji('flags', '🇫🇯', 'flag_fiji', 'flag: fiji', ['U+1F1EB', 'U+1F1EF']),
	Emoji('flags', '🇫🇰', 'flag_falkland_islands', 'flag: falkland islands', ['U+1F1EB', 'U+1F1F0']),
	Emoji('flags', '🇫🇲', 'flag_micronesia', 'flag: micronesia', ['U+1F1EB', 'U+1F1F2']),
	Emoji('flags', '🇫🇴', 'flag_faroe_islands', 'flag: faroe islands', ['U+1F1EB', 'U+1F1F4']),
	Emoji('flags', '🇫🇷', 'flag_france', 'flag: france', ['U+1F1EB', 'U+1F1F7']),
	Emoji('flags', '🇬🇦', 'flag_gabon', 'flag: gabon', ['U+1F1EC', 'U+1F1E6']),
	Emoji('flags', '🇬🇧', 'flag_united_kingdom', 'flag: united kingdom', ['U+1F1EC', 'U+1F1E7']),
	Emoji('flags', '🇬🇩', 'flag_grenada', 'flag: grenada', ['U+1F1EC', 'U+1F1E9']),
	Emoji('flags', '🇬🇪', 'flag_georgia', 'flag: georgia', ['U+1F1EC', 'U+1F1EA']),
	Emoji('flags', '🇬🇫', 'flag_french_guiana', 'flag: french guiana', ['U+1F1EC', 'U+1F1EB']),
	Emoji('flags', '🇬🇬', 'flag_guernsey', 'flag: guernsey', ['U+1F1EC', 'U+1F1EC']),
	Emoji('flags', '🇬🇭', 'flag_ghana', 'flag: ghana', ['U+1F1EC', 'U+1F1ED']),
	Emoji('flags', '🇬🇮', 'flag_gibraltar', 'flag: gibraltar', ['U+1F1EC', 'U+1F1EE']),
	Emoji('flags', '🇬🇱', 'flag_greenland', 'flag: greenland', ['U+1F1EC', 'U+1F1F1']),
	Emoji('flags', '🇬🇲', 'flag_gambia', 'flag: gambia', ['U+1F1EC', 'U+1F1F2']),
	Emoji('flags', '🇬🇳', 'flag_guinea', 'flag: guinea', ['U+1F1EC', 'U+1F1F3']),
	Emoji('flags', '🇬🇵', 'flag_guadeloupe', 'flag: guadeloupe', ['U+1F1EC', 'U+1F1F5']),
	Emoji('flags', '🇬🇶', 'flag_equatorial_guinea', 'flag: equatorial guinea', ['U+1F1EC', 'U+1F1F6']),
	Emoji('flags', '🇬🇷', 'flag_greece', 'flag: greece', ['U+1F1EC', 'U+1F1F7']),
	Emoji('flags', '🇬🇸', 'flag_south_georgia_south_sandwich_islands', 'flag: south georgia & south sandwich islands', ['U+1F1EC', 'U+1F1F8']),
	Emoji('flags', '🇬🇹', 'flag_guatemala', 'flag: guatemala', ['U+1F1EC', 'U+1F1F9']),
	Emoji('flags', '🇬🇺', 'flag_guam', 'flag: guam', ['U+1F1EC', 'U+1F1FA']),
	Emoji('flags', '🇬🇼', 'flag_guinea_bissau', 'flag: guinea-bissau', ['U+1F1EC', 'U+1F1FC']),
	Emoji('flags', '🇬🇾', 'flag_guyana', 'flag: guyana', ['U+1F1EC', 'U+1F1FE']),
	Emoji('flags', '🇭🇰', 'flag_hong_kong_sar_china', 'flag: hong kong sar china', ['U+1F1ED', 'U+1F1F0']),
	Emoji('flags', '🇭🇲', 'flag_heard_mcdonald_islands', 'flag: heard & mcdonald islands', ['U+1F1ED', 'U+1F1F2']),
	Emoji('flags', '🇭🇳', 'flag_honduras', 'flag: honduras', ['U+1F1ED', 'U+1F1F3']),
	Emoji('flags', '🇭🇷', 'flag_croatia', 'flag: croatia', ['U+1F1ED', 'U+1F1F7']),
	Emoji('flags', '🇭🇹', 'flag_haiti', 'flag: haiti', ['U+1F1ED', 'U+1F1F9']),
	Emoji('flags', '🇭🇺', 'flag_hungary', 'flag: hungary', ['U+1F1ED', 'U+1F1FA']),
	Emoji('flags', '🇮🇨', 'flag_canary_islands', 'flag: canary islands', ['U+1F1EE', 'U+1F1E8']),
	Emoji('flags', '🇮🇩', 'flag_indonesia', 'flag: indonesia', ['U+1F1EE', 'U+1F1E9']),
	Emoji('flags', '🇮🇪', 'flag_ireland', 'flag: ireland', ['U+1F1EE', 'U+1F1EA']),
	Emoji('flags', '🇮🇱', 'flag_israel', 'flag: israel', ['U+1F1EE', 'U+1F1F1']),
	Emoji('flags', '🇮🇲', 'flag_isle_of_man', 'flag: isle of man', ['U+1F1EE', 'U+1F1F2']),
	Emoji('flags', '🇮🇳', 'flag_india', 'flag: india', ['U+1F1EE', 'U+1F1F3']),
	Emoji('flags', '🇮🇴', 'flag_british_indian_ocean_territory', 'flag: british indian ocean territory', ['U+1F1EE', 'U+1F1F4']),
	Emoji('flags', '🇮🇶', 'flag_iraq', 'flag: iraq', ['U+1F1EE', 'U+1F1F6']),
	Emoji('flags', '🇮🇷', 'flag_iran', 'flag: iran', ['U+1F1EE', 'U+1F1F7']),
	Emoji('flags', '🇮🇸', 'flag_iceland', 'flag: iceland', ['U+1F1EE', 'U+1F1F8']),
	Emoji('flags', '🇮🇹', 'flag_italy', 'flag: italy', ['U+1F1EE', 'U+1F1F9']),
	Emoji('flags', '🇯🇪', 'flag_jersey', 'flag: jersey', ['U+1F1EF', 'U+1F1EA']),
	Emoji('flags', '🇯🇲', 'flag_jamaica', 'flag: jamaica', ['U+1F1EF', 'U+1F1F2']),
	Emoji('flags', '🇯🇴', 'flag_jordan', 'flag: jordan', ['U+1F1EF', 'U+1F1F4']),
	Emoji('flags', '🇯🇵', 'flag_japan', 'flag: japan', ['U+1F1EF', 'U+1F1F5']),
	Emoji('flags', '🇰🇪', 'flag_kenya', 'flag: kenya', ['U+1F1F0', 'U+1F1EA']),
	Emoji('flags', '🇰🇬', 'flag_kyrgyzstan', 'flag: kyrgyzstan', ['U+1F1F0', 'U+1F1EC']),
	Emoji('flags', '🇰🇭', 'flag_cambodia', 'flag: cambodia', ['U+1F1F0', 'U+1F1ED']),
	Emoji('flags', '🇰🇮', 'flag_kiribati', 'flag: kiribati', ['U+1F1F0', 'U+1F1EE']),
	Emoji('flags', '🇰🇲', 'flag_comoros', 'flag: comoros', ['U+1F1F0', 'U+1F1F2']),
	Emoji('flags', '🇰🇳', 'flag_st._kitts_nevis', 'flag: st. kitts & nevis', ['U+1F1F0', 'U+1F1F3']),
	Emoji('flags', '🇰🇵', 'flag_north_korea', 'flag: north korea', ['U+1F1F0', 'U+1F1F5']),
	Emoji('flags', '🇰🇷', 'flag_south_korea', 'flag: south korea', ['U+1F1F0', 'U+1F1F7']),
	Emoji('flags', '🇰🇼', 'flag_kuwait', 'flag: kuwait', ['U+1F1F0', 'U+1F1FC']),
	Emoji('flags', '🇰🇾', 'flag_cayman_islands', 'flag: cayman islands', ['U+1F1F0', 'U+1F1FE']),
	Emoji('flags', '🇰🇿', 'flag_kazakhstan', 'flag: kazakhstan', ['U+1F1F0', 'U+1F1FF']),
	Emoji('flags', '🇱🇦', 'flag_laos', 'flag: laos', ['U+1F1F1', 'U+1F1E6']),
	Emoji('flags', '🇱🇧', 'flag_lebanon', 'flag: lebanon', ['U+1F1F1', 'U+1F1E7']),
	Emoji('flags', '🇱🇨', 'flag_st._lucia', 'flag: st. lucia', ['U+1F1F1', 'U+1F1E8']),
	Emoji('flags', '🇱🇮', 'flag_liechtenstein', 'flag: liechtenstein', ['U+1F1F1', 'U+1F1EE']),
	Emoji('flags', '🇱🇰', 'flag_sri_lanka', 'flag: sri lanka', ['U+1F1F1', 'U+1F1F0']),
	Emoji('flags', '🇱🇷', 'flag_liberia', 'flag: liberia', ['U+1F1F1', 'U+1F1F7']),
	Emoji('flags', '🇱🇸', 'flag_lesotho', 'flag: lesotho', ['U+1F1F1', 'U+1F1F8']),
	Emoji('flags', '🇱🇹', 'flag_lithuania', 'flag: lithuania', ['U+1F1F1', 'U+1F1F9']),
	Emoji('flags', '🇱🇺', 'flag_luxembourg', 'flag: luxembourg', ['U+1F1F1', 'U+1F1FA']),
	Emoji('flags', '🇱🇻', 'flag_latvia', 'flag: latvia', ['U+1F1F1', 'U+1F1FB']),
	Emoji('flags', '🇱🇾', 'flag_libya', 'flag: libya', ['U+1F1F1', 'U+1F1FE']),
	Emoji('flags', '🇲🇦', 'flag_morocco', 'flag: morocco', ['U+1F1F2', 'U+1F1E6']),
	Emoji('flags', '🇲🇨', 'flag_monaco', 'flag: monaco', ['U+1F1F2', 'U+1F1E8']),
	Emoji('flags', '🇲🇩', 'flag_moldova', 'flag: moldova', ['U+1F1F2', 'U+1F1E9']),
	Emoji('flags', '🇲🇪', 'flag_montenegro', 'flag: montenegro', ['U+1F1F2', 'U+1F1EA']),
	Emoji('flags', '🇲🇫', 'flag_st._martin', 'flag: st. martin', ['U+1F1F2', 'U+1F1EB']),
	Emoji('flags', '🇲🇬', 'flag_madagascar', 'flag: madagascar', ['U+1F1F2', 'U+1F1EC']),
	Emoji('flags', '🇲🇭', 'flag_marshall_islands', 'flag: marshall islands', ['U+1F1F2', 'U+1F1ED']),
	Emoji('flags', '🇲🇰', 'flag_north_macedonia', 'flag: north macedonia', ['U+1F1F2', 'U+1F1F0']),
	Emoji('flags', '🇲🇱', 'flag_mali', 'flag: mali', ['U+1F1F2', 'U+1F1F1']),
	Emoji('flags', '🇲🇲', 'flag_myanmar_burma_', 'flag: myanmar (burma)', ['U+1F1F2', 'U+1F1F2']),
	Emoji('flags', '🇲🇳', 'flag_mongolia', 'flag: mongolia', ['U+1F1F2', 'U+1F1F3']),
	Emoji('flags', '🇲🇴', 'flag_macao_sar_china', 'flag: macao sar china', ['U+1F1F2', 'U+1F1F4']),
	Emoji('flags', '🇲🇵', 'flag_northern_mariana_islands', 'flag: northern mariana islands', ['U+1F1F2', 'U+1F1F5']),
	Emoji('flags', '🇲🇶', 'flag_martinique', 'flag: martinique', ['U+1F1F2', 'U+1F1F6']),
	Emoji('flags', '🇲🇷', 'flag_mauritania', 'flag: mauritania', ['U+1F1F2', 'U+1F1F7']),
	Emoji('flags', '🇲🇸', 'flag_montserrat', 'flag: montserrat', ['U+1F1F2', 'U+1F1F8']),
	Emoji('flags', '🇲🇹', 'flag_malta', 'flag: malta', ['U+1F1F2', 'U+1F1F9']),
	Emoji('flags', '🇲🇺', 'flag_mauritius', 'flag: mauritius', ['U+1F1F2', 'U+1F1FA']),
	Emoji('flags', '🇲🇻', 'flag_maldives', 'flag: maldives', ['U+1F1F2', 'U+1F1FB']),
	Emoji('flags', '🇲🇼', 'flag_malawi', 'flag: malawi', ['U+1F1F2', 'U+1F1FC']),
	Emoji('flags', '🇲🇽', 'flag_mexico', 'flag: mexico', ['U+1F1F2', 'U+1F1FD']),
	Emoji('flags', '🇲🇾', 'flag_malaysia', 'flag: malaysia', ['U+1F1F2', 'U+1F1FE']),
	Emoji('flags', '🇲🇿', 'flag_mozambique', 'flag: mozambique', ['U+1F1F2', 'U+1F1FF']),
	Emoji('flags', '🇳🇦', 'flag_namibia', 'flag: namibia', ['U+1F1F3', 'U+1F1E6']),
	Emoji('flags', '🇳🇨', 'flag_new_caledonia', 'flag: new caledonia', ['U+1F1F3', 'U+1F1E8']),
	Emoji('flags', '🇳🇪', 'flag_niger', 'flag: niger', ['U+1F1F3', 'U+1F1EA']),
	Emoji('flags', '🇳🇫', 'flag_norfolk_island', 'flag: norfolk island', ['U+1F1F3', 'U+1F1EB']),
	Emoji('flags', '🇳🇬', 'flag_nigeria', 'flag: nigeria', ['U+1F1F3', 'U+1F1EC']),
	Emoji('flags', '🇳🇮', 'flag_nicaragua', 'flag: nicaragua', ['U+1F1F3', 'U+1F1EE']),
	Emoji('flags', '🇳🇱', 'flag_netherlands', 'flag: netherlands', ['U+1F1F3', 'U+1F1F1']),
	Emoji('flags', '🇳🇴', 'flag_norway', 'flag: norway', ['U+1F1F3', 'U+1F1F4']),
	Emoji('flags', '🇳🇵', 'flag_nepal', 'flag: nepal', ['U+1F1F3', 'U+1F1F5']),
	Emoji('flags', '🇳🇷', 'flag_nauru', 'flag: nauru', ['U+1F1F3', 'U+1F1F7']),
	Emoji('flags', '🇳🇺', 'flag_niue', 'flag: niue', ['U+1F1F3', 'U+1F1FA']),
	Emoji('flags', '🇳🇿', 'flag_new_zealand', 'flag: new zealand', ['U+1F1F3', 'U+1F1FF']),
	Emoji('flags', '🇴🇲', 'flag_oman', 'flag: oman', ['U+1F1F4', 'U+1F1F2']),
	Emoji('flags', '🇵🇦', 'flag_panama', 'flag: panama', ['U+1F1F5', 'U+1F1E6']),
	Emoji('flags', '🇵🇪', 'flag_peru', 'flag: peru', ['U+1F1F5', 'U+1F1EA']),
	Emoji('flags', '🇵🇫', 'flag_french_polynesia', 'flag: french polynesia', ['U+1F1F5', 'U+1F1EB']),
	Emoji('flags', '🇵🇬', 'flag_papua_new_guinea', 'flag: papua new guinea', ['U+1F1F5', 'U+1F1EC']),
	Emoji('flags', '🇵🇭', 'flag_philippines', 'flag: philippines', ['U+1F1F5', 'U+1F1ED']),
	Emoji('flags', '🇵🇰', 'flag_pakistan', 'flag: pakistan', ['U+1F1F5', 'U+1F1F0']),
	Emoji('flags', '🇵🇱', 'flag_poland', 'flag: poland', ['U+1F1F5', 'U+1F1F1']),
	Emoji('flags', '🇵🇲', 'flag_st._pierre_miquelon', 'flag: st. pierre & miquelon', ['U+1F1F5', 'U+1F1F2']),
	Emoji('flags', '🇵🇳', 'flag_pitcairn_islands', 'flag: pitcairn islands', ['U+1F1F5', 'U+1F1F3']),
	Emoji('flags', '🇵🇷', 'flag_puerto_rico', 'flag: puerto rico', ['U+1F1F5', 'U+1F1F7']),
	Emoji('flags', '🇵🇸', 'flag_palestinian_territories', 'flag: palestinian territories', ['U+1F1F5', 'U+1F1F8']),
	Emoji('flags', '🇵🇹', 'flag_portugal', 'flag: portugal', ['U+1F1F5', 'U+1F1F9']),
	Emoji('flags', '🇵🇼', 'flag_palau', 'flag: palau', ['U+1F1F5', 'U+1F1FC']),
	Emoji('flags', '🇵🇾', 'flag_paraguay', 'flag: paraguay', ['U+1F1F5', 'U+1F1FE']),
	Emoji('flags', '🇶🇦', 'flag_qatar', 'flag: qatar', ['U+1F1F6', 'U+1F1E6']),
	Emoji('flags', '🇷🇪', 'flag_réunion', 'flag: réunion', ['U+1F1F7', 'U+1F1EA']),
	Emoji('flags', '🇷🇴', 'flag_romania', 'flag: romania', ['U+1F1F7', 'U+1F1F4']),
	Emoji('flags', '🇷🇸', 'flag_serbia', 'flag: serbia', ['U+1F1F7', 'U+1F1F8']),
	Emoji('flags', '🇷🇺', 'flag_russia', 'flag: russia', ['U+1F1F7', 'U+1F1FA']),
	Emoji('flags', '🇷🇼', 'flag_rwanda', 'flag: rwanda', ['U+1F1F7', 'U+1F1FC']),
	Emoji('flags', '🇸🇦', 'flag_saudi_arabia', 'flag: saudi arabia', ['U+1F1F8', 'U+1F1E6']),
	Emoji('flags', '🇸🇧', 'flag_solomon_islands', 'flag: solomon islands', ['U+1F1F8', 'U+1F1E7']),
	Emoji('flags', '🇸🇨', 'flag_seychelles', 'flag: seychelles', ['U+1F1F8', 'U+1F1E8']),
	Emoji('flags', '🇸🇩', 'flag_sudan', 'flag: sudan', ['U+1F1F8', 'U+1F1E9']),
	Emoji('flags', '🇸🇪', 'flag_sweden', 'flag: sweden', ['U+1F1F8', 'U+1F1EA']),
	Emoji('flags', '🇸🇬', 'flag_singapore', 'flag: singapore', ['U+1F1F8', 'U+1F1EC']),
	Emoji('flags', '🇸🇭', 'flag_st._helena', 'flag: st. helena', ['U+1F1F8', 'U+1F1ED']),
	Emoji('flags', '🇸🇮', 'flag_slovenia', 'flag: slovenia', ['U+1F1F8', 'U+1F1EE']),
	Emoji('flags', '🇸🇯', 'flag_svalbard_jan_mayen', 'flag: svalbard & jan mayen', ['U+1F1F8', 'U+1F1EF']),
	Emoji('flags', '🇸🇰', 'flag_slovakia', 'flag: slovakia', ['U+1F1F8', 'U+1F1F0']),
	Emoji('flags', '🇸🇱', 'flag_sierra_leone', 'flag: sierra leone', ['U+1F1F8', 'U+1F1F1']),
	Emoji('flags', '🇸🇲', 'flag_san_marino', 'flag: san marino', ['U+1F1F8', 'U+1F1F2']),
	Emoji('flags', '🇸🇳', 'flag_senegal', 'flag: senegal', ['U+1F1F8', 'U+1F1F3']),
	Emoji('flags', '🇸🇴', 'flag_somalia', 'flag: somalia', ['U+1F1F8', 'U+1F1F4']),
	Emoji('flags', '🇸🇷', 'flag_suriname', 'flag: suriname', ['U+1F1F8', 'U+1F1F7']),
	Emoji('flags', '🇸🇸', 'flag_south_sudan', 'flag: south sudan', ['U+1F1F8', 'U+1F1F8']),
	Emoji('flags', '🇸🇹', 'flag_são_tomé_príncipe', 'flag: são tomé & príncipe', ['U+1F1F8', 'U+1F1F9']),
	Emoji('flags', '🇸🇻', 'flag_el_salvador', 'flag: el salvador', ['U+1F1F8', 'U+1F1FB']),
	Emoji('flags', '🇸🇽', 'flag_sint_maarten', 'flag: sint maarten', ['U+1F1F8', 'U+1F1FD']),
	Emoji('flags', '🇸🇾', 'flag_syria', 'flag: syria', ['U+1F1F8', 'U+1F1FE']),
	Emoji('flags', '🇸🇿', 'flag_eswatini', 'flag: eswatini', ['U+1F1F8', 'U+1F1FF']),
	Emoji('flags', '🇹🇦', 'flag_tristan_da_cunha', 'flag: tristan da cunha', ['U+1F1F9', 'U+1F1E6']),
	Emoji('flags', '🇹🇨', 'flag_turks_caicos_islands', 'flag: turks & caicos islands', ['U+1F1F9', 'U+1F1E8']),
	Emoji('flags', '🇹🇩', 'flag_chad', 'flag: chad', ['U+1F1F9', 'U+1F1E9']),
	Emoji('flags', '🇹🇫', 'flag_french_southern_territories', 'flag: french southern territories', ['U+1F1F9', 'U+1F1EB']),
	Emoji('flags', '🇹🇬', 'flag_togo', 'flag: togo', ['U+1F1F9', 'U+1F1EC']),
	Emoji('flags', '🇹🇭', 'flag_thailand', 'flag: thailand', ['U+1F1F9', 'U+1F1ED']),
	Emoji('flags', '🇹🇯', 'flag_tajikistan', 'flag: tajikistan', ['U+1F1F9', 'U+1F1EF']),
	Emoji('flags', '🇹🇰', 'flag_tokelau', 'flag: tokelau', ['U+1F1F9', 'U+1F1F0']),
	Emoji('flags', '🇹🇱', 'flag_timor_leste', 'flag: timor-leste', ['U+1F1F9', 'U+1F1F1']),
	Emoji('flags', '🇹🇲', 'flag_turkmenistan', 'flag: turkmenistan', ['U+1F1F9', 'U+1F1F2']),
	Emoji('flags', '🇹🇳', 'flag_tunisia', 'flag: tunisia', ['U+1F1F9', 'U+1F1F3']),
	Emoji('flags', '🇹🇴', 'flag_tonga', 'flag: tonga', ['U+1F1F9', 'U+1F1F4']),
	Emoji('flags', '🇹🇷', 'flag_turkey', 'flag: turkey', ['U+1F1F9', 'U+1F1F7']),
	Emoji('flags', '🇹🇹', 'flag_trinidad_tobago', 'flag: trinidad & tobago', ['U+1F1F9', 'U+1F1F9']),
	Emoji('flags', '🇹🇻', 'flag_tuvalu', 'flag: tuvalu', ['U+1F1F9', 'U+1F1FB']),
	Emoji('flags', '🇹🇼', 'flag_taiwan', 'flag: taiwan', ['U+1F1F9', 'U+1F1FC']),
	Emoji('flags', '🇹🇿', 'flag_tanzania', 'flag: tanzania', ['U+1F1F9', 'U+1F1FF']),
	Emoji('flags', '🇺🇦', 'flag_ukraine', 'flag: ukraine', ['U+1F1FA', 'U+1F1E6']),
	Emoji('flags', '🇺🇬', 'flag_uganda', 'flag: uganda', ['U+1F1FA', 'U+1F1EC']),
	Emoji('flags', '🇺🇲', 'flag_u.s._outlying_islands', 'flag: u.s. outlying islands', ['U+1F1FA', 'U+1F1F2']),
	Emoji('flags', '🇺🇳', 'flag_united_nations', 'flag: united nations', ['U+1F1FA', 'U+1F1F3']),
	Emoji('flags', '🇺🇸', 'flag_united_states', 'flag: united states', ['U+1F1FA', 'U+1F1F8']),
	Emoji('flags', '🇺🇾', 'flag_uruguay', 'flag: uruguay', ['U+1F1FA', 'U+1F1FE']),
	Emoji('flags', '🇺🇿', 'flag_uzbekistan', 'flag: uzbekistan', ['U+1F1FA', 'U+1F1FF']),
	Emoji('flags', '🇻🇦', 'flag_vatican_city', 'flag: vatican city', ['U+1F1FB', 'U+1F1E6']),
	Emoji('flags', '🇻🇨', 'flag_st._vincent_grenadines', 'flag: st. vincent & grenadines', ['U+1F1FB', 'U+1F1E8']),
	Emoji('flags', '🇻🇪', 'flag_venezuela', 'flag: venezuela', ['U+1F1FB', 'U+1F1EA']),
	Emoji('flags', '🇻🇬', 'flag_british_virgin_islands', 'flag: british virgin islands', ['U+1F1FB', 'U+1F1EC']),
	Emoji('flags', '🇻🇮', 'flag_u.s._virgin_islands', 'flag: u.s. virgin islands', ['U+1F1FB', 'U+1F1EE']),
	Emoji('flags', '🇻🇳', 'flag_vietnam', 'flag: vietnam', ['U+1F1FB', 'U+1F1F3']),
	Emoji('flags', '🇻🇺', 'flag_vanuatu', 'flag: vanuatu', ['U+1F1FB', 'U+1F1FA']),
	Emoji('flags', '🇼🇫', 'flag_wallis_futuna', 'flag: wallis & futuna', ['U+1F1FC', 'U+1F1EB']),
	Emoji('flags', '🇼🇸', 'flag_samoa', 'flag: samoa', ['U+1F1FC', 'U+1F1F8']),
	Emoji('flags', '🇽🇰', 'flag_kosovo', 'flag: kosovo', ['U+1F1FD', 'U+1F1F0']),
	Emoji('flags', '🇾🇪', 'flag_yemen', 'flag: yemen', ['U+1F1FE', 'U+1F1EA']),
	Emoji('flags', '🇾🇹', 'flag_mayotte', 'flag: mayotte', ['U+1F1FE', 'U+1F1F9']),
	Emoji('flags', '🇿🇦', 'flag_south_africa', 'flag: south africa', ['U+1F1FF', 'U+1F1E6']),
	Emoji('flags', '🇿🇲', 'flag_zambia', 'flag: zambia', ['U+1F1FF', 'U+1F1F2']),
	Emoji('flags', '🇿🇼', 'flag_zimbabwe', 'flag: zimbabwe', ['U+1F1FF', 'U+1F1FC']),
	Emoji('flags', '🏴󠁧󠁢󠁥󠁮󠁧󠁿', 'flag_england', 'flag: england', ['U+1F3F4', 'U+E0067', 'U+E0062', 'U+E0065', 'U+E006E', 'U+E0067', 'U+E007F']),
	Emoji('flags', '🏴󠁧󠁢󠁳󠁣󠁴󠁿', 'flag_scotland', 'flag: scotland', ['U+1F3F4', 'U+E0067', 'U+E0062', 'U+E0073', 'U+E0063', 'U+E0074', 'U+E007F']),
	Emoji('flags', '🏴󠁧󠁢󠁷󠁬󠁳󠁿', 'flag_wales', 'flag: wales', ['U+1F3F4', 'U+E0067', 'U+E0062', 'U+E0077', 'U+E006C', 'U+E0073', 'U+E007F']),

	## » 269 Emojis found in flags category « ##

]
## » Total of 1851 Emojis found in all categories « ##
